+function ($) {
    "use strict";
    /**
     * 保存sessionStorage信息，session级别缓存
     * 在key前增加模块名的前缀标识，每个模块存的key值是属于当前模块的，而开发人员不需要关注前缀（缓存的数据会自动增加前缀标识）
     * 另外在非pc浏览器上保存、取值统一通过aes加密为密文
     * @parm key 设置的key
     * @parm value 设置的值
     * @parm isModulesShare true/false 是否多模块共享，true表示可以被其他模块使用，否则保存没有模块前缀标识，不传默认为false，
     *        注意：这里共享只能是同域下同一个浏览器，如果是嵌入原生多webview中，相当于开启多个浏览器，不能实现模块共享，共享数据存取需要调用原生的对接方法！！
     * @param options 保存时的参数
     *        shareCookie 是否共享到 cookie
     *        isEncrypt 是否加密，默认 false
     *      isSaveSession 是否存储到sessionStorage，默认true
     */
    $.setSStorageInfo = function (key, value, isModulesShare, options) {
        value = value != null ? value : "";
        options = options || {isEncrypt: false};
        options.isEncrypt = typeof (options.isEncrypt) === "undefined" ? false : options.isEncrypt;

        if ($.config.platform !== "0" && $.config.isSaveSessionToApp == 1 && $.config.appSStorageKey && $.config.appSStorageKey.indexOf(key) > -1) {
            //增加模块前缀标识
            if (isModulesShare) {
                key = "_share|" + key;
            } else {
                key = $.config.storagePrefix + "|" + key;
            }
            var oValue = JSON.stringify(value);
            var param = {
                funcNo: "50040", //保存数据到内存缓存
                key: key,
                value: oValue,
                time: 0,
                isEncrypt: options.isEncrypt ? 1 : 0
            }
            $.callMessage(param)
        } else {
            //增加模块前缀标识
            if (isModulesShare) {
                key = "_share|" + key;
            } else {
                key = $.config.storagePrefix + "|" + key;
            }
            var oValue = {
                // 值
                value: value,
                // 保存的时间，0 代表不会被扫描器清除
                time: 0
            };
            try {
                oValue = JSON.stringify(oValue);
            } catch (e) {
                $.alert("存储数据失败，key为：" + key + "错误信息：" + e.message);
            }
            try {
                if (options.isEncrypt) {
                    oValue = $.endecryptUtils.aesEncrypt('iloveyou', oValue);
                }
            } catch (e) {

            }
            try {
                if (options.isSaveSession === undefined || options.isSaveSession) {
                    sessionStorage.setItem(key, oValue);
                }
                if ($.cookieUtils.enabled() && options.shareCookie) {
                    $.cookieUtils.set(key, oValue);
                }
            } catch (e) {
                $.alert("您的浏览器版本太低，或者您开启了隐身/无痕浏览模式，或者WebView组件不支持sessionStorage！");
                try {
                    point(JSON.stringify({
                        pageId:location.href,
                        key:key, 
                        value:value,
                        type:'sessionStorage.set'
                    }));
                } catch (error) {}
            }
        }
    }
    function point(text){
        var param = {
            "funcNo":"10000001",
            "moduleId":"yjapp.trade",//模块id
            "pageName":"",
            "pageId":"sotragePoint",
            "eventName":"",
            "eventId":"",
            "actionType":"click",
            "eventParam":"", //事件参数
            "pageDomain":"",//域名
            "pagePath":"",// 路径
            "pageQuery":"",//页面参数
            "formData":text,//表单内容
            "stayTime":"",//页面停留时长
            "osType":"",
        };
        $.callMessage(param);
    }
    /**
     * 获取sessionStorage信息，session级别缓存
     * 在key前增加模块名的前缀标识，每个模块存的key值是属于当前模块的，避免冲突，而开发人员不需要关注前缀（缓存的数据会自动增加前缀标识）
     * 另外在非pc浏览器上保存、取值统一通过aes加密为密文
     * @parm key 设置的key
     * @parm isModulesShare true/false 是否多模块共享，true表示可以被其他模块使用，则保存没有模块前缀标识，不传默认为false
     *        注意：这里共享只能是同域下同一个浏览器，如果是嵌入原生多webview中，相当于开启多个浏览器，不能实现模块共享，共享数据存取需要调用原生的对接方法！！
     * @param options 获取时的参数
     *        isDecrypt 是否解密，默认 false
     */
    $.getSStorageInfo = function (key, isModulesShare, options) {
        options = options || {isDecrypt: false};
        options.isDecrypt = typeof (options.isDecrypt) === "undefined" ? false : options.isDecrypt;
        if ($.config.platform !== "0" && $.config.isSaveSessionToApp == 1 && $.config.appSStorageKey && $.config.appSStorageKey.indexOf(key) > -1) {
            //增加模块前缀标识
            if (isModulesShare) {
                key = "_share|" + key;
            } else {
                key = $.config.storagePrefix + "|" + key;
            }
            var catchValue = null;
            var param = {
                funcNo: '50041',
                isParseJsonObject: '0',
                key: key
            };
            catchValue = $.callMessage(param);
            if (catchValue.error_no == 0 && catchValue.results && catchValue.results.length > 0) {
                var value = catchValue.results[0].value
                //兼容andriod一些版本直接返回object和''
                if (typeof value === 'object' || value === '') {
                    return value
                }
                return JSON.parse(value)
            } else {
                $.alert(catchValue.error_info, value);
            }
        } else {
            //增加模块前缀标识
            if (isModulesShare) {
                key = "_share|" + key;
            } else {
                key = $.config.storagePrefix + "|" + key;
            }

            var oValue = null;
            try {
                oValue = sessionStorage.getItem(key);
            } catch (e) {
                $.alert("您的浏览器版本太低，或者您开启了隐身/无痕浏览模式，或者WebView组件不支持sessionStorage！");
                try {
                    point(JSON.stringify({
                        pageId:location.href,
                        key:key, 
                        type:'sessionStorage.get'
                    }));
                } catch (error) {}
                return null;
            }

            if (oValue === null && $.cookieUtils.enabled()) {
                oValue = $.cookieUtils.get(key);
            }

            if (oValue === null || oValue === "null" || oValue === "") {
                return oValue;
            }

            if (options.isDecrypt) {
                oValue = $.endecryptUtils.aesDecrypt('iloveyou', oValue);
            }

            var value = null;
            try {
                oValue = JSON.parse(oValue);
            } catch (e) {
                value = oValue;
            }

            // 如果是调用 setSStorageInfo api 存储的数据，取 value 属性值
            if (oValue.hasOwnProperty("time") && oValue.hasOwnProperty("value")) {
                value = oValue.value;
            } else {
                value = oValue;
            }

            return value;
        }
    }
    /**
     * 清除sessionStorage中的数据，这里分3种情况：
     * 1、如果不传key，则清除当前模块的sessionStorage数据
     * 2、如果key为字符串变量，则清除当前模块的sessionStorage数据
     * 3、如果key为Boolean类型变量true，则清除同一站点下所有模块的sessionStorage数据（支持多模块）
     * @parm key 保存时的key，为 true时，清空sessionStorage
     * @parm isModulesShare true/false 是否多模块共享，不传默认为false
     */
    $.clearSStorage = function (key, isModulesShare) {
        try {
            if ($.config.platform !== "0" && $.config.isSaveSessionToApp == 1 && $.config.appSStorageKey && $.config.appSStorageKey.indexOf(key) > -1) {
                //增加模块前缀标识
                if (isModulesShare) {
                    key = "_share|" + key;
                } else {
                    key = $.config.storagePrefix + "|" + key;
                }
                var param = {
                    funcNo: "50040",
                    key: key,
                    value: '',
                    time: 0
                }
                $.callMessage(param)
            } else {
                if (key === true) {
                    sessionStorage.clear();
                    var oAllCookies = $.cookieUtils.all();
                    for (var p in oAllCookies) {
                        if (p.indexOf($.config.storagePrefix + "|") != -1) {
                            $.cookieUtils.remove(p);
                        }
                    }
                } else {
                    if (key) {
                        if (isModulesShare) {
                            sessionStorage.removeItem("_share|" + key);
                            if ($.cookieUtils.enabled()) {
                                $.cookieUtils.remove("_share|" + key);
                            }
                        } else {
                            sessionStorage.removeItem($.config.storagePrefix + "|" + key);
                            if ($.cookieUtils.enabled()) {
                                $.cookieUtils.remove($.config.storagePrefix + "|" + key);
                            }
                        }
                    } else {
                        for (var pkey in sessionStorage) {
                            if (pkey.indexOf($.config.storagePrefix + "|") != -1) {
                                sessionStorage.removeItem(pkey);
                                if ($.cookieUtils.enabled()) {
                                    $.cookieUtils.remove(pkey);
                                }
                            }
                        }
                    }
                }
            }
        } catch (e) {
            $.alert("您的浏览器版本太低，或者您开启了隐身/无痕浏览模式，或者WebView组件不支持sessionStorage！");
            try {
                point(JSON.stringify({
                    pageId:location.href,
                    key:key, 
                    type:'sessionStorage.clear'
                }));
            } catch (error) {}
        }
    }

    /**
     * 清除sessionStorage中的数据，这里分3种情况：
     * 1、如果不传key，则清除当前模块的sessionStorage数据
     * 2、如果key为字符串变量，则模糊清除当前模块的sessionStorage数据
     * 3、如果key为Boolean类型变量true，则清除同一站点下所有模块的sessionStorage数据（支持多模块）
     * @parm key 保存时的key，为 true时，清空sessionStorage
     * @parm isModulesShare true/false 是否多模块共享，不传默认为false
     */
    $.clearLikeSStorage = function (key, isModulesShare) {
        try {
            if (key == true || !$.isValue(key)) {
                $.clearSStorage(key, isModulesShare);
            } else {
                //增加模块前缀标识
                var moduleTag = "";
                if (isModulesShare) {
                    moduleTag = "_share|";
                } else {
                    moduleTag = $.config.storagePrefix + "|";
                }
                var sessionKeys = Object.keys(sessionStorage);
                for (var i = 0; i < sessionKeys.length; i++) {
                    if (sessionKeys[i].indexOf(moduleTag) > -1 && sessionKeys[i].indexOf(key) > -1) {
                        $.clearSStorage(sessionKeys[i].replace(moduleTag, ""), isModulesShare);
                    }
                }
            }
        } catch (e) {
            $.alert("清理sessionStorage失败！key=" + key);
        }
    }

    /**
     * 页面的事件绑定处理
     * @parm ele 页面元素
     * @param eMethod 处理函数
     * @param etype 事件类型，pc 默认 click，移动端默认 tap
     * @param fn 函数类型  返回true或false,返回false时会禁止点击事件
     */
    $.bindEvent = function (ele, eMethod, eType, fn) {
        var isgo = (fn === undefined || fn === '') ? true : fn();
        if (!isgo) {
            return false;
        }
        eType = eType ? eType : 'click'
        $(ele).off(eType);
        $(ele).each(function () {
            // 计算时间的目的是防止多次点击
            var timeInv = 0;
            var _eMethod = $.bindFunc(eMethod, this);
            var eventFunc = function (e) {
                if (eType.toLowerCase() == "tap" || eType.toLowerCase() == "click" || eType.toLowerCase() == "mousedown" || eType.toLowerCase() == "touchstart") {
                    var time = new Date().getTime();
                    if (time - timeInv > 400) {
                        _eMethod(e);
                        timeInv = time;
                    }
                } else {
                    _eMethod(e);
                }
            };
            $(this).on(eType, eventFunc);
        });
    }
    /**
     * 页面元素预绑定事件，预绑定需要知道父容器
     * @parm parentEle 页面负载元素
     * @parm eleSelc 预绑定元素选择器
     * @param eMethod 处理函数
     * @param etype 事件类型，pc 默认 click，移动端默认 tap
     */
    $.preBindEvent = function (parentEle, eleSelc, eMethod, eType) {
        eType = eType ? eType : 'click'
        $(parentEle).off(eType, eleSelc);
        $(parentEle).each(function () {
            // 计算时间的目的是防止多次点击
            var timeInv = 0;
            var eventFunc = function (e) {
                var _eMethod = $.bindFunc(eMethod, this);
                if (eType.toLowerCase() == "tap" || eType.toLowerCase() == "click" || eType.toLowerCase() == "mousedown" || eType.toLowerCase() == "touchstart") {
                    var time = new Date().getTime();
                    if (time - timeInv > 400) {
                        _eMethod(e);
                        // 防止预绑定事件的传播
                        if (e.isPropagationStopped()) e.stopImmediatePropagation();

                        timeInv = time;
                    }
                } else {
                    _eMethod(e);
                    // 防止预绑定事件的传播
                    if (e.isPropagationStopped()) e.stopImmediatePropagation();
                }
            };
            $(this).on(eType, eleSelc, eventFunc);
        });
    }

    /**
     * 重写框架pageRefresh  框架没有绑定bindPageEvent事件
     */
    $.pageRefresh = function (b) {
        b = b || $.getCurrentPageObj().scriptUrl,
        b && seajs.use(b, function (a) {
            a && a.destroy && a.destroy(),
            a && a.init && a.init(),
            a && a.bindEvent && a.bindEvent(),
            a && a.bindPageEvent && a.bindPageEvent(),
            a && a.load && a.load()
        })
    }

    /**
     * 是否需要发送关闭push消息
     * @param {*} curPage   当前页面
     * @param {*} nextPage  跳转页面
     * @param {*} type      1跳转0返回
     */
    $.isClosePushWebView = function (curPage, nextPage, type) {
        var appName = $.getSStorageInfo("app_third");
        var appMainPage = $.getSStorageInfo("app_third_mainpage");
        var pageObj = $.getCurrentPageObj() || {};
        clearNsbStorageInfo(nextPage, pageObj);
        var flag = false;

        if (type == 1) {
            if ($.getPageParam("isFromApp") || appName == 'native') {
                if (nextPage == "account/index") flag = true;
            }
        } else {
            if (pageObj.pageId == appMainPage || $.getPageParam("isFromApp")) flag = true;
        }
        return flag;
    }

    /**
     * 清理新股申购相关的缓存信息
     * @param nextPage
     * @param pageObj
     */
    function clearNsbStorageInfo(nextPage, pageObj) {
        if (nextPage == "nsb/index") {
            var curId = pageObj.pageId;
            if (curId != "nsb_detail"
                && curId != "nsb_calendar"
                && curId != "nsb_help"
                && curId != "nsb_sgjk"
                && curId != "nsb_result"
                && curId != "nsb_commonPro"
                && curId != "debtzg_converHS"
                && curId != "credit_debtzg_converHS"
                && curId != "nsb_agreement") {
                $.setSStorageInfo("switchUserInfo", "", true);
                $.setSStorageInfo("isFirstIn", "", true);
                $.setSStorageInfo("selectIndex", "", true);
                $.setSStorageInfo("stockListSize", "", true);
                $.setSStorageInfo("bondListSize", "", true);
                $.setSStorageInfo("nsb_isCalendarStocks","",true);
                $.setSStorageInfo("nsb_calendar","",true);
                $.setSStorageInfo("nsb_stock_code","",true);
                $.setSStorageInfo("nsb_market","",true);
                $.setSStorageInfo("nsb_calendar","",true);
            }
        }
    }

    $.pushWebViewBack = function () {
        var uri = $.getCurrentPageObj().scriptUrl;
        if (uri) {
            seajs.use(uri, function (page) {
                page && page.destroy && page.destroy();
                $.callMessage({"moduleName": "push", "funcNo": "50114", "params": {}});
            });
        } else {
            $.callMessage({"moduleName": "push", "funcNo": "50114", "params": {}});
        }
    }

    /**
     * 重写框架的pageBack
     */
    var pageBack = $.pageBack;
    $.pageBack = function () {
        if ($.isClosePushWebView()) {
            $.pushWebViewBack();
        } else {
            pageBack.apply(this, arguments)
        }
    }
}($);
