/**
 * 交易模块公用方法js  （涉及到业务接口的调用）
 */
define('trade/scripts/common/commonFunc.js', function (require, exports, module) {
    var gconfig = $.config;
    var global = gconfig.global;
    var common = require("common");
    var service_hq = require("service_hq");
    if (global.hqCallInterface == 1) {
        service_hq = require("service_hqTrade");
    }
    var service_zhyw = require("service_zhyw");
    var service_stock = require("service_stock");
    var service_fund = require("service_fund");
    var service_native_sync = require("service_native_sync");
    var service_xkj = require("service_xkj");
    var service_common = require("service_common");
    var nativePluginService = require("nativePluginService");
    var dateUtils = require("mobiscrollUtils");
    require("rsa");
    require("base64");
    require("endecryptUtils");
    var endecryptUtils = $.endecryptUtils;
    var modulus = null;
    var publicExponent = null;
    var tradingTime = true;
    var checkTradeTimer = null;


    /**
     * 股票小数保留位数
     */
    function decimalKeep(stockCode, callback) {  //小数保留
        var KEEP_TWO = 3;
        var param = {
//				"code_list" : stockCode
            "q": stockCode
        };
        service_hq.getStockList(param, function (data) {
            if (data.errorNo == "0") {
                var results = data.results;
                if (results && results.length > 0) {
                    var stkType = results[0][10];  // 行情类别
                    var stockVal = results[0][1];
                    var price_step_const = [0, 1, 2, 7, 9, 15, 18, 25, 26, 27]; // 保留两位
                    var step_flag = $.inArray(stkType, price_step_const);
                    // 上海国债逆回购
                    if (stockVal.substring(0, 3) == "204") {
                        KEEP_TWO = 3
                    }
                    // 否则浮动为0.01
                    else if (step_flag == -1) {
                        KEEP_TWO = 3;
                    }
                    // 变动价格为0.001
                    else {
                        KEEP_TWO = 2;
                    }
                    callback(KEEP_TWO, results[0]);
                } else {
                    callback(KEEP_TWO, ['', stockCode]);
                }
            } else {
                callback(KEEP_TWO, ['', stockCode]);
                $.alert("获取股票信息失败");
            }
        }, {
            "isShowWait": false, "timeOutFunc": function () {
                callback(KEEP_TWO, ['', stockCode]);
            }, "errorFunc": function () {
                callback(KEEP_TWO, ['', stockCode]);
            }
        });
    }

    /**
     * 取行情服务器时间
     * @param {Object} isAsync 是否异步请求
     * @param {Object} callback 回调
     */
    function getServerTime(isAsync, callback) {
        isAsync = isAsync ? false : true;
        var dates = {};
        var localDate = new Date();
        dates["dateTime"] = localDate.format("yyyy-MM-dd HH:mm:ss");
        dates["date"] = localDate.format("yyyy-MM-dd");
        dates["time"] = localDate.format("HH:mm:ss");
        dates["Date"] = localDate;
        service_stock.getHqState({}, function (data) {
            if (data) {
                var results = data.results;
                if (results && results[0]) {
					var s = results[0].date_time+"" || "";
                    var date = "";
                    var time = "";
                    if (s.length > 7) {
                        date = s.slice(0, 4) + "-" + s.slice(4, 6) + "-" + s.slice(6, 8);
                    }
                    if (s.length == 14) {
                        time = s.slice(8, 10) + ":" + s.slice(10, 12) + ":" + s.slice(12);
                    }
                    var dateTime = date + " " + time;
                    dates["dateTime"] = dateTime;
                    dates["date"] = date;
                    dates["time"] = time;

                    var serverDate = dateTime.replace(/-/g, "/");
                    $.setSStorageInfo("_simulationTime", localDate.getTime() + "|" + serverDate);

                    dates["Date"] = new Date(serverDate);

                    isTradingTime(dates);
                    dates["tradingF"] = true;

                    if (callback) {
                        callback(dates);
                    }
                } else {
                    if (callback) {
                        callback(dates);
                    }
                }
            } else {
                if (callback) {
                    callback(dates);
                }
            }
        }, {
            "isAsync": isAsync,
            "isShowWait": false,
            "isShowOverLay": false,
            "isGlobal": true,
            "timeOutFunc": function () {
                if (callback) {
                    callback(dates);
                }
            }, "errorFunc": function () {
                if (callback) {
                    callback(dates);
                }
            }
        });
        return dates;
    }


    /**
     * 取行模拟计算的时间
     * @param {Object} isAsync 是否异步请求
     * @param {Object} callback 回调
     */
    function simulationTime(isAsync, callback) {
        var s = new Date().getTime();
        var simulationTime = $.getSStorageInfo("_simulationTime") || "";
        simulationTime = simulationTime.split("|");
        var lastDoTime = s - Number(simulationTime[0]);
        if (global.syncServerTime && lastDoTime > 60000 * global.syncServerTime) {
            return getServerTime(isAsync, callback);
        } else {
            var serverDate = new Date(simulationTime[1]).getTime();
            var localDate = new Date(serverDate + lastDoTime);
            var dates = {};
            dates["dateTime"] = localDate.format("yyyy-MM-dd HH:mm:ss");
            dates["date"] = localDate.format("yyyy-MM-dd");
            dates["time"] = localDate.format("HH:mm:ss");
            dates["Date"] = localDate;
            if (callback) {
                callback(dates);
            }
            return dates;
        }
    }

    function initCheckTradeTimer() {
        if (checkTradeTimer == null) {
            simulationTime(false, isTradingTime);
            //启动是否是交易时间检查定时器
            checkTradeTimer = window.setInterval(function () {
                if (common.isAppFlag()) {
                    simulationTime(false, isTradingTime);
                }
            }, global.checkTradeTime * 60000); // 5秒检测一次
        }
    }

    function clearCheckTradeTimer() {
        if (checkTradeTimer != null) {
            window.clearInterval(checkTradeTimer);
            checkTradeTimer = null;
        }
    }

    function getTradingTime() {
        return tradingTime;
    }

    /***
     * 判断是否是交易时间
     * @param {Object} type
     */
    function isTradingTime(dates) {
        dates = dates || simulationTime();
        if (!dates.tradingF) {
            var xq = dates.Date.getDay();
            var time = dates.time;
            if (timeComparison(time, "08:50") >= 0 && timeComparison(time, "15:40") <= 0) {
                tradingTime = true;
            } else {
                tradingTime = false;
            }
        }
        return tradingTime;
    }


    /***
     * 判断是否是交易时间
     * @param {Object} type
     */
    function isTradingTimes(type, dates) {
        if (!type && !dates) {
            return isTradingTime();
        } else {
            dates = dates || simulationTime();
            if (dates["Date"]) {
                var xq = dates.Date.getDay();
                if (xq == 6 || xq == 0) {
                    return false;
                }
                if (!dates["time"]) {
                    dates["time"] = dates["Date"].format("HH:mm:ss");
                }
            } else {
                type = type + "";
                var time = dates.time;
                var isTrading = false;
                var tradingtimes = [['09:00', "15:00"]];
                switch (type) {
                    case "0":
                        tradingtimes = [['09:00', "12:00"], ['13:00', "15:00"]];
                        break;
                    case "1":
                        tradingtimes = [['09:00:00', "12:00:00"], ['13:00:00', "16:00:00"]];
                        break;
                }
                for (var i = 0; i < tradingtimes.length; i++) {
                    if (timeComparison(time, tradingtimes[i][0]) >= 0 && timeComparison(time, tradingtimes[i][1]) <= 0) {
                        isTrading = true;
                        break;
                    }
                }
                return isTrading;
            }
        }
    }

    function timeComparison(a, b) {
        a = (a || '').split(":");
        b = (b || '').split(":");
        a = Number(a[0] || 0) * 60 * 60 + Number(a[1] || 0) * 60 + Number(a[2] || 0);
        b = Number(b[0] || 0) * 60 * 60 + Number(b[1] || 0) * 60 + Number(b[2] || 0);
        return a - b;
    }

    /**
     * 获取当前日前后几天的日期
     * @param {Number} days 天数 正数为后几天，负数为前几天
     * @param {String} format 时间显示格式
     */
    function getTradingDay(days, format) {
        format = format ? format : "yyyy-MM-dd";
        var end_time = new Date();	//截止时间
        end_time.setDate(end_time.getDate() + days);
        return end_time.format(format);
    }

    /**
     * 初始化日期选择组件
     * @param {Object} pageId
     * @param {Object} timeLimit 默认查询天数
     * @param {Boolean} notContainToday 不包含今天
     */
    function initTimeChoice(pageId, timeLimit, notContainToday) {
        if (!timeLimit) {
            timeLimit = 0;
        }
        var begin_time = getTradingDay(0 - timeLimit, "yyyy-MM-dd");	//截止时间
        var end_time = new Date().format("yyyy-MM-dd");
        if (notContainToday) {
            begin_time = getTradingDay(0 - timeLimit - 1, "yyyy-MM-dd");
            end_time = getTradingDay(-1, "yyyy-MM-dd");
        }
        $(pageId + " #startDate").html(begin_time);
        $(pageId + " #endDate").html(end_time);
        $(pageId + " #startInput").val(begin_time);
        $(pageId + " #endInput").val(end_time);
        //初始化时间控件
        //初始化时间控件
        $(pageId + " #startInput").datetimePicker({
            toolbarTemplate: '<header class="bar bar-nav"><button class="button button-link pull-right close-picker">确定</button><div class="titlehsea">选择日期开始日期</div></header>',
            "onClose": function (e) {
                //埋点
                var objectId = $(pageId + " .date_filter").attr("startObjectId");
                var actionId = $(pageId + " .date_filter").attr("actionId");
                var thisVal = $(pageId + " #startDate").html();
                if (objectId && actionId) {
                    thisVal = thisVal.toString();
                    common.comStat(objectId, 2, actionId, true, {
                        "i_change_name": "开始日期选择",
                        "i_change_to": thisVal ? (thisVal.replaceAll("-", "")) : thisVal
                    });
                }
            }
        });
        $(pageId + " #endInput").datetimePicker({
            toolbarTemplate: '<header class="bar bar-nav"><button class="button button-link pull-right close-picker">确定</button><div class="titlehsea">选择日期截止日期</div></header>',
            "onClose": function (e) {
                //埋点
                var objectId = $(pageId + " .date_filter").attr("endObjectId");
                var actionId = $(pageId + " .date_filter").attr("actionId");
                var thisVal = $(pageId + " #endDate").html();
                if (objectId && actionId) {
                    thisVal = thisVal.toString();
                    common.comStat(objectId, 2, actionId, true, {
                        "i_change_name": "结束日期选择",
                        "i_change_to": thisVal ? (thisVal.replaceAll("-", "")) : thisVal
                    });
                }
            }
        });


        //设置开始日期
        $.bindEvent($(pageId + " #setStart"), function (e) {
            var d = $(pageId + " #startInput").val().split("-");
            $(pageId + " #startInput").data("picker").value = d;
            $(pageId + " #startInput").data("picker").params.value = d;
            $(pageId + " #startInput").picker("open");
//			$(pageId + " #startInput").focus();
            e.stopPropagation();
        });

        //设置截止日期
        $.bindEvent($(pageId + " #setEnd"), function (e) {
            var d = $(pageId + " #endInput").val().split("-");
            $(pageId + " #endInput").data("picker").value = d;
            $(pageId + " #endInput").data("picker").params.value = d;
            $(pageId + " #endInput").picker("open");
            e.stopPropagation();
        });


        $.bindEvent($(pageId + " #startInput"), function (e) {
            var reg = /^\d{4}-\d{2}-\d{2}$/,
                thisVal = $(this).val().replaceAll("/", "-");
            if (reg.test(thisVal)) {
                $(pageId + " #startDate").html(thisVal);
            }
            e.stopPropagation();
        }, "change");

        $.bindEvent($(pageId + " #endInput"), function (e) {
            var reg = /^\d{4}-\d{2}-\d{2}$/,
                thisVal = $(this).val().replaceAll("/", "-");
            if (reg.test(thisVal)) {
                $(pageId + " #endDate").html(thisVal);
            }
            e.stopPropagation();
        }, "change");
    }


    /**
     * 获取密码要
     * @param {Object} data
     * @param {Object} callback
     */
    function getKey(callback, data) {
        modulus = $.getSStorageInfo("modulus");
        publicExponent = $.getSStorageInfo("publicExponent");
        $.showPreloaders("请等待...");
        if (modulus && publicExponent) {
            if (callback) {
                if (data) {
                    if (typeof (data) == "string") {
                        if (data && $.trim(data) != "") {
                            data = endecryptUtils.rsaEncrypt(modulus, publicExponent, $.trim(data));
                        } else {
                            data = "";
                        }
                    } else if (typeof (data) == "object" && common.size(data) > 0) {
                        $.each(data, function (key, value) {
                            if (value && $.trim(value) != "") {
                                data[key] = endecryptUtils.rsaEncrypt(modulus, publicExponent, $.trim(value));
                            } else {
                                data[key] = "";
                            }
                        });
                    }
                }
                callback(data);
            }
        } else {
            service_common.getKey({}, function (d) {
                if (d && d.error_no == "0" && d.results[0]) {
                    modulus = d.results[0].modulus;
                    publicExponent = d.results[0].publicExponent;
                    $.setSStorageInfo("modulus", modulus);
                    $.setSStorageInfo("publicExponent", publicExponent);
                    if (callback) {
                        if (data) {
                            if (typeof (data) == "string") {
                                if (data && $.trim(data) != "") {
                                    data = endecryptUtils.rsaEncrypt(modulus, publicExponent, $.trim(data));
                                } else {
                                    data = "";
                                }
                            } else if (typeof (data) == "object" && common.size(data) > 0) {
                                $.each(data, function (key, value) {
                                    if (value && $.trim(value) != "") {
                                        data[key] = endecryptUtils.rsaEncrypt(modulus, publicExponent, $.trim(value));
                                    } else {
                                        data[key] = "";
                                    }
                                });
                            }
                        }
                        callback(data);
                    }
                }
            }, {
                "isLastReq": false, "isShowWait": false,
                "timeOutFunc": function () {
                    $.hidePreloader();
                }, "errorFunc": function () {
                    $.hidePreloader();
                }
            });
        }
    }

    function setStockAccount(userInfo, callback) {
        var param = {
            "entrust_way": global.entrust_way,
            "branch_no": userInfo.branch_no,
            "fund_account": userInfo.fund_account,
            "cust_code": userInfo.cust_code,
            "password": userInfo.password,
            "session_id": userInfo.session_id,
            "account_type": userInfo._loginClass,
        };
        service_common.queryStockAccountList(param, function (data) {
            $.hidePreloader();
            if (data) {
                if (data.error_no == 0) {
                    var results = data.results;
                    if (results && results.length > 0) {
                        var stockAccount = results;
                        var key = "gd|" + userInfo._loginClass + "|" + userInfo._uniqueness;
                        $.setSStorageInfo(key, JSON.stringify(stockAccount), false, {
                            "shareCookie": global.shareCookie,
                            "isEncrypt": global.shareCookie,
                            "isSaveSession": !global.shareCookie
                        });// 信用普通
                        var _jurisdiction = "|";
                        for (var i = 0; results && i < results.length; i++) {
                            _jurisdiction += results[i].exchange_type + "|";
                        }
                        $.setSStorageInfo("_jurisdiction", _jurisdiction, false, {
                            "shareCookie": global.shareCookie,
                            "isSaveSession": !global.shareCookie
                        }); // 保存登录成功状态
                    }
                }
            }
            if (callback) {
                callback();
            }
        }, {
            "isShowWait": false,
            "isLastReq": false,
            "isShowOverLay": false,
            "isGlobal": true,
            "errorFunc": function () {
                $.hidePreloader();
                if (callback) {
                    callback();
                }
            },
            "timeOutFunc": function () {
                $.hidePreloader();
                if (callback) {
                    callback();
                }
            }
        });
    }


    function getStockAccount(type, userInfo, callback, isExclude) {
        if (!$.isValue(userInfo)) {
            userInfo = common.getCurUserInfo();
        }
        var key = "gd|" + userInfo._loginClass + "|" + userInfo._uniqueness;
        var stockAccount = $.getSStorageInfo(key, false, {"isDecrypt": global.shareCookie}) || "";
        if (stockAccount) {
            stockAccount = JSON.parse(stockAccount);
        }
        if (!$.isValue(stockAccount) && callback) {
            setStockAccount(userInfo, function () {
                var stockAccount = $.getSStorageInfo(key, false, {"isDecrypt": global.shareCookie});
                if (stockAccount) {
                    stockAccount = JSON.parse(stockAccount);
                }
                var r = judgeStockAccount(type, stockAccount, isExclude);
                if (callback) {
                    callback(r);
                }
            });
        } else {
            var r = judgeStockAccount(type, stockAccount, isExclude);
            if (callback) {
                callback(r);
            }
            return r;
        }
    }

    /**
     exchange_type    varchar(4)    交易市场类别（见数据字典)
     * holder_kind    varchar(1)    账户类别（见数据字典）
     main_flag    varchar(1)    主账标志(0:否，1：是)
     holder_status    varchar(1)    账户状态（见数据字典）

     * @param {Object} type 交易市场类别|账户类别|主账标志|账户状态
     * @param {Object} stockAccount
     */
    function judgeStockAccount(types, stockAccount, isExclude) {
        if (types) {
            if (isExclude) {
                var z = [];
                var juds = function (type) {
                    var t = type.split("|");
                    var exchange_type = t[0] ? t[0] : "";
                    var holder_kind = t[1] ? t[1] : "";
                    var main_flag = t[2] ? t[2] : "";
                    var holder_status = t[3] ? t[3] : "";
                    for (var i = 0; stockAccount && i < stockAccount.length; i++) {
                        if (exchange_type && exchange_type != stockAccount[i].exchange_type) {
                            continue;
                        }
                        if (holder_kind && holder_kind != stockAccount[i].holder_kind) {
                            continue;
                        }
                        if (main_flag && main_flag != stockAccount[i].main_flag) {
                            continue;
                        }
                        if (holder_status && holder_status != stockAccount[i].holder_status) {
                            continue;
                        }
                        stockAccount[i] = {};
                    }
                }
                if (types instanceof Array && types.length > 0) {
                    for (var y = 0; y < types.length; y++) {
                        juds(types[y]);
                    }
                } else {
                    juds(types);
                }
                for (var i = 0; stockAccount && i < stockAccount.length; i++) {
                    if (stockAccount[i] && stockAccount[i].stock_account) {
                        z.push(stockAccount[i]);
                    }
                }
                return z;
            } else {
                var z = [];
                var juds = function (type) {
                    var t = type.split("|");
                    var exchange_type = t[0] ? t[0] : "";
                    var holder_kind = t[1] ? t[1] : "";
                    var main_flag = t[2] ? t[2] : "";
                    var holder_status = t[3] ? t[3] : "";
                    for (var i = 0; stockAccount && i < stockAccount.length; i++) {
                        if (exchange_type && exchange_type != stockAccount[i].exchange_type) {
                            continue;
                        }
                        if (holder_kind && holder_kind != stockAccount[i].holder_kind) {
                            continue;
                        }
                        if (main_flag && main_flag != stockAccount[i].main_flag) {
                            continue;
                        }
                        if (holder_status && holder_status != stockAccount[i].holder_status) {
                            continue;
                        }
                        z.push(stockAccount[i]);
                    }
                }
                if (types instanceof Array && types.length > 0) {
                    for (var y = 0; y < types.length; y++) {
                        juds(types[y]);
                    }
                } else {
                    juds(types);
                }
                return z;
            }
        } else {
            return stockAccount;
        }
    }

    /**
     * 科创板权限校验
     */
    function kcbJurisdiction(login_type, userInfo, callBack) {
        if (!$.isValue(userInfo)) {
            userInfo = common.getCurUserInfo();
        }
        var param = {
            "entrust_way": global.entrust_way,
            "branch_no": userInfo.branch_no,
            "fund_account": userInfo.fund_account,
            "cust_code": userInfo.cust_code,
            "password": userInfo.password,
            "session_id": userInfo.session_id,
            "login_type": login_type,
        };
        service_common.stockKcbJurisdiction(param, function (data) {
            var _rights = "";
            if (data) {
                if (data.error_no == 0) {
                    var results = data.results;
                    if (results && results.length > 0) {
                        _rights = results[0].technology_innovation_rights;//科创板权限（1无权限，0有权限）
                    }
                }
            }
            if (callBack) {
                callBack(_rights);
            }
        }, {
            "isShowWait": false,
            "isLastReq": false,
            "isShowOverLay": false,
            "isGlobal": true,
            "errorFunc": function () {
                if (callBack) {
                    callBack();//无权限
                }
            },
            "timeOutFunc": function () {
                if (callBack) {
                    callBack();//无权限
                }
            }
        });
    }

    /**
     * 权限信息的查询
     * userInfo 用户信息
     * callBack    查询成功后的回调处理
     */
    function setJurisdiction(userInfo, callBack) {
        if (!$.isValue(userInfo)) {
            userInfo = common.getCurUserInfo();
        }
        //获取缓存的权限信息
        var key = "qx|" + userInfo._loginClass + "|" + userInfo._uniqueness;
        var jurisdictionList = $.getSStorageInfo(key, false, {"isDecrypt": global.shareCookie}) || {};
        if ($.isValue(jurisdictionList)) {
            jurisdictionList = JSON.parse(jurisdictionList);
        } else {//缓存中为空，新增查询失败的字段
            jurisdictionList.IsQuerySuccess = false;
        }
        // if(jurisdictionList.IsQuerySuccess){
        // 	callBack && callBack(jurisdictionList);
        // 	return jurisdictionList;
        // }
        var param = {
            "entrust_way": global.entrust_way,
            "branch_no": userInfo.branch_no,
            "fund_account": userInfo.fund_account,
            "cust_code": userInfo.cust_code,
            "password": userInfo.password,
            "session_id": userInfo.session_id,
            "login_type": userInfo._loginClass
        };
        var queryCallback = function (data) {
            if (data) {
                if (data.error_no == 0) {
                    var results = data.results;
                    if (results && results.length > 0) {
                        delete jurisdictionList.IsQuerySuccess;
                        //缓存中为空，全量更新
                        if (!$.isValue(jurisdictionList)) {
                            jurisdictionList = results[0];
                        } else {//增量更新
                            for (index in results[0]) {
                                jurisdictionList[index] = results[0][index];//当前遍历的权限字段
                            }
                        }
                        jurisdictionList.IsQuerySuccess = true;
                    }
                }
            }
            if (callBack) {
                callBack(jurisdictionList);
            }
            $.setSStorageInfo(key, JSON.stringify(jurisdictionList), false, {
                "shareCookie": global.shareCookie,
                "isEncrypt": global.shareCookie,
                "isSaveSession": !global.shareCookie
            });
        }
        service_common.queryJurisdiction(param, queryCallback, {
            "isShowWait": false,
            "isLastReq": false,
            "timeout": global.stockTimeout,
            "isShowOverLay": false,
            "isGlobal": true,
            "errorFunc": function () {
                if (callBack) {
                    callBack(jurisdictionList);
                }
                $.setSStorageInfo(key, JSON.stringify(jurisdictionList), false, {
                    "shareCookie": global.shareCookie,
                    "isEncrypt": global.shareCookie,
                    "isSaveSession": !global.shareCookie
                });
            },
            "timeOutFunc": function () {
                if (callBack) {
                    callBack(jurisdictionList);
                }
                $.setSStorageInfo(key, JSON.stringify(jurisdictionList), false, {
                    "shareCookie": global.shareCookie,
                    "isEncrypt": global.shareCookie,
                    "isSaveSession": !global.shareCookie
                });
            }
        });
    }

    /**
     * 获取权限信息
     */
    function getJurisdiction(userInfo, callBack) {
        if (!$.isValue(userInfo)) {
            userInfo = common.getCurUserInfo();
        }
        //获取缓存的权限信息
        var key = "qx|" + userInfo._loginClass + "|" + userInfo._uniqueness;
        var _jurisdiction = $.getSStorageInfo(key, false, {"isDecrypt": global.shareCookie}) || {};
        if ($.isValue(_jurisdiction)) {
            _jurisdiction = JSON.parse(_jurisdiction);
        } else {
            _jurisdiction.IsQuerySuccess = false;
        }
        if (_jurisdiction.IsQuerySuccess) {
            callBack && callBack(_jurisdiction);
        } else {
            setJurisdiction(userInfo, callBack);
        }
        return _jurisdiction;
    }


    /**
     * 股转系统——股东账号查询
     */
    function setNewStockAccount(userInfo, callback) {
        var param = {
            "entrust_way": global.entrust_way,
            "branch_no": userInfo.branch_no,
            "fund_account": userInfo.fund_account,
            "cust_code": userInfo.cust_code,
            "password": userInfo.password,
            "session_id": userInfo.session_id,
            "account_type": userInfo._loginClass,
        };
        service_common.queryNewStockAccountList(param, function (data) {
            if (data) {
                if (data.error_no == 0) {
                    var results = data.results;
                    if (results && results.length > 0) {
                        var stockAccount = results;
                        var key = "thirdgd|" + userInfo._loginClass + "|" + userInfo._uniqueness;
                        stockAccount = stockAccountSort(stockAccount);
                        $.setSStorageInfo(key, JSON.stringify(stockAccount), false, {
                            "shareCookie": global.shareCookie,
                            "isEncrypt": global.shareCookie,
                            "isSaveSession": !global.shareCookie
                        });// 信用普通
                        var _jurisdiction = "|";
                        for (var i = 0; results && i < results.length; i++) {
                            _jurisdiction += results[i].exchange_type + "|";
                        }
                        $.setSStorageInfo("_jurisdiction", _jurisdiction, false, {
                            "shareCookie": global.shareCookie,
                            "isSaveSession": !global.shareCookie
                        }); // 保存登录成功状态
                    }
                }
            }
            if (callback) {
                callback();
            }
        }, {
            "isShowWait": false,
            "isLastReq": false,
            "isShowOverLay": false,
            "isGlobal": true,
            "errorFunc": function () {
                if (callback) {
                    callback();
                }
            },
            "timeOutFunc": function () {
                if (callback) {
                    callback();
                }
            }
        });
    }

    /**
     * 股转系统——获取股东账号
     */
    function getNewStockAccount(type, userInfo, callback, isExclude) {
        if (!$.isValue(userInfo)) {
            userInfo = common.getCurUserInfo();
        }
        var key = "thirdgd|" + userInfo._loginClass + "|" + userInfo._uniqueness;
        var stockAccount = $.getSStorageInfo(key, false, {"isDecrypt": global.shareCookie}) || "";
        if (stockAccount) {
            stockAccount = JSON.parse(stockAccount);
        }
        if (!$.isValue(stockAccount) && callback) {
            setNewStockAccount(userInfo, function () {
                var stockAccount = $.getSStorageInfo(key, false, {"isDecrypt": global.shareCookie});
                if (stockAccount) {
                    stockAccount = JSON.parse(stockAccount);
                }
                var r = judgeStockAccount(type, stockAccount, isExclude);
                if (callback) {
                    callback(r);
                }
            });
        } else {
            var r = judgeStockAccount(type, stockAccount, isExclude);
            if (callback) {
                callback(r);
            }
            return r;
        }
    }

    /**
     * 股东账号排序
     * accountList    股东账号信息
     * 1、账户列表按市场（市场顺序以沪A、深A、沪B、深B、特A、特B为准，其他市场直接放到后面）
     * 2、主辅排序
     */
    function stockAccountSort(accountList) {
        if (!$.isValue(accountList)) {
            return [];//为空直接返回空
        }
        var sortArr = [], defaultArr = accountList;
        var filterArr = ["2_1", "2_0", "0_1", "0_0", "3_1", "3_0", "1_1", "1_0", "9_1", "9_0", "A_1", "A_0"];//普通交易市场顺序以沪A、深A、沪B、深B、特A、特B为准;
        for (var j = 0; j < filterArr.length; j++) {
            var arr = filterArr[j].split("_");
            for (var i = 0; i < defaultArr.length; i++) {
                var a = defaultArr[i];
                if (a.exchange_type == arr[0] && a.main_flag == arr[1]) {
                    sortArr.push(a);
                    defaultArr.splice(i, 1);
                    i = -1;
                }
            }
        }
        return sortArr.concat(defaultArr);
    }

    function newStockConfirmFunc() {// 新股弹窗
        var userInfo = common.getCurUserInfo("0");
        if (userInfo) {// 已登录
            var keyNS = [new Date().format("yyyyMMdd"), userInfo.fund_account].join("|");// 新股的key值 以日期+账户资金账号作为key存储
            var param = {
                "entrust_way": global.entrust_way,// 委托方式  在configuration配置
                "branch_no": userInfo.branch_no,
                "fund_account": userInfo.fund_account,
                "password": userInfo.password,
                "cust_code": userInfo.cust_code,
                "sessionid": userInfo.session_id,
                "cust_name": userInfo.client_name
            };
            service_common.query_GZ_NewStockList(param, function (data) {
                if (data.error_no == 0 && data.results.length > 0 && !$.getLStorageInfo(keyNS)) {
                    $.setLStorageInfo(keyNS, true);// 弹框只弹一次
                    newStockConfirm("今日股转新股", data.results, function () {
                        $.pageInit($.getCurrentPageObj().pageCode || "account/index", "third/publicOffering/recentEnquiry");// 跳转至近日询价
                    }, null, "一键打新", "我知道了");
                }
            }, {"isShowWait": false, "isGlobal": true});
        }
    }

    /**
     * 新股弹窗
     * */
    function newStockConfirm(title, results, yesFunc, noFunc, yesBtnWords, noBtnWords) {
        $("#newstock_confirm").remove();
        var pageId = '#' + $.getCurrentPageObj().pageId;
        var viewContent = "<div id='newstock_confirm'>";
        viewContent += "<div class='overlay-layer'></div>";
        viewContent += "<div class='overlay-cont' style='margin-top: -1.5rem;'>";
        viewContent += (title ? "<h2>" + title + "</h2>" : "");
        viewContent += "	<ul class='list_box'>";
        for (var i = 0; i < results.length; i++) {
            viewContent += "<li>" + (results[i].stock_name || '--') + "<span>" + (results[i].stock_code || '--') + "</span></li>";
        }
        viewContent += "	</ul>";
        viewContent += (yesBtnWords ? " <div class='btn_box' style='margin-top: 0.25rem;'><a href='javascript:void(0);'>" + yesBtnWords + "</a></div>" : "");
        viewContent += (noBtnWords ? " <p class='tip'><a href='javascript:void(0);'>" + noBtnWords + "</a></p>" : "");
        viewContent += "</div>";
        viewContent += "</div>";
        $(pageId).append(viewContent);

        $.preBindEvent($("body #newstock_confirm .btn_box a"), function (e) {
            $(this).unbind();
            $(pageId + " #newstock_confirm").remove();
            if (yesFunc) {
                yesFunc();
            }
            e.stopPropagation();
        });

        $.preBindEvent($("body #newstock_confirm p.tip"), function (e) {
            $(this).unbind();
            $(pageId + " #newstock_confirm").remove();
            if (noFunc) {
                noFunc();
            }
            e.stopPropagation();
        });
    }


    function appThirdBack(pageCode, callback) {
        var appName = $.getSStorageInfo("app_third");
        var appMainPage = $.getSStorageInfo("app_third_mainpage");
        if (appName == 'znzd') { // 智能账单返回
            if (['stock_stockHolding', 'credit_asset_asset', 'option_position_holdingsQuery'].indexOf(appMainPage) > -1) {
                if (['stock_stockBuy', 'stock_stockSell', 'stock_stockCancel', 'stock_stockHolding', 'stock_stockQuery',
                    'credit_asset_asset', 'credit_order_mainOrder', 'credit_transferred_collateralTransfer', 'credit_query_financingQuery',
                    'option_position_holdingsQuery'].indexOf(pageCode) == -1
                ) {
                    callback && callback();
                } else {
                    $.callMessage({"moduleName": "znzd_trade", "funcNo": "50114", "params": {}});
                }
            } else if (['banking_transfer','banking_transferNew'].indexOf(appMainPage) > -1) {
                if (['banking_transfer','banking_transferNew'].indexOf(pageCode) == -1) {
                    callback && callback();
                } else {
                    $.callMessage({"moduleName": "znzd_trade", "funcNo": "50114", "params": {}});
                }
            } else {
                $.callMessage({"moduleName": "znzd_trade", "funcNo": "50114", "params": {}});
            }
        } else if (appName == 'native') { // 原生app返回
            if (['shares_oneKeyPurchase', 'purchaseNewDebt_newPurchase'].indexOf(appMainPage) > -1) {
                if (['shares_oneKeyPurchase', 'shares_distribution', 'shares_success', 'shares_more',
                    'purchaseNewDebt_newPurchase', 'purchaseNewDebt_newDistribution', 'purchaseNewDebt_newSuccess', 'purchaseNewDebt_newMore',
                ].indexOf(pageCode) == -1
                ) {
                    callback && callback();
                } else {
                    $.callMessage({"moduleName": "push", "funcNo": "50114", "params": {}});
                }
            } else if (['third/thirdJurisdiction', 'third_publicOffering_recentEnquiry', 'third_publicOffering_todayPurchase', 'third_publicOffering_myDeclare', 'third_publicOffering_enquiryConfirm'].indexOf(pageCode) > -1) {
                $.callMessage({"moduleName": "push", "funcNo": "50114", "params": {}});
            } else {
                callback && callback();
            }
        } else if(appName && appName.indexOf('mall') > -1) {
            $.callMessage({"moduleName": "push", "funcNo": "50114", "params": {}});
        } else {
            callback && callback();
        }
    }

    // 权限提示框
    function popupRightsConfirm(results, opts) {
        var userInfo = common.getCurUserInfo();
        if (results && userInfo) {
            getJurisdiction(userInfo, function (jurisdiction) {
                if (opts.checkCyb) {
                    popupRightsCybConfirm(results, jurisdiction);
                }
                if (opts.checkKzz) {
                    popupRightsKzzConfirm(results, jurisdiction);
                }
                if(opts.ckeckReits){
                    popupRightsReitsConfirm(results,jurisdiction)
                }
                if(opts.ckeckCreditReits){
                    popupRightsCreditReitsConfirm(results,jurisdiction)
                }
                if(opts.registerUser){
                    popupRegisterUser(results,jurisdiction)
                }
            });
        }
    }

    function popupRightsCybConfirm(results, jurisdiction) {
        var userInfo = common.getCurUserInfo();
        if (results && userInfo && jurisdiction) {
            var isOpenGemPerm = jurisdiction.gem_rights_switch == 1; // 是否开启创业板权限校验
            var stock_type = results.stock_type;
            if (jurisdiction.prof_flag != "1" && isOpenGemPerm && stock_type) {
                var gem_rights = results.gem_rights || jurisdiction.gem_rights;
                var gem_register_rights = results.gem_register_rights || jurisdiction.gem_register_rights;
                if (((stock_type == "f" && gem_rights == "0" && gem_register_rights != "1") || (["p", "q"].indexOf(stock_type) >= 0 && gem_register_rights == "0"))) {  //创业板
                    common.iConfirm("温馨提示", gem_rights == "0" ? "您尚未开通创业板权限，如需进行交易，请到业务办理完成对应权限开通。" : "尊敬的投资者您好，您无创业板注册制证券的交易权限，请到业务办理完成对应权限的开通。", function success(html) {
                        if (global.callNative && global.isSso) {
                            var param = {
                                "funcNo": "50500",
                                "msgNo": "123",
                                "sourceModule": "",
                                "targetModule": "tradeDispatcher",
                                "action": "1",
                                "param": {
                                    "business_type": userInfo._loginClass,//普通0  两融1
                                    "event": gem_rights == "0" ? "9" : "10",//打开权限开通页面
                                    "title": "",
                                }
                            }
                            $.callMessage(param);
                        }
                    }, function fail() {
                    }, "开通权限", "取消");
                }
            }
        }
    }

    // 可转债权限提示框
    function popupRightsKzzConfirm(results, jurisdiction) {
        var userInfo = common.getCurUserInfo();
        if (results && userInfo && jurisdiction) {
            var stock_type = results.stock_type;
            if (stock_type) {
                var convertible_bonds_rights;
                if (["7","18","19"].indexOf(stock_type) > -1 && results.exchange_type == "0") {
                    convertible_bonds_rights = results.convertible_bonds_rights_sz || jurisdiction.convertible_bonds_rights_sz;
                } else if (["7","18","19"].indexOf(stock_type) > -1 && results.exchange_type == "2") {
                    convertible_bonds_rights = results.convertible_bonds_rights_sh || jurisdiction.convertible_bonds_rights_sh;
                }
                // 个人用户优先判断可转债退市整理期权限
                if(userInfo.organ_prop === "0" && results.exchange_type === "0" && results.delist_convertible_bonds_rights === "0" && stock_type === "7" && results.delist_flag === "1"){
                    common.iConfirm("温馨提示", results.delist_convertible_bonds_prompt, function success(html) {
                        if (global.callNative && global.isSso) {
                            var jump_url = {
                                "url": global.newFrameUrl + "fintechpages/business/index.html#/convertibleBondDelisting/index",
                                "uniqueCode":"PalmHall-convertibleBondDelisting/index",
                                "loginMode":"2"
                            };
                            nativePluginService.function501152(jump_url);
                        }
                    }, function fail() {
                    }, "开通权限", "取消");
                }else if((["7","18","19"].indexOf(stock_type) > -1 && convertible_bonds_rights == "0")) {
                    common.iConfirm("风险揭示", "尊敬的投资者您好，您无可转债的交易权限，请到业务办理完成对应权限的开通。", function success(html) {
                        if (global.callNative && global.isSso) {
                            var jump_url = {
                                "url": global.newFrameUrl + "fintechpages/business/index.html#/convertibleBondOpen/index",
                                "uniqueCode":"PalmHall-convertibleBondOpen/index",
                                "loginMode":"11"
                            };
                            nativePluginService.function501152(jump_url);
                        }
                    }, function fail() {
                    }, "开通权限", "取消");
                }
            }
        }
    }


    //reits权限提示框
    function popupRightsReitsConfirm(results, jurisdiction) {
        var userInfo = common.getCurUserInfo();
        if (results && userInfo && jurisdiction) {
            var stock_type = results.stock_type_open||results.stock_type;
            if (jurisdiction.prof_flag != "1" && stock_type) {
                var reits_rights;
                var tips;
                if (["20","21"].indexOf(stock_type) > -1 && results.exchange_type == "0") {
                    reits_rights = results.reits_rights_sz;
                    tips = "您尚未开通深市基础设施基金购买权限，如需进行交易，请到业务办理完成对应权限开通。"
                } else if (["20","21"].indexOf(stock_type) > -1 && results.exchange_type == "2") {
                    reits_rights = results.reits_rights_sh;
                    tips = "您尚未开通沪市基础设施基金购买权限，如需进行交易，请到业务办理完成对应权限开通。"
                }
                if ((["20","21"].indexOf(stock_type) > -1 && reits_rights == "0")) {
                    var toPage="";
                    if(global.nsb_isProd){
                        toPage = "https://online.huajinsc.cn/new/ygt/index.html#!/reits/index.html";
                    }else{
                        toPage = "http://140.207.41.22:8807/new/ygt/index.html#!/reits/index.html";
                    }
                    common.iConfirm("温馨提示", tips, function success(html) {
                        if (global.callNative && global.isSso) {
                            var param = {
                                "funcNo": "50500",
                                "msgNo": "123",
                                "sourceModule": "",
                                "targetModule": "tradeDispatcher",
                                "action": "1",
                                "param": {
                                    "business_type": userInfo._loginClass,//普通0  两融1
                                    "event": "15",//打开权限开通页面
                                    "title": "",
                                    "toPage":toPage,
                                }
                            }
                            $.callMessage(param);
                        }
                    }, function fail() {
                    }, "开通权限", "取消");
                }
            }
        }
    }

    //creditreits权限提示框
    function popupRightsCreditReitsConfirm(results, jurisdiction) {
        var userInfo = common.getCurUserInfo();
        if (results && userInfo && jurisdiction) {
            var stock_type = results.stock_type_open||results.stock_type;
            if (jurisdiction.prof_flag != "1" && stock_type) {
                var reits_rights;
                var tips;
                if (["20","21"].indexOf(stock_type) > -1 && results.exchange_type == "0") {
                    reits_rights = results.reits_rights_sz;
                    tips = "您尚未开通深市基础设施基金购买权限，如需进行交易，请到业务办理完成对应权限开通。"
                } else if (["20","21"].indexOf(stock_type) > -1 && results.exchange_type == "2") {
                    reits_rights = results.reits_rights_sh;
                    tips = "您尚未开通沪市基础设施基金购买权限，如需进行交易，请到业务办理完成对应权限开通。"
                }
                if ((["20","21"].indexOf(stock_type) > -1 && reits_rights == "0")) {
                    var toPage="";
                    if(global.nsb_isProd){
                        toPage = "https://online.huajinsc.cn/new/ygt/index.html#!/xyreits/index.html";
                    }else{
                        toPage = "http://140.207.41.22:8807/new/ygt/index.html#!/xyreits/index.html";
                    }
                    common.iConfirm("温馨提示", tips, function success(html) {
                        if (global.callNative && global.isSso) {
                            var param = {
                                "funcNo": "50500",
                                "msgNo": "123",
                                "sourceModule": "",
                                "targetModule": "tradeDispatcher",
                                "action": "1",
                                "param": {
                                    "business_type": userInfo._loginClass,//普通0  两融1
                                    "event": "15",//打开权限开通页面
                                    "title": "",
                                    "toPage":toPage,
                                }
                            }
                            $.callMessage(param);
                        }
                    }, function fail() {
                    }, "开通权限", "取消");
                }
            }
        }
    }

    function popupRegisterUser(results,jurisdiction){
        var userInfo = common.getCurUserInfo();
        if (results && userInfo && jurisdiction) {
            var reits_rights = results.registration_rights;
            var stock_type = results.stock_type;
            if (["23"].indexOf(stock_type) > -1 && reits_rights == "0" && jurisdiction.prof_flag !== "1") {
                common.iConfirm("风险揭示", results.registration_rights_prompt, function success(html) {
                    if (global.callNative && global.isSso) {
                        var jump_url = {
                            "url": global.newFrameUrl + "fintechpages/business/index.html#/stockRegisterRight/index",
                            "uniqueCode":"PalmHall-stockRegisterRight/index",
                            "loginMode":"2"
                        };
                        nativePluginService.function501152(jump_url);
                    }
                }, function fail() {
                }, "开通权限", "取消");
            }
        }

    }

    /*******
     * 获取缓存的数据
     * @param key
     * @param defaultStr
     * @returns {*}
     */
    function getSaveStr(key, defaultStr) {
        var str = $.getSStorageInfo(key, true) || $.getSStorageInfo(key);
        if (null == str || "" == str || str == "undefined"||str==undefined) {
            return defaultStr;
        } else {
            return str;
        }
    }

    /*********
     * 判断是否有缓存数据
     * @param key
     * @returns {boolean}
     */
    function hasSaveStr(key) {
        var str = $.getSStorageInfo(key, true) || $.getSStorageInfo(key);
        if (null == str || "" == str || str == "undefined"||str==undefined) {
            return false;
        } else {
            return true;
        }
    }


    /**
     * 获取广告图片信息
     * @param {*} userInfo
     * @param {*} callBack
     */
    function getAdPicData(param, callBack) {
        var param = param || {};
        param.channel = "2" || $.config.platform;
        param.ad_version_code = "";
        var queryCallback = function (data) {
            if (data && data.error_no == "0") {
                var results = data.results;
                var callbackData = [];
                if (results && results.length) {
                    for (var i = 0; i < results.length; i++) {
                        var info = results[i];
                        if (info.state == "1" && info.is_open == "1") { //是否启用，放开
                            callbackData.push(info);
                        }
                    }
                    callbackData.sort(function (a, b) {
                        return a.sort > b.sort ? 1 : a.sort < b.sort ? -1 : 1
                    });
                    callbackData.length && callBack && callBack(callbackData);
                } else {
                    callBack(callbackData);
                }
            }
        }
        service_zhyw.getAdPicData(param, queryCallback, {
            "isShowWait": false,
            "isLastReq": false,
            "isShowWait": false,
            "timeout": global.stockTimeout,
            "isShowOverLay": false,
            "isGlobal": true,
            "errorFunc": function () {

            },
            "timeOutFunc": function () {

            }
        });
    }

    /********
     * 权限提示框
     * @param results
     * @param opts
     * @returns {boolean}
     */
    function popupRightsConfirmNew(results, opts) {
        var userInfo = common.getCurUserInfo();
        if (results && userInfo) {
            getJurisdiction(userInfo, function (jurisdiction) {
                if (opts.checkCyb) {
                    return popupRightsCybConfirmNew(results, jurisdiction);
                }
                if (opts.checkKzz) {
                    return popupRightsKzzConfirmNew(results, jurisdiction);
                }
            });
        }
    }


    /*******
     * 创业板权限判断
     * @param results
     * @param jurisdiction
     */
    function popupRightsCybConfirmNew(results, jurisdiction) {
        var userInfo = common.getCurUserInfo();
        if (results && userInfo && jurisdiction) {
            var isOpenGemPerm = jurisdiction.gem_rights_switch == 1; // 是否开启创业板权限校验
            var stock_type = results.stock_type;
            if (jurisdiction.prof_flag != "1" && isOpenGemPerm && stock_type) {
                var gem_rights = results.gem_rights || jurisdiction.gem_rights;
                var gem_register_rights = results.gem_register_rights || jurisdiction.gem_register_rights;
                if (((stock_type == "f" && gem_rights == "1" && gem_register_rights != "0") || (["p", "q"].indexOf(stock_type) >= 0 && gem_register_rights == "1"))) {  //创业板
                    common.iConfirm("温馨提示", gem_rights == "0" ? "您尚未开通创业板权限，如需进行交易，请到业务办理完成对应权限开通。" : "尊敬的投资者您好，您无创业板注册制证券的交易权限，请到业务办理完成对应权限的开通。", function success(html) {
                        if (global.callNative && global.isSso) {
                            var param = {
                                "funcNo": "50500",
                                "msgNo": "123",
                                "sourceModule": "",
                                "targetModule": "tradeDispatcher",
                                "action": "1",
                                "param": {
                                    "business_type": userInfo._loginClass,//普通0  两融1
                                    "event": gem_rights == "1" ? "9" : "10",//打开权限开通页面
                                    "title": "",
                                }
                            }
                            $.callMessage(param);
                        }
                    }, function fail() {
                    }, "开通权限", "取消");
                    return false;
                } else {
                    return true;
                }
            } else {
                return true;
            }
        }
        return false;
    }

    /********
     * 可转债权限提示框
     * @param convertible_bonds_rights
     * @param jurisdiction
     * @returns {boolean}
     */
    function popupRightsKzzConfirmNew(convertible_bonds_rights, jurisdiction) {
        var userInfo = common.getCurUserInfo();
        if (convertible_bonds_rights && userInfo && jurisdiction) {
            if (jurisdiction.prof_flag != "1") {
                if (convertible_bonds_rights == "1") {
                    common.iConfirm("风险揭示", "尊敬的投资者您好，您无可转债的交易权限，请到业务办理完成对应权限的开通。", function success(html) {
                        if (global.callNative && global.isSso) {
                            var param = {
                                "funcNo": "50500",
                                "msgNo": "123",
                                "sourceModule": "",
                                "targetModule": "tradeDispatcher",
                                "action": "1",
                                "param": {
                                    "business_type": userInfo._loginClass,//普通0  两融1
                                    "event": "11",//打开权限开通页面
                                    "title": "",
                                }
                            }
                            $.callMessage(param);
                        }
                    }, function fail() {
                    }, "开通权限", "取消");
                    return false;
                } else {
                    return true;
                }
            } else {
                return true
            }
        } else {
            return false;
        }
        return false;
    }

    /**
     * 登录公共方法
     * @param pageCode 来源页面
     * @param h5ToPage H5登录成功跳转的页面
     * @param h5ParamMap  h5登录参数
     * @param nativeParamMap 原生登录参数
     * @param nativeCallback  唤起原生登录之后的回调方法，用于处理唤起登录的同时H5需要同步执行的动作
     * @param direct 打开动画方向right,left,'',默认为right
     * @param replace 销毁跳转前页面，使其返回的时候，直接返回到上一个页面
     */
    function login(pageCode, h5ToPage, h5ParamMap, nativeParamMap, nativeCallback, direct, replace) {
        if (global.callNative && global.isSso) {
            nativeParamMap = nativeParamMap || {};
            //原生登录入参增加来源标识，用于解决当新开webview时，tabbar交易会同时刷新跳转页面问题
            var loginSourceId = new Date().getTime();
            nativeParamMap.loginSourceId = loginSourceId;
            $.setSStorageInfo("loginSourceId", loginSourceId);
            $.callMessage({
                "funcNo": "50500",
                "msgNo": "901",
                "sourceModule": "trade",
                "targetModule": "sso",
                "action": "4",
                "param": {
                    "login_type": "1",
                    "account_type": "A",
                    "account": "",
                    "param": nativeParamMap,
                    "allow_branch": "false",
                    "exclude_phone_login": false, //false-先进行手机号登录再进行资金账号登录 true-跳过手机号登录，直接进行资金账号登录
                    "auto_allow_branch": "true",
                    "page_type": ""
                }
            });
            if (typeof (nativeCallback) == "function") {
                nativeCallback();
            }
        } else {
            h5ParamMap = h5ParamMap || {};
            $.pageInit(pageCode, h5ToPage, h5ParamMap, direct, replace);
        }
    }



    /**
     * 获取清算状态和清算提示信息
     * @param pageId 页面pageId
     * @param isReq 是否重新获取清算状态
     */
    function getLiquidationInfo(pageId, isReq, callBack) {
        var liquidationInfo = $.getSStorageInfo("liquidationInfo") || "";
        if(!isReq && liquidationInfo) {
            setLiquidationInfo(pageId, liquidationInfo);
            return;
        }
        service_common.getLiquidationInfo({}, function (data) {
            if (data && data.error_no == 0) {
                var result = (data.results && data.results[0]) || {};
                $.setSStorageInfo("liquidationInfo", result);
                setLiquidationInfo(pageId, result);
                callBack && callBack();
            }
        }, {
            "isShowWait": false,
            "isLastReq": false,
            "isShowOverLay": false,
            "isGlobal": true,
            "errorFunc": function () {
            },
            "timeOutFunc": function () {
            }
        });
    }

    /**
     * 设置清算提示信息
     */
    function setLiquidationInfo(pageId, liquidationInfo) {
        pageId = pageId || "";
        liquidationInfo = liquidationInfo || {};
        if(liquidationInfo.liquidation_flag == "1" && liquidationInfo.liquidation_title) {
            $(pageId + " .tip_qs").show();
            $(pageId + " .tip_qs span").text(liquidationInfo.liquidation_title);
            var liquidationTxt = liquidationInfo.liquidation_txt || "";
            $.bindEvent($(pageId + " .tip_qs"), function (e) { //点击显示清算时间提醒弹框
                common.singleIConfirm("",  liquidationTxt || '系统正在清算', function () {
                }, "我知道了");
                e.stopPropagation();
            });
        }else {
            $(pageId + " .tip_qs").hide();
        }
    }

    /**
     * 截长屏分享公用方法-基于vIscroll插件滚动
     * btnDom 需要绑定的元素
     * scroll iscroll 对象
     * topFixedHeight 顶部固定区域高度
     * callback 如果有回调函数，则执行回调，通过回调返回的对象中获取 scroll ，topFixedHeight
     */
    function longScreenShot(param) {
        var scroll = param.scroll;
        var topFixedHeight = param.topFixedHeight;
        var offsetHeight = param.offsetHeight;
        var maxScrollY = param.maxScrollY;
        var startY = scroll.y;
        $.callMessage({
            funcNo: "501157",
            // 是否加上公众号二维码
            isNeedQrcode: true,
            // 顶部固定区域高度，如果有固定的元素，不加会出现多个
            topFixedHeight: topFixedHeight,
            // 内容高度
            offsetHeight: offsetHeight,
            // 最大可滚动距离
            maxScrollY: maxScrollY,
            // 是否开启截长屏
            isLongImage: true,
            // 滚动方法
            callback: 'custmScrollTo',
            // 截屏结束后回调，返回刚开始的高度
            successCallback: 'successCallback',
        });
        window.custmScrollTo = function (posY) {
            // iscroll 是从 -40 开始滚动的，客户端是从0开始，这里加上
            var scrolly = -(posY + Math.abs(scroll.minScrollY));
            // 滚动距离大于最大可滚动距离，使用最大可滚动距离
            if (-scrolly > -scroll.maxScrollY && scroll.maxScrollY < 0) {
                scrolly = scroll.maxScrollY;
            }
            console.log('native=' + posY + ';h5=' + scrolly);
            scroll.scrollTo(0, scrolly, 0)
        }
        window.successCallback = function () {
            scroll.scrollTo(0, startY, 0)
        }
    }

    /**
     * 截长屏分享公用方法-基于h5自带滚动
     * btnDom 需要绑定的元素
     * scroll 滚动容器元素
     * topFixedHeight 顶部固定区域高度
     * callback 如果有回调函数，则执行回调，通过回调返回的对象中获取 scroll ，topFixedHeight
     */
    function longScreenShotH5(param) {
        var scroll = param.scroll;
        var topFixedHeight = param.topFixedHeight;
        var offsetHeight = param.offsetHeight;
        var maxScrollY = param.maxScrollY;
        var startY = scroll.scrollTop;
        $.callMessage({
            funcNo: "501157",
            // 是否加上公众号二维码
            isNeedQrcode: true,
            // 顶部固定区域高度，如果有固定的元素，不加会出现多个
            topFixedHeight: topFixedHeight,
            // 内容高度
            offsetHeight: offsetHeight,
            // 最大可滚动距离
            maxScrollY: maxScrollY,
            // 是否开启截长屏
            isLongImage: true,
            // 滚动方法
            callback: 'custmScrollTo',
            // 截屏结束后回调，返回刚开始的高度
            successCallback: 'successCallback',
        });
        window.custmScrollTo = function (posY) {
            var scrolly = posY;
            // 滚动距离大于最大可滚动距离，使用最大可滚动距离
            if (scrolly > scroll.scrollHeight) {
                scrolly = scroll.scrollHeight;
            }
            console.log('native=' + posY + ';h5=' + scrolly);
            scroll.scrollTo(0, scrolly)
        }
        window.successCallback = function () {
            scroll.scrollTo(0, startY)
        }
    }
    /**
     * 截屏分享公用方法
     * btnDom 需要绑定的元素
     */
    function screenShot(btnDom) {
        $.bindEvent(btnDom, function (e) {
            $.callMessage({
                funcNo: "501157",
                // 是否加上公众号二维码
                isNeedQrcode: true,
                // 是否开启截长屏
                isLongImage: false,
            });
        });
    }
    /**
     * 判断是否是思迪行情
     * 全局存一个标志 is_trade_hq_use_by_szy 避免影响性能
     */
    function isTradeSZYHQ(){
        //  key : "is_trade_hq_use_by_szy" 返回：1-上证云；0-思迪
        var data = $.callMessage({"funcNo": "50043",key : "is_trade_hq_use_by_szy"});
        if(data.results && data.results.length > 0 && data.results[0].value && data.results[0].value == '1'){
            $.setSStorageInfo("is_trade_hq_use_by_szy", "1");
        }else{
            $.setSStorageInfo("is_trade_hq_use_by_szy", "0");
        }
    }
    /**
      * 通用下拉选择框
      * title; //标题
      * selectIndex; //选中索引 默认0
      * isShowTip;  //是否显示提示按钮 0不显示，1显示  默认"0";
      * list; // 帅选列表【格式是json数组】
    
      * 出参：
      * status; //0点击确定按钮 1点击取消按钮 2点击提示按钮 其他表示选择框消失
      * selectIndex; //选中数据的索引
      * dateStr 选择的数据【只有点击确定按钮的时候会返回】
      * */
    function nativeSelect(title,vals,list,isSHowTip,selectIndex){
        var defaultVal = selectIndex || 0;
        return function(callback,custTitle){
            service_native_sync.native5011519({
                title: custTitle || title,
                selectIndex: defaultVal,
                isShowTip: isSHowTip || "0",
                list: JSON.stringify(list),
            },function(data){
                if(data.status === "0"){
                    defaultVal = data.selectIndex;
                }
                callback(data,vals,list);
            });
        }
    }
    /**
      * 通用日期选择控件
      * title; //标题
      * formatStr; //返回时间格式                   默认"yyyy年MM月dd日"; 
      * startDateStr; //开始时间【格式同formatStr】 默认"19900101"; 
      * selectedDateStr; //选中时间【格式同formatStr】默认当前时间  
      * endDateStr; //结束时间【格式同formatStr】     默认"21001231"; 
      * isShowTip;  //是否显示提示按钮 0不显示，1显示  默认"0"; 
    
      * 出参： 
      * status; //0点击确定按钮 1点击取消按钮 2点击提示按钮 其他表示选择框消失 
      * dateStr 选择的日期【按formatStr返回】只有点击确定按钮的时候会返回 
      * */
    function nativeDateSelect(title,selectedDateStr,startDateStr,endDateStr,isShowTip,formatStr){
        var vals = vals;
        var defaultVal = selectedDateStr;
        return function(defaultDateStr,callback){
            service_native_sync.native5011518({
                title: title,
                formatStr: formatStr || "yyyy-MM-dd",
                startDateStr: startDateStr || "1990-01-01",
                selectedDateStr: defaultDateStr || selectedDateStr,
                endDateStr: endDateStr || "2100-12-31",
                isShowTip: isShowTip || "0",
            },function(data){
                if(data.status === "0"){
                    defaultVal = data.dateStr;
                }
                callback(data);
            });
        }
    }
    /**
     * 初始化日期选择组件
     * @param {Object} pageId
     * @param {Object} timeLimit 默认查询天数
     * @param {Boolean} notContainToday 不包含今天
     */
    function initNativeTimeChoice(pageId, timeLimit, notContainToday) {
        if (!timeLimit) {
            timeLimit = 0;
        }
        var begin_time = getTradingDay(0 - timeLimit, "yyyy-MM-dd");	//截止时间
        var end_time = new Date().format("yyyy-MM-dd");
        if (notContainToday) {
            begin_time = getTradingDay(0 - timeLimit - 1, "yyyy-MM-dd");
            end_time = getTradingDay(-1, "yyyy-MM-dd");
        }
        $(pageId + " #startDate").html(begin_time);
        $(pageId + " #endDate").html(end_time);
        $(pageId + " #startInput").val(begin_time);
        $(pageId + " #endInput").val(end_time);
        var beginTimeFunc = nativeDateSelect("选择开始日期",begin_time);
        var endTimeFunc = nativeDateSelect("选择截止日期",end_time);

        //设置开始日期
        $.bindEvent($(pageId + " #setStart"), function (e) {
            beginTimeFunc($(pageId + " #startDate").text(),function(data){
                if(data.status === "0"){
                    $(pageId + " #startDate").html(data.dateStr);
                }
            })
            e.stopPropagation();
        });

        //设置截止日期
        $.bindEvent($(pageId + " #setEnd"), function (e) {
            endTimeFunc($(pageId + " #endDate").text(),function(data){
                if(data.status === "0"){
                    $(pageId + " #endDate").html(data.dateStr);
                }
            })
            e.stopPropagation();
        });
    }

    function showNoticeBtn(_pageId){
        service_native_sync.native5011516({},function(data){
            var noticeState = data.noticeState; // 1 已允许
            if(noticeState === "1"){
                $(_pageId + ".j_notice_warp").hide();
                $(_pageId + ".j_system").hide();
                $(_pageId + ".j_wx").show();
                var userInfo = common.getCurUserInfo();
                // 判断微信是否绑定
                service_xkj.require2001045({
                    fundAccount:userInfo.fund_account
                },function(data){
                    if(data.error_no === 0){
                        var bindFlag = data.results.bindFlag // 0：未绑定  1：已绑定
                        if(bindFlag === "1"){
                            $(_pageId + ".j_notice_warp").hide();
                            $(_pageId + ".j_system").show();
                            $(_pageId + ".j_wx").hide();
                        }else{
                            $(_pageId + ".j_notice_warp").show();
                            $(_pageId + ".j_wx").show();
                            $(_pageId + ".j_system").hide();
                        }
                    }
                });
            }else {
                $(_pageId + ".j_notice_warp").show();
                $(_pageId + ".j_system").show();
                $(_pageId + ".j_wx").hide();
            }
        });
        
        $.bindEvent($(_pageId+".j_sys_btn"), function(e){
            nativePluginService.function5011517();
        });
        $.bindEvent($(_pageId+".j_wx_btn"), function(e){
            var targetPage = "HJWechatMessageController";
            if ($.device.android) { 
                targetPage = "com.thinkive.android.thinkive_invest.ui.activity.WeChatMsgRemaindActivity";
            }
            $.callMessage({
                "funcNo": "50500",
                "msgNo": "309",
                "targetModule":"appDispatcher",
                "action": 4,
                "param": {
                    "loginMode":"0",
                    "targetPage":targetPage
                }
            });
        });
    }
    var base = {
        "getTradingDay": getTradingDay,
        "getKey": getKey,
        "decimalKeep": decimalKeep,
        "initTimeChoice": initTimeChoice,
        "getServerTime": getServerTime,
        "simulationTime": simulationTime,
        "isTradingTimes": isTradingTimes,
        "getTradingTime": getTradingTime,
        "initCheckTradeTimer": initCheckTradeTimer,
        "clearCheckTradeTimer": clearCheckTradeTimer,
        "getStockAccount": getStockAccount,
        "kcbJurisdiction": kcbJurisdiction,
        "setJurisdiction": setJurisdiction,
        "getJurisdiction": getJurisdiction,
        "setNewStockAccount": setNewStockAccount,
        "getNewStockAccount": getNewStockAccount,
        "stockAccountSort": stockAccountSort,
        "setStockAccount": setStockAccount,
        "newStockConfirmFunc": newStockConfirmFunc,
        "appThirdBack": appThirdBack,
        "isTradeSZYHQ": isTradeSZYHQ,
        "popupRightsConfirmNew": popupRightsConfirmNew,
        "popupRightsConfirm": popupRightsConfirm,
        "getSaveStr": getSaveStr,
        "hasSaveStr": hasSaveStr,
        "getAdPicData": getAdPicData,
        "login": login,
        "longScreenShot": longScreenShot,
        "longScreenShotH5": longScreenShotH5,
        "screenShot": screenShot,
        "nativeSelect":nativeSelect,
        "nativeDateSelect":nativeDateSelect,
        "initNativeTimeChoice":initNativeTimeChoice,
        "showNoticeBtn":showNoticeBtn,
        "getLiquidationInfo": getLiquidationInfo
    };

    module.exports = base;
});
