/**
 * 密码键盘插件
 */
define(function(require, exports, module) {
    var gconfig = $.config;
    var global = gconfig.global;
    require('keyPanel'); // 首先引入 keyPanel 插件
    var myKeyPanel = new $.KeyPanel(); // 创建与当前页面对应的 keyPanel 对象
    var pageGlobal = {
        "curPwd": ""
    };

    var htmlStr = '<div class="mask_box">\n' +
        '                <div class="shade_box"></div>\n' +
        '                <div class="alert_box">\n' +
        '                    <div class="tit">\n' +
        '                        <span class="icon_close" id="closeWindowBtn"></span>\n' +
        '                        <h3>余额查询</h3>\n' +
        '                    </div>\n' +
        '                    <p class="card"><span class="sign">主</span><span></span></p>\n' +
        '                    <div class="ui input" placeholder="" maxlength="6" id="tradePwd" style="display: none"></div>\n' +
        '                    <table>\n' +
        '                        <tr id="tradePwdBox">\n' +
        '                            <td></td>\n' +
        '                            <td></td>\n' +
        '                            <td></td>\n' +
        '                            <td></td>\n' +
        '                            <td></td>\n' +
        '                            <td></td>\n' +
        '                        </tr>\n' +
        '                    </table>\n' +
        '                    <span class="bottom_tip">请输入银行卡取款密码</span>\n' +
        '                </div>\n' +
        '            </div>';

    // 定义密码窗口模板，注意事项：必须有一个id="tradePwd"的div，圆点父元素的id必须等于tradePwdBox
    var pwdWindowTemp = {
        "htmlStr": htmlStr
    };

    /**
     * 初始化密码控件
     * 适用于弹出密码窗口
     * @param callBack ：交易密码输入完成后需要执行的回调函数
     * @param htmlStr： 密码窗口风格（项目中根据重构给的样式自定义模板）注意事项：必须有一个id="tradePwd"的div，圆点父元素的id必须等于tradePwdBox
     * @param opt: 扩展参数
     *
     */
    function initPwdWindow(callBack, style, closeBack, opt){
        pageGlobal.curPwd = "";
        opt = opt || {};
        style = style ? style : "htmlStr";
        var pwdWindowHtml = '<div id="payWindow" style="display: none;">' + pwdWindowTemp[style] + '</div>';
        var keyType = opt["keyType"] || 2;

        var _pageId = getCurPageId();
        if ($(_pageId + "#payWindow").length > 0) {
            $(_pageId + "#payWindow").remove();
        }
        $(_pageId).append(pwdWindowHtml);

        // 点击密码弹出键盘    PC：调用H5键盘，Android & ios 调用原生键盘
        $.bindEvent(_pageId + "#tradePwdBox", function(e){
            e.stopPropagation();
            var keyPanelConfig = {
                "okFunc": function() {
                    if(typeof(opt["okFunc"]) == "function") {
                        var pwdParam = {
                            "pwdStr": pageGlobal.curPwd
                        };
                        opt["okFunc"](pwdParam);
                    }
                },
                "skinName": "white"
            };
            myKeyPanel.init(_pageId + "#tradePwd", keyType, true, keyPanelConfig); // 执行初始化
        }, "click");

        // H5键盘监控文本框输入事件
        $.bindEvent(_pageId + "#tradePwd", function(e){
            e.stopPropagation();
            var curKeyCode = e.originalEvent ? e.originalEvent.detail["optType"] : e.detail["optType"]; // 按键值
            var $input = $(_pageId + "#tradePwd"); // 密码input控件
            var curTradePwd = $input.attr("value");
            var len = curTradePwd.length;
            pageGlobal.curPwd = curTradePwd;
            switch(curKeyCode + ""){
                case "del": // H5键盘删除键
                    if (len >= 0) {
                        $(_pageId + "#tradePwdBox").find("td").eq(len).html("");
                    }
                    break;
                case "clear":
                    if (len >= 0) {
                        $(_pageId + "#tradePwdBox").find("td").html("");
                    }
                    break;
                default:
                    if(len <= 6){
                        $(_pageId + "#tradePwdBox").find("td").eq(len - 1).html('<em></em>');
                        if(len == 6){
                            var pwdParam = {
                                "pwdStr": curTradePwd
                            };
                            if(typeof(callBack) == "function") {
                                callBack(pwdParam);
                            }
                        }
                    }
                    break;
            }
        }, "input");

        /**
         * 绑定点击关闭按钮
         */
        $.bindEvent(_pageId + "#closeWindowBtn", function(){
            hidePwdWindow();
            if (typeof(closeBack) == "function") {
                closeBack();
            }
        });
    }

    /**
     * 初始化密码文本框
     */
    function initPwdInput(pageId, pwdId, callBack,callBackFun,afterCloseFunc,opt) {
        opt = opt || {};
        $(pageId + " #" + pwdId).attr('value','');  //初始化密码值
        var oldValue = ''; //初始化的老密码
        var keyType = opt["keyType"] || 2;

        // 点击密码弹出键盘 PC：调用H5键盘，Android & ios 调用原生键盘
        $.bindEvent(pageId + " #" + pwdId, function(e){
            e.stopPropagation();
            myKeyPanel.init(this, keyType, true, {skinName: "white","afterCloseFunc":afterCloseFunc}); // 执行初始化

            $(pageId + " #" + pwdId).attr('value','');  //重新初始化密码值
            oldValue = ''; //初始化的老密码

            if (typeof(callBackFun) == "function") {
                callBackFun({"type":"init","pwdId":pwdId});
            }
        });

        $.bindEvent($(pageId + " #" + pwdId), function(e){
            e.stopPropagation();
            var curKeyCode = e.originalEvent ? e.originalEvent.detail["optType"] : e.detail["optType"]; // 按键值

            if(String(curKeyCode) != 'del' && String(curKeyCode) != 'clear'){
                var curLen = $(pageId + " #" + pwdId).attr('value').length;
                var curTradePwd = oldValue + $(pageId + " #" + pwdId).attr('value').substr(curLen-1,1);  //获取当前的curTradePwd
            }else{
                var curTradePwd = oldValue;  //获取当前的curTradePwd
            }
            var len = curTradePwd.length;
            if(len > 6){
                return false;
            }
            oldValue = curTradePwd;  //oldValue重新赋值

            switch(curKeyCode + ""){
                case "del": // H5键盘删除键
                    if (len >= 0) {
                        $(this).val(curTradePwd.substr(0,len-1));
                        oldValue = curTradePwd.substr(0,len-1);  //删除后重置oldValue
                    }
                    break;
                case "clear":
                    if (len >= 0) {
                        $(this).val('');
                        oldValue = ''; //清空后重置oldValue
                    }
                    break;
                default:
                    if(len <= 6){
                        $(this).val(curTradePwd)
                    }
                    break;
            }
            //原来的逻辑
            if (typeof(callBack) == "function") {
                callBack();
            }
        },"input");

        // 点击页面关闭键盘
        $.bindEvent(pageId, function(){
            $(pageId + " #" + pwdId).attr('value','');  //重新初始化密码值
            oldValue = ''; //初始化的老密码
            hideKeyBoard();
        });
    }

    /**
     * 弹出支付窗口 注：此方法依赖于initPwdWindow
     */
    function showPwdWindow(opt) {
        opt = opt || {};
        var keyType = opt["keyType"] || 2;
        var _pageId = getCurPageId();
        $(_pageId + "#payWindow").slideDown("slow");
        $(_pageId + "#tradePwdBox").find("td").html("");
        $(_pageId + "#tradePwd").attr("value", "").find("em").html("");
        pageGlobal.curPwd = "";
        var keyPanelConfig = {
            "okFunc": function() {
                if(typeof(opt["okFunc"]) == "function") {
                    var pwdParam = {
                        "pwdStr": pageGlobal.curPwd
                    };
                    opt["okFunc"](pwdParam);
                }
            },
            "skinName": "white"
        };
        myKeyPanel.init(_pageId + "#tradePwd", keyType, true, keyPanelConfig); // 执行初始化
    }

    /**
     * 隐藏支付窗口 注：此方法依赖于initPwdWindow
     */
    function hidePwdWindow() {
        var _pageId = getCurPageId();
        $(_pageId + "#payWindow").hide();
        pageGlobal.curPwd = "";
        hideKeyBoard();
    }

    /**
     * 隐藏键盘
     */
    function hideKeyBoard() {
        if(myKeyPanel) {
            myKeyPanel.close(); // 隐藏h5键盘
        }
    }

    /**
     * 获取当前页面id
     */
    function getCurPageId() {
        var _curPageCode = ($.getCurrentPageObj().pageCode);
        var _curPageId = _curPageCode.replaceAll("/", "_") + "";
        return "#" + _curPageId + " ";
    }

    var keyboardUtils = {
        "initPwdWindow" : initPwdWindow, // 初始化密码输入窗口，弹出窗
        "showPwdWindow" : showPwdWindow, // 显示密码窗口
        "hidePwdWindow" : hidePwdWindow, // 隐藏密码窗口
        "initPwdInput" : initPwdInput, // 初始化密码文本框
        "hideKeyBoard" : hideKeyBoard // 隐藏键盘
    };

    // 暴露对外的接口
    module.exports = keyboardUtils;
});