;
(function($, undefined) {
	var prefix = '',
		eventPrefix,
		vendors = { Webkit: 'webkit', Moz: '', O: 'o' },
		testEl = document.createElement('div'),
		supportedTransforms = /^((translate|rotate|scale)(X|Y|Z|3d)?|matrix(3d)?|perspective|skew(X|Y)?)$/i,
		transform,
		transitionProperty, transitionDuration, transitionTiming, transitionDelay,
		animationName, animationDuration, animationTiming, animationDelay,
		cssReset = {}

	function dasherize(str) { return str.replace(/([a-z])([A-Z])/, '$1-$2').toLowerCase() }

	function normalizeEvent(name) { return eventPrefix ? eventPrefix + name : name.toLowerCase() }

	$.each(vendors, function(vendor, event) {
		if(testEl.style[vendor + 'TransitionProperty'] !== undefined) {
			prefix = '-' + vendor.toLowerCase() + '-'
			eventPrefix = event
			return false
		}
	})

	transform = prefix + 'transform'
	cssReset[transitionProperty = prefix + 'transition-property'] =
		cssReset[transitionDuration = prefix + 'transition-duration'] =
		cssReset[transitionDelay = prefix + 'transition-delay'] =
		cssReset[transitionTiming = prefix + 'transition-timing-function'] =
		cssReset[animationName = prefix + 'animation-name'] =
		cssReset[animationDuration = prefix + 'animation-duration'] =
		cssReset[animationDelay = prefix + 'animation-delay'] =
		cssReset[animationTiming = prefix + 'animation-timing-function'] = ''

	$.fx = {
		off: (eventPrefix === undefined && testEl.style.transitionProperty === undefined),
		speeds: { _default: 400, fast: 200, slow: 600 },
		cssPrefix: prefix,
		transitionEnd: normalizeEvent('TransitionEnd'),
		animationEnd: normalizeEvent('AnimationEnd')
	}

	$.fn.animate = function(properties, duration, ease, callback, delay) {
		if($.isFunction(duration))
			callback = duration, ease = undefined, duration = undefined
		if($.isFunction(ease))
			callback = ease, ease = undefined
		if($.isPlainObject(duration))
			ease = duration.easing, callback = duration.complete, delay = duration.delay, duration = duration.duration
		if(duration) duration = (typeof duration == 'number' ? duration :
			($.fx.speeds[duration] || $.fx.speeds._default)) / 1000
		if(delay) delay = parseFloat(delay) / 1000
		return this.anim(properties, duration, ease, callback, delay)
	}

	$.fn.anim = function(properties, duration, ease, callback, delay) {
		var key, cssValues = {},
			cssProperties, transforms = '',
			that = this,
			wrappedCallback, endEvent = $.fx.transitionEnd,
			fired = false

		if(duration === undefined) duration = $.fx.speeds._default / 1000
		if(delay === undefined) delay = 0
		if($.fx.off) duration = 0

		if(typeof properties == 'string') {
			// keyframe animation
			cssValues[animationName] = properties
			cssValues[animationDuration] = duration + 's'
			cssValues[animationDelay] = delay + 's'
			cssValues[animationTiming] = (ease || 'linear')
			endEvent = $.fx.animationEnd
		} else {
			cssProperties = []
			// CSS transitions
			for(key in properties)
				if(supportedTransforms.test(key)) transforms += key + '(' + properties[key] + ') '
			else cssValues[key] = properties[key], cssProperties.push(dasherize(key))

			if(transforms) cssValues[transform] = transforms, cssProperties.push(transform)
			if(duration > 0 && typeof properties === 'object') {
				cssValues[transitionProperty] = cssProperties.join(', ')
				cssValues[transitionDuration] = duration + 's'
				cssValues[transitionDelay] = delay + 's'
				cssValues[transitionTiming] = (ease || 'linear')
			}
		}

		wrappedCallback = function(event) {
			if(typeof event !== 'undefined') {
				if(event.target !== event.currentTarget) return // makes sure the event didn't bubble from "below"
				$(event.target).unbind(endEvent, wrappedCallback)
			} else
				$(this).unbind(endEvent, wrappedCallback) // triggered by setTimeout

			fired = true
			$(this).css(cssReset)
			callback && callback.call(this)
		}
		if(duration > 0) {
			this.bind(endEvent, wrappedCallback)
			// transitionEnd is not always firing on older Android phones
			// so make sure it gets fired
			setTimeout(function() {
				if(fired) return
				wrappedCallback.call(that)
			}, ((duration + delay) * 1000) + 25)
		}

		// trigger page reflow so new elements can animate
		this.size() && this.get(0).clientLeft

		this.css(cssValues)

		if(duration <= 0) setTimeout(function() {
			that.each(function() { wrappedCallback.call(this) })
		}, 0)

		return this
	}

	testEl = null;
	$.fn.slideDown = function(duration, callback) {
		var that = this;
		if(that.css("display") !== "none") {
			callback && callback.call(that);
			return that;
		}
		switch(duration) {
			case "slow":
				duration = 600;
				break;
			case "normal":
				duration = 400;
				break;
			case "fast":
				duration = 200;
				break;
		}
		duration = typeof(duration) === "undefined" ? 400 : duration;
		duration = (+duration + "") === "NaN" ? 400 : +duration;
		var originalCss = that[0].style.cssText;
		that.css("display", "block").css("overflow", "hidden");
		var height = that.height();
		that.css("height", 0);
		setTimeout(function() {
			that.animate({
				height: height
			}, duration, "linear", function() {
				that[0].style.cssText = originalCss; // 恢复原有的 css
				that.css("display", "block");
				callback && callback.call(that);
			});
		}, 0);
		return that;
	};

	$.fn.slideUp = function(duration, callback) {
		var that = this;
		if(that.css("display") === "none") {
			callback && callback.call(that);
			return that;
		}
		switch(duration) {
			case "slow":
				duration = 600;
				break;
			case "normal":
				duration = 400;
				break;
			case "fast":
				duration = 200;
				break;
		}
		duration = typeof(duration) === "undefined" ? 400 : duration;
		duration = (+duration + "") === "NaN" ? 400 : +duration;
		setTimeout(function() {
			var height = that.height();
			var originalCss = that[0].style.cssText;
			that.css("overflow", "hidden").css("height", height + "px");
			that.animate({
				height: 0
			}, duration, "linear", function() {
				that[0].style.cssText = originalCss; // 恢复原有的 css
				that.css("display", "none");
				callback && callback.call(that);
			});
		}, 0);
		return that;
	};

	$.fn.slideToggle = function(duration, callback) {
		var that = this;
		if(that.css("display") === "none") {
			that.slideDown(duration, callback);
		} else {
			that.slideUp(duration, callback);
		}
		return that;
	};
	
	/**
	 * div从右向左动画效果显示
	 * @param {Object} duration
	 * @param {Object} ease
	 * @param {Object} callback
	 * @param {Object} delay
	 */
	$.fn.showLeft = function(duration, ease, callback, delay) {
		this.css("left", "100%");
		this.show();
		return this.animate({ "left": "0%" }, duration, "fast", callback, delay)
	}
	/**
	 * div从左向右动画效果隐藏
	 * @param {Object} duration
	 * @param {Object} ease
	 * @param {Object} callback
	 * @param {Object} delay
	 */
	$.fn.hideLeft = function(duration, ease, callback, delay) {
		var t = this;
		return this.animate({ "left": "100%" }, duration, "fast", function() {
			t.hide();
			t.css("left", "0%");
			if(callback) {
				callback();
			}
		}, delay)
	}

	/**
	 * 取div的值，设置div的值
	 * 主要实用在的div实现的输入框中，取值和设置值
	 * @param {Object} t 值
	 */
	$.fn.quzhi = function(t) {
		if(this && this[0]) {
			if(this.length > 1 && $(this).eq(0).attr("js-key") && typeof(t) != "undefined") {
				for(var i = 0; i < this.length; i++) {
					if(this[i].localName == "input" && $(this).eq(i).attr("js-key")) {
						this[i].value = t;
					} else if(this[i].localName == "div" && $(this).eq(i).hasClass("jsKey")) {
						this.eq(i).val(t + "");
						this.eq(i).children("em").text(t + "");
						this.eq(i).find("div.key_text").html(t + "");
						if(t.length == 0) {
							this.eq(i).find("div.key_place").show();
						} else {
							this.eq(i).find("div.key_place").hide();
						}
					} else {
						var a = this[i].localName;
						if(a == "input") {
							return 0 in arguments ? this[i].each(function(e) {
								this.value = t
							}) : 0 in this[i] ? this[i].value : ''
						} else {
							return 0 in arguments ? this[i].each(function(e) {
								this.textContent = t
							}) : 0 in this[i] ? this[i].textContent : ''
						}
					}
				}
			} else {
				var a = this[0].localName;
				if(a == "input") {
					return 0 in arguments ? this.each(function(e) {
						this.value = t
					}) : 0 in this ? this[0].value : ''
				} else {
					return 0 in arguments ? this.each(function(e) {
						this.textContent = t
					}) : 0 in this ? this[0].textContent : ''
				}
			}
		} else {
			return '';
		}
	}

	/**
	 * 设置input的placeholder属性的值。
	 * 主要实用在的div实现的输入框中，用来设置placeholder的属性的值
	 * @param {Object} t
	 */
	$.fn.setPlaceholder = function(t) {
		if(this && typeof(t) != "undefined") {
			if(this.length > 1 && $(this).eq(0).attr("js-key")) {
				for(var i = 0; i < this.length; i++) {
					if(this[i].localName == "input" && $(this).eq(i).attr("js-key")) {
						this.eq(i).attr("placeholder", t);
					} else if(this[i].localName == "div" && $(this).eq(i).hasClass("jsKey")) {
						this.eq(i).find("div.key_place").text(t);
					} else {
						this.eq(i).attr("placeholder", t);
					}
				}
			} else {
				this.attr("placeholder", t);
			}
		}
	}
	
	/**
	 * 判断div是否是显示的
	 */
	$.fn.isShow = function(){
		return $(this).css("display") && $(this).css("display") != "none" && $(this).height() != 0;
	}
	
	/**
	 * 获取元素的高度，精确到小数
	 * 边框 border + 内边距 padding 
	 */
	$.fn.getHeight = function(){
		var h = $(this).css("height");
		if(h){
			h = h.replace("px", "");
			return Number(h) || 0;
		}
		else{
			return 0;
		}
	}
	
	
	/**
	 * 获取元素的宽度，精确到小数
	 * 边框 border + 内边距 padding 
	 */
	$.fn.getWidth = function(){
		var h = $(this).css("width");
		if(h){
			h = h.replace("px", "");
			return Number(h) || 0;
		}
		else{
			return 0;
		}
	}

	$.fn.getContentWidth = function(){
		var pw = 0,pArr = $(this).css("padding").split("px"),len = pArr.length;
		if(len == 1) pw = Number(pArr[0]) * 2;
		else if(len <= 3) pw = Number(pArr[1]) * 2;
		else pw = Number(pArr[1]) + Number(pArr[3]);
		var w = this.getWidth() - pw;
		return w || this.getWidth();
	}
	
	/**
	 * 获取元素的高度，精确到小数
	 * 边框 border + 内边距 padding + 外边框 margin
	 */
	$.fn.getMHeight = function(){
		if($(this) && $(this).length > 0){
			var h = $(this).css("height").replace("px", "");
			var mt = $(this).css("margin-top").replace("px", "");
			var mb = $(this).css("margin-bottom").replace("px", "");
			return (Number(h) || 0) + (Number(mt) || 0) + (Number(mb) || 0);
		}
		else{
			return 0;
		}
	}
	
	/**
	 * 获取显示的元素的高度，精确到小数
	 * 边框 border + 内边距 padding + 外边框 margin
	 */
	$.fn.getSMHeight = function(){
		if($(this) && $(this).length > 0 && $(this).isShow()){
			var h = $(this).css("height").replace("px", "");
			var mt = $(this).css("margin-top").replace("px", "");
			var mb = $(this).css("margin-bottom").replace("px", "");
			return (Number(h) || 0) + (Number(mt) || 0) + (Number(mb) || 0);
		}
		else{
			return 0;
		}
	}
	
	
	/**
	 * 对框架存储的数据优化处理
	 */
	var getobj = $.getCurrentPageObj;
	$.getCurrentPageObj = function() {
		var t = getobj();
		if(!t || typeof(t) != "object") t = {};
		return t;
	}

	/**
	 * 去掉字符串头尾空格
	 * @param {Object} data 字符串
	 */
	$.trim = function(data) {
		if(typeof data == "string") {
			return data.replace(/(^\s*)|(\s*$)/g, "");
		} else {
			return data;
		}
	}

	/**
	 * 复制对象的值
	 * @param {Object} obj
	 */
	$.cloneFun = function(obj) {
		if(!obj || "object" != typeof obj) {
			return {};
		}
		var result = (obj instanceof Array) ? [] : {};
		for(var i in obj) {
			if(!obj.hasOwnProperty(i)) continue;
			result[i] = ("object" != typeof obj[i]) ? obj[i] : $.cloneFun(obj[i]);
		}
		return result;
	}


	/**
	 * 将数字转换为金钱格式
	 * @param {Object} number 数据
	 * @param {Object} places 小数位数
	 * @param {Object} symbol 头标
	 * @param {Object} thousand 分格符
	 * @param {Object} decimal 小数点
	 */
	$.formatMoney = function(number, places, symbol, thousand, decimal) {
		if(!isNaN(Number(number))) {
			number = Number(number);
			places = !isNaN(places = Math.abs(places)) ? places : 2;
			symbol = symbol !== undefined ? symbol : "";
			thousand = thousand || ",";
			decimal = decimal || ".";
			var negative = number < 0 ? "-" : "",
				i = parseInt(number = Math.abs(+number || 0).toFixed(places), 10) + "",
				j = (j = i.length) > 3 ? j % 3 : 0;
			return symbol + negative + (j ? i.substr(0, j) + thousand : "") + i.substr(j).replace(/(\d{3})(?=\d)/g, "$1" + thousand) + (places ? decimal + Math.abs(number - i).toFixed(places).slice(2) : "");
		}
	};
	
	$.changeMoneyToChinese = function(money){  
        var cnNums = new Array("零","壹","贰","叁","肆","伍","陆","柒","捌","玖"); //汉字的数字  
        var cnIntRadice = new Array("","拾","佰","仟"); //基本单位  
        var cnIntUnits = new Array("","万","亿","兆"); //对应整数部分扩展单位  
        var cnDecUnits = new Array("角","分","毫","厘"); //对应小数部分单位  
        //var cnInteger = "整"; //整数金额时后面跟的字符  
        var cnIntLast = "元"; //整型完以后的单位  
        var maxNum = 999999999999999.9999; //最大处理的数字  
          
        var IntegerNum; //金额整数部分  
        var DecimalNum; //金额小数部分  
        var ChineseStr=""; //输出的中文金额字符串  
        var parts; //分离金额后用的数组，预定义  
        if( money == "" ){  
            return "";  
        }  
        money = parseFloat(money);  
        if( money >= maxNum ){  
            $.alert('超出最大处理数字');  
            return "";  
        }  
        if( money == 0 ){  
            //ChineseStr = cnNums[0]+cnIntLast+cnInteger;  
            ChineseStr = cnNums[0]+cnIntLast  
            //document.getElementById("show").value=ChineseStr;  
            return ChineseStr;  
        }  
        money = money.toString(); //转换为字符串  
        if( money.indexOf(".") == -1 ){  
            IntegerNum = money;  
            DecimalNum = '';  
        }else{  
            parts = money.split(".");  
            IntegerNum = parts[0];  
            DecimalNum = parts[1].substr(0,4);  
        }  
        if( parseInt(IntegerNum,10) > 0 ){//获取整型部分转换  
            zeroCount = 0;  
            IntLen = IntegerNum.length;  
            for( i=0;i<IntLen;i++ ){  
                n = IntegerNum.substr(i,1);  
                p = IntLen - i - 1;  
                q = p / 4;  
                m = p % 4;  
                if( n == "0" ){  
                    zeroCount++;  
                }else{  
                    if( zeroCount > 0 ){  
                        ChineseStr += cnNums[0];  
                    }  
                    zeroCount = 0; //归零  
                    ChineseStr += cnNums[parseInt(n)]+cnIntRadice[m];  
                }  
                if( m==0 && zeroCount<4 ){  
                    ChineseStr += cnIntUnits[q];  
                }  
            }  
            ChineseStr += cnIntLast;  
            //整型部分处理完毕  
        }  
        if( DecimalNum!= '' ){//小数部分  
            decLen = DecimalNum.length;  
            for( i=0; i<decLen; i++ ){  
                n = DecimalNum.substr(i,1);  
                if( n != '0' ){  
                    ChineseStr += cnNums[Number(n)]+cnDecUnits[i];  
                }  
            }  
        }  
        if( ChineseStr == '' ){  
            //ChineseStr += cnNums[0]+cnIntLast+cnInteger;  
            ChineseStr += cnNums[0]+cnIntLast;  
        }/* else if( DecimalNum == '' ){ 
            ChineseStr += cnInteger; 
            ChineseStr += cnInteger; 
        } */  
        return ChineseStr;  
    }  
	
    
	/**
	 * 将不是数字文本转换为 "--"
	 * @param {Object} str 文本
	 * @param {Object} num 如果是数字,可以设置小数位数
	 */
	$.transferText = function(str, num) {
		var outText = "--";
		if(str && str != 0 && !isNaN(Number(str))) {
			outText = num ? Number(str).toFixed(num) : str;
		}
		return outText;
	}

	/**
	 * 数值过万改以万为单位
	 * @param {Object} num 数值
	 * @param {Object} s 小数位数
	 */
	$.convertMillion = function(num, s) {
		var outText = "--";
		s = s !== undefined ? s : 2;
		if(num && num != 0 && !isNaN(Number(num))) {
			num = Number(num);
			outText = num >= 10000 ? (num * 0.0001).toFixed(s) + "万" : num;
		}
		return outText;
	}

	/**
	 * 获取数据的长度，和对象的属性个数
	 * @param {Object} obj
	 */
	$.size = function(obj) {
		if(obj) {
			if(typeof(obj) == "string" || obj instanceof Array) {
				return obj.length;
			} else if(typeof(obj) == "object") {
				return Object.getOwnPropertyNames(obj).length
			} else if(typeof(obj) == "number") {
				return(obj + "").length;
			}
		} else {
			return 0;
		}
	}

	/**
	 * 判断数据的值是否有用的值
	 * @param {Object} v
	 */
	$.isValue = function(v) {
		if(v && $.size(v) > 0) {
			if(typeof(v) == "string") {
				v = $.trim(v);
				if(v == "" || v == "null" || v == "undefined" || v == "false") {
					return false;
				} else {
					return true;
				}
			}
			else{
				return true;
			}
		} else {
			return false;
		}
	}
	
	/**
	 * 获取当前日前后几天的日期
	 * @param {Number} days 天数 正数为后几天，负数为前几天
	 * @param {String} format 时间显示格式
	 */
	$.getTradingDay = function(days, format){
		format = format ? format : "yyyy-MM-dd";
		var end_time  = new Date();	//截止时间
		end_time.setDate(end_time.getDate() + days);
		return end_time.format(format);
	}
	
	/**
	 * 获取obj的key的数组
	 */
	$.getObjKey = function(o) {
		var a = [];
		if($.isValue(o)){
			$.each(o, function(key) {  
				a.push(key);
			});
		}
		return a;
	};

	/**
	 * 根据字体大小和宽度获取字体缩放比例
	 * @param {string} text  	文本内容
	 * @param {String} fontSize	字体大小
	 * @param {Number} width 	指定宽度
	 */
	$.getMaxFontSize = function (text,fontSize, width) {
		if ($("body>div#nameMecism").length == 0) $("body").append("<div id=\"nameMecism\" style=\"width: 100%; height: 0;\"></div>");
		$("#nameMecism").append("<span id=\"test1\" style=\"visibility: hidden; white-space: nowrap;font-size:"+fontSize+"\">" + text + "</span>");
		var textWidth = $("#nameMecism>span[id=test1]").width();
		$("body>div#nameMecism").remove();
		var size =1;
		if (textWidth > width) size = width / (textWidth + 5);
		return size;//盒子模型缩放
	}

	/**
	 * 根据字体大下和width得到
	 * @param {string} text 
	 * @param {string, Number} width 
	 */
	$.getTransformScale = function(text, fontSize, width){
		return Math.min(1, width / $.measureText(text, fontSize));
	}

	$.getTransformScaleFontSize = function(text, fontSize, width){
		return (Math.min(1, width / $.measureText(text, fontSize)) || 1) * fontSize;
	}

	$.fn.setTransformScale = function(value){
		$(this).css("transform","scale(" + value+ ")");
	}

	//页面元素字体大小自适应
	$.pageScaleFontSize = function(optsArr){
		try{
			optsArr.forEach(function(opt){
				var width = opt.width || opt.el.width(),
				text = opt.text || opt.el.text(),
				size = opt.size || opt.el.css("font-size").replace("px", "");
				var size = $.getTransformScaleFontSize(text, size, width);
				$(opt.el).css({"font-size": size + "px" }).text(text);
			});
		}catch(e){
			console.error(e)
		}
		
	}
	
	/**
	 * 获取字符串的字节长度
	 */
	String.prototype.lenReg = function() {　　
		return this.replace(/[^x00-xFF]/g, '**').length;
	};
	

	/**
	 * 数组去除相同的数据，添加或者删除数组 
	 * @param {Array} arrays 要操作的数组
	 * @param {Object} account 添加或者删除
	 * @param {Object} isDelete 是否是删除  N
	 */
	Array.prototype.goHeavy = function(account, isDelete) {
		var arr = this;
		var len = arr.length;
		var result = [];
		if(account && !isDelete){
			result.push(account);
		}
		for(var i = 0; i < len; i++) {
			var flag = true;
			for(var j = 0; j < result.length; j++) {
				if(arr[i] == result[j]) {
					flag = false;
					break;
				}
			}
			if(account && isDelete){
				if(arr[i] == account){
					flag = false;
				}
			}
			if(flag) {
				result.push(arr[i])
			}
		}
		return result;
	}
	
	Number.prototype.toFixed0 = function(d){
		var s = this + "";
		var ss = s.split(".");
		if(ss.length == 1){
			if(d == 0){
				return ss[0];
			}
			else{
				var t = "";
				for(var i = 0; i < d; i++){
					t += "0";
				}
				return ss[0]+"."+t;
			}
		}
		else if(ss.length == 2){
			if(d == 0){
				return ss[0];
			}
			else{
				var t = ss[1];
				t = t.substring(0,d);
				for(var i = t.length; i < d; i++){
					t += "0"
				}
				return ss[0]+"."+t;
			}
		}
		else{
			return this + "";
		}
	}
	
	$.getUrlParam = function(name){
		var obj = {};
		var r = window.location.search;
		if(r){
			r = r.substr(1);
			var arr = r.split("&"); //各个参数放到数组里
			for (var i = 0; i < arr.length; i++) {
				var num = arr[i].split("=",1)[0];
				var reg = new RegExp("(^|&)"+ num +"=([^&]*)(&|$)");
				if (num.length > 0) {
					obj[num] = decodeURI((r.match(reg))[2]);
				}
			}
		}
		if(name){
			return obj[name];
		}
		else{
			return obj;
		}
	}
	
	$.setUrlParam = function(param, url){
		var st = "";
		$.each(param,function(key,value){
			st += key + "=" + value + "&";
		});
		if(st && st.length > 0){
			st = st.substring(0, st.length - 1);
		}
		if(url){
			st = url + "?"+st;
		}
		return st;
	}

	$.measureText = function(text, fontSize) {
		fontSize = fontSize || 10;
		text = String(text);
		var text = text.split('');
		var width = 0;
		text.forEach(function(item) {
			if (/[a-zA-Z]/.test(item)) {
				width += 7;
			} else if (/[0-9]|,/.test(item)) {
				width += 5.5;
			} else if (/\./.test(item)) {
				width += 2.7;
			} else if (/-/.test(item)) {
				width += 3.25;
			} else if (/[\u4e00-\u9fa5]/.test(item)) {
				width += 11;
			} else if (/\(|\)/.test(item)) {
				width += 3.73;
			} else if (/\s/.test(item)) {
				width += 2.5;
			} else if (/%/.test(item)) {
				width += 8;
			} else {
				width += 11;
			}
		});
		return width * fontSize * 0.1
	}

	$.getUUID = function(len, radix){
		var chars = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz'.split('');
		var uuid = [],
			i;
		radix = radix || chars.length;
	 
		if (len) {
			// Compact form
			for (i = 0; i < len; i++) uuid[i] = chars[0 | Math.random() * radix];
		} else {
			// rfc4122, version 4 form
			var r;
	 
			// rfc4122 requires these characters
			uuid[8] = uuid[13] = uuid[18] = uuid[23] = '-';
			uuid[14] = '4';
	 
			// Fill in random data.  At i==19 set the high bits of clock sequence as
			// per rfc4122, sec. 4.1.5
			for (i = 0; i < 36; i++) {
				if (!uuid[i]) {
					r = 0 | Math.random() * 16;
					uuid[i] = chars[(i == 19) ? (r & 0x3) | 0x8 : r];
				}
			}
		}
	 
		return uuid.join('');
	}
	
	 //除法函数
	 function accDiv(arg1, arg2) {
	     var t1 = 0, t2 = 0, r1, r2;
	     try {
	         t1 = arg1.toString().split(".")[1].length;
	     }
	     catch (e) {
	     }
	     try {
	         t2 = arg2.toString().split(".")[1].length;
	     }
	     catch (e) {
	     }
         r1 = Number(arg1.toString().replace(".", ""));
         r2 = Number(arg2.toString().replace(".", ""));
         return (r1 / r2) * Math.pow(10, t2 - t1);

	 } 
	 
	 //给Number类型增加一个div方法，，使用时直接用 .div 即可完成计算。 
	 Number.prototype.div = function (arg) {
	     return accDiv(this, arg);
	 };
	 
	 //添加tap绑定事件
	 $.fn.triggerFastTap=function(){
	 	this.trigger("tap");
	 }
	 
	 //添加blur绑定事件
	 $.fn.triggerFastBlur=function(){
	 	if(this){
	 		this.trigger("blur");
	 	}
	 }
})(Zepto)