/**
 * 信用交易-历史合约流水查询
 */
define('trade/scripts/credit/query/historyContractFlowQuery.js', function (require, exports, module) {
    var service_credit = require("service_credit");
    var common = require("common");
    var gconfig = $.config;
    var global = gconfig.global;
    var iscrollUtils = require("iscrollUtils");
    var commonFunc = require("commonFunc");
    var myScroller = null; // 滑动组件对象
    var _pageId = "#credit_query_historyContractFlowQuery ";
    var userInfo = null;

    /**
     * 初始化
     */
    function init() {
        userInfo = common.getCurUserInfo();
        commonFunc.initTimeChoice(_pageId, 6, true);
        // common.pageBuryingPoint("105384");
        if (global.requestLocation == 0) {
            backgroundInterface();
        }
    }

    function load() {
        var mianHeight = common.setMainHeightNew(_pageId, false);
        if (global.requestLocation == 1) {
            backgroundInterface();
        }
    }

    function backgroundInterface() {
        queryMsg();//查询信息
    }

    /**
     * 查询信息
     */
    function queryMsg() {
        $(_pageId + ".no_data_box").hide();
        queryContracliata(); //查询合约流水
    }

    /**
     * 事件绑定
     */
    function bindPageEvent() {
        //返回按钮
        $.bindEvent($(_pageId + ".header_inner .back_btn"), function (e) {
            // common.comStat(105385, 2, 103, true, {"i_group_name": "返回"});//埋点
            setTimeout(function () {
                $.pageBack();
                e.preventDefault();
                e.stopPropagation();
            },300);
        });

        //时间选择
        $.bindEvent($(_pageId + ".date_filter .btn"), function (e) {
            queryContracliata();
            //埋点
            var end_time = $(_pageId + " #endDate").text();
            var begin_time = $(_pageId + " #startDate").text();
            var time1 = begin_time.replaceAll("-", "");
            var time2 = end_time.replaceAll("-", "");
            var objectId = $(this).attr("objectId");
            var actionId = $(this).attr("actionId");
            common.comStat(objectId, 2, actionId, true, {
                "i_change_name": "历史合约流水查询",
                "i_change_to": time1 + "-" + time2
            });
        });

    }

    /**
     * 未偿还合约查询
     */
    function queryContracliata() {
        var end_date = $(_pageId + " #endDate").text();
        var begin_date = $(_pageId + " #startDate").text();	//截止时间
        var time1 = new Date(end_date.replaceAll("-", "/"));
        var time2 = new Date(begin_date.replaceAll("-", "/"));
        if (time1 < time2) {
            $.alert("开始日期大于截止日期");
            if (!myScroller) {
                initScroller();
            } else {
                myScroller.refresh();
            }
            return false;
        }
        $(_pageId + ".contract_flow_list").html("");
        var entrust_way = global.entrust_way; // 委托方式  在configuration配置
        var branch_no = userInfo.branch_no;	//分支机构
        var fund_account = userInfo.fund_account;	//资产账户
        var cust_code = userInfo.cust_code;	//客户代码
        var sessionid = userInfo.session_id;
        var password = userInfo.password;
        var param = {
            "entrust_way": entrust_way,
            "branch_no": branch_no,
            "fund_account": fund_account,
            "password": password,
            "cust_code": cust_code,
            "sessionid": sessionid,
            "begin_date": begin_date,
            "end_date": end_date

        };
        service_credit.credit_bdls(param, queryContracliataCallBack,
            {
                "isLastReq": true,
                "isShowWait": true,
                "isShowOverLay": false,
                "timeOutFunc": function () {
                    if (!myScroller) {
                        initScroller();
                    } else {
                        myScroller.refresh();
                    }
                }
            });//未偿还合约查询
    }

    /**
     * 未偿还合约数据查询回调方法
     */
    function queryContracliataCallBack(data) {
        if (data) {
            if (data.error_no == 0) {
                var results = data.results;
                if (results && results.length > 0) {
                    var openInterestHtml = "";
                    var isEnd = false;
                    for (var i = 0; i < results.length; i++) {
                        if ($.isValue(results[i].stock_name_long)) results[i].stock_name = results[i].stock_name_long;
                        var data = results[i];
                        if (i == results.length - 1) {
                            isEnd = true;
                        }
                        openInterestHtml += createHtml(data, isEnd);
                    }
                    $(_pageId + ".contract_flow_list").html(openInterestHtml);
                    $(_pageId + ".contract_flow_list").append('<div class="no_more_data" style="padding-top: 0.1rem;">没有更多数据了</div>');
                    $(_pageId + ".no_data_box").hide();
                } else {
                    $(_pageId + ".no_data_box").show();
                }
                if (!myScroller) {
                    initScroller();
                } else {
                    myScroller.refresh();
                }
            } else {
                $.alert(data.error_info);
            }
        }
    }

    /**
     * 生成未偿还合约html
     * @param {Object} element 数据项
     */
    function createHtml(element, isEnd) {
        var compactTypes = {"0": "融资", "1": "融券", "2": "其他负债"};
        var eleHtml = "";
        var stock_name = $.trim(element.stock_name) ? $.trim(element.stock_name) : "--";
        var stock_code = $.trim(element.stock_code) ? $.trim(element.stock_code) : "--";
        if (isEnd) {//最后一个，取消下边框样式
            eleHtml += '<div class="list_item" style="margin-bottom: 0;">';
        } else {
            eleHtml += '<div class="list_item">';
        }
        eleHtml += '<div class="li_top border_bottom">';
        eleHtml += '<span class="label_text" style="padding-left: 0;">' + element.init_date + '</span>';
        eleHtml += '<p class="fr_text" id="' + element.compact_id + '">编号 ' + element.compact_id + '</p>';
        eleHtml += '</div>';
        eleHtml += '<div class="li_con">';
        eleHtml += '<ul class="flow_list flow_list2">';
        eleHtml += '<li><span class="flow_list_stock_name_long" style="font-size:'+ $.getTransformScaleFontSize(stock_name, 14, 65) +'px;">' + stock_name + '</span>' + stock_code + '</li>';
        eleHtml += '<li><span>合约类型</span>' + compactTypes[element.compact_type] + '</li>';
        eleHtml += '<li><span>发生金额</span>' + element.occur_balance + '</li>';
        eleHtml += '<li><span>发生数量</span>' + element.occur_amount + '</li>';
        eleHtml += '<li><span>后资金额</span>' + element.post_balance + '</li>';
        eleHtml += '<li><span>后证券额</span>' + element.post_amount + '</li>';
        eleHtml += '<li><span>发生费用</span>' + element.occur_fare + '</li>';
        eleHtml += '<li><span>后余费用</span>' + element.post_fare + '</li>';
        eleHtml += '<li><span>发生利息</span>' + element.occur_interest + '</li>';
        eleHtml += '<li><span>后余利息</span>' + element.post_interest + '</li>';
        eleHtml += '<li><span>业务标志</span>' + (element.business_flag_name ? element.business_flag_name : "--") + '</li>';
        eleHtml += '</ul>';
        eleHtml += '</div>';
        eleHtml += '</div>';
        return eleHtml;
    }


    function initScroller() {
        var scrollOptions = {
            scrollerHeight: $(window).height() - $(_pageId + "header").height() - $(_pageId + ".date_filter").height() + 2, // 滚动组件的高度
            pullThreshold: 5, // 拖动刷新或者加载的阀值，默认 5 像素
            $wrapper: $(_pageId + " #wrapper"),
            hasPullDown: true, // 是否显示下拉提示，默认 true
            hasPullUp: false, // 是否显示上拉提示，默认 true
            isAlwaysShowPullUp: false, // 是否一直显示上拉提示，true 一直显示上拉加载的提示，false 仅在上拉的时候显示提示，默认 true
            pullDownHandler: function () {
                queryMsg();//下拉获取上一页数据方法
                // common.comStat(105386, 2, 102, true, {"i_direct": "下拉", "i_type": "1"});
            },
            pullUpHandler: function () {
            }
        };
        if (!myScroller) {
            // 内容的高度比滚动区域高度小时
            // iscrollUtils 已有相同判断的代码，此处这样写的目的是为了解决 Android UC、微信等浏览器滚动失效的问题，在 iscrollUtils 设置高度，在初始化组件时，取到的值不准确
            if (scrollOptions.$wrapper.find("[data-is-content='true']").height() <= scrollOptions.scrollerHeight) {
                scrollOptions.$wrapper.children().height(scrollOptions.scrollerHeight + 1);
            }
            myScroller = iscrollUtils.vScroller(scrollOptions);
        } else {
            myScroller.refresh();
        }
    }

    /**
     * 销毁
     */
    function destroy() {
        common.pageBuryingPoint();
        $(_pageId + ".contract_flow_list").html("");
        $(_pageId + ".no_data_box").hide();
        if (myScroller) {
            myScroller.destroy();
            myScroller = null;
        }
    }

    var base = {
        "init": init,
        "load": load,
        "bindPageEvent": bindPageEvent,
        "destroy": destroy
    };
    module.exports = base;
});
