/**
 * ETF基金赎回（T2、顶点）
 */
define('trade/scripts/fund/etfFund/etfRedeem.js', function (require, exports, module) {
    var _pageId = "#fund_etfFund_etfRedeem ";
    var gconfig = $.config;
    var global = gconfig.global;
    var common = require("common");
    var commonHq = require("commonHq");
	var nativePluginService = require("nativePluginService");
    var keyboard = require("keyboard");
    var service_fundETF = require("service_fundETF");
    var etfLineChart = require("etfLineChart");
    require("validatorUtils");
    var validata = $.validatorUtils;
    var fundDataList = {};
    var userInfo = null;
    var listData = {};

    /**
     * 初始化
     */
    function init() {
        userInfo = common.getCurUserInfo();
        if (keyboard) {
            keyboard.keyInit();
        }
        common.setMainHeight(_pageId, false);
        etfLineChart.initHtml();
        // 页面高度变化重置滚动容器高度
        window.onresize = function () {
            common.setMainHeight(_pageId, false);
        };
    }

    function load() {
        etfHoldPositionsQuery();
    }

    /**
     * 事件绑定
     */
    function bindPageEvent() {
        //返回按钮
        $.bindEvent($(_pageId + " .top_title .icon_back"), function (e) {
            $(this).unbind(e.type);
            this[e.type] = null;
            if (keyboard) {
                keyboard.closeKeyPanel();
            }
            var param = $.getPageParam("param");
            if (param && param.form === 'mall') {
                $.callMessage({
                    "moduleName": "mall_trade",
                    "funcNo": "50114",
                });
            }else{
                $.pageInit("fund/etfFund/etfRedeem", "fund/etfFund/home", {}, "left", true);
            }
            e.stopPropagation();
            e.preventDefault();
        });

        //点击股票输入框
        $.bindEvent($(_pageId + " #fundCode"), function (e) {
            if (keyboard) {
                keyboard.clickOpenKeyboard($(this), _pageId);
            }
            $(_pageId + " .cmpscode").show();
            e.stopPropagation();
        });

        //股票代码输入框监听
        $.bindEvent($(_pageId + " #fundCode"), function (e) {
            if (keyboard) {
                keyboard.popUpKeyboard($(this), e);
            }
            var fundCode = $(_pageId + " #fundCode").val();
            var fundNumber = $(_pageId + " #fundNumber").val();
            if (fundCode.length > 0 && fundNumber.length > 0) {
                $(_pageId + '.applyvote a').removeClass('btn-disable');
            } else {
                $(_pageId + '.applyvote a').addClass('btn-disable');
            }
            if (fundCode.length == 6) {
                getFundList(fundCode);
                if (keyboard) {
                    keyboard.closeKeyPanel();
                }
            } else {
                clearBuyMsg();
            }
            e.stopPropagation();
        }, "input");

        // 股票代码键盘确定按钮回调
        window.etfRedeemFundcodeSure = function(){
          $(_pageId + " .cmpscode").hide();
        }
        // 股票代码键盘隐藏按钮回调
        window.etfRedeemFundcodeHide = function(){
          $(_pageId + " .cmpscode").hide();
        }

        //点击认购份额输入框
        $.bindEvent($(_pageId + " #fundNumber"), function (e) {
          if (keyboard) {
              keyboard.clickOpenKeyboard($(this), _pageId);
          }
          $(_pageId + " .cmpscode").hide();
          e.stopPropagation();
        });
        //认购份额输入框监听
        $.bindEvent($(_pageId + " #fundNumber"), function (e) {
            if (keyboard) {
                keyboard.popUpKeyboard($(this), e);
            }
            var fundNumber = $(_pageId + " #fundNumber").val();
            var fundCode = $(_pageId + " #fundCode").val();
            if (fundCode.length > 0 && fundNumber.length > 0) {
                $(_pageId + '.applyvote a').removeClass('btn-disable');
            } else {
                $(_pageId + '.applyvote a').addClass('btn-disable');
            }
        }, "input");

        //全部
        $.bindEvent($(_pageId + " #all"), function (e) {
            if (keyboard) {
                keyboard.closeKeyPanel();
            }
            var maxNumber = $(_pageId + " #maxNumber").quzhi();
            if (!maxNumber) {
                return false;
            }
            $(_pageId + "#fundNumber").quzhi(maxNumber);
            $(_pageId + " .cmpscode").hide();
            e.stopPropagation();
        });

        //赎回
        $.bindEvent($(_pageId + ".applyvote .nocheck"), function (e) {
            $(_pageId + " .cmpscode").hide();
            if (keyboard) {
                keyboard.closeKeyPanel();
            }
            vailSubmitOrder();
            e.stopPropagation();
        });

        //点击页面其他地方
        $.bindEvent($(_pageId), function (e) {
            if (keyboard) {
                keyboard.closeKeyPanel();
            }
            $(_pageId + " .cmpscode").hide();
        });
        etfLineChart.bindPageEvent();
    }

    /**
     * 获取基金列表
     * */
    function getFundList(fundStr, exchange_type) {
        $(_pageId + " .cmpscode").hide();
        if (fundStr != "" && fundStr.length == 6) {
            clearBuyMsg();
            var entrust_way = global.entrust_way; // 委托方式  在configuration配置
            var stock_code = fundStr;
            var entrust_bs = "1";//认购、申购是买入、赎回是卖出
            var branch_no = userInfo.branch_no;
            var fund_account = userInfo.fund_account;
            var cust_code = userInfo.cust_code;//关联资产账户标志
            var param = {
                "entrust_way": entrust_way,
                "branch_no": branch_no,
                "fund_account": fund_account,
                "cust_code": cust_code,
                "entrust_bs": entrust_bs,
                "stock_code": stock_code,
                "exchange_type": exchange_type,
                "organ_flag": userInfo.organ_prop
            };
            service_fundETF.etfStockMaxBuyQuery(param, getFundInfoBack);
        }
    }

    function getFundInfoBack(data) {
        if (data.error_no == 0) {
            var results = data.results;
            if (results && results.length > 0) {
                // 判断证券类别是否为N
                if(results[0].can_buy_flag === "0"){
                    common.iConfirm("温馨提示","代码输入有误，请输入交易代码",function(){}, function fail() {
                        checkRight();
                    },"重新输入", "取消");
                }else{
                    checkRight();
                }
                if ($.isValue(results[0].stock_name_long)) results[0].stock_name = results[0].stock_name_long;
                var nav = results[0].price ? results[0].price : "0";
                nav = Number(nav).toFixed(4);
                $(_pageId + "#fundCode").quzhi(results[0].stock_code);//赎回代码
                $(_pageId + "#fundName").quzhi(results[0].stock_name);//基金名称
                $(_pageId + "#fundNav").quzhi(nav);//基金净值
                //				$(_pageId+"#fundUnit").quzhi(results[0].buy_unit);//赎回单位
                $(_pageId + "#fundUnit").quzhi(results[0].report_unit);//赎回单位
                $(_pageId + "#maxNumber").quzhi(results[0].stock_max_amount);//可赎回数
                var maxNumber2 = Math.floor(Number(results[0].stock_max_amount) / Number(results[0].report_unit));
                $(_pageId + "#maxNumber2").quzhi(isFinite(maxNumber2) ? maxNumber2 : 0);//可赎回数蓝数
                fundDataList = results[0];
                etfLineChart.showContent(fundDataList);
                // 校验权限
                function checkRight(){
                    if(userInfo.organ_prop === "0" && results[0].right_flag === "0"){
                        common.iConfirm("温馨提示", "您还未开通" + results[0].etfcode_type_name + "的权限", function success(html) {
                            if (global.callNative && global.isSso) {
                                nativePluginService.function501152({
                                    "url":global.newFrameUrl + "fintechpages/business/index.html#/etfBuy/index",
                                    "uniqueCode":"PalmHall-etfBuy/index",
                                    "loginMode":"2"
                                });
                            }
                        }, function fail() {
                        }, "去开通", "取消");
                    }
                }
            } else {
                $.alert("该证券不支持此类交易");
            }
        } else {
            $.alert(data.error_info);
        }
    }

    /**
     * 下单验证
     * */
    function vailSubmitOrder() {
        // if ($.size(listData) == 0) {
        //     $.alert("没有可赎回的基金");
        //     return false;
        // }

        var stock_code = $(_pageId + " #fundCode").val();

        if (!$.isValue(stock_code)) {
            $.alert("请选可赎回的基金");
            return false;
        }
        //验证赎回代码输入是否正确
        if (stock_code.length == 0) {
            $.alert("请输入赎回代码");
            return false;
        }
        if (stock_code.length != 6) {
            $.alert("赎回代码输入错误");
            return false;
        }
        //验证基金份额输入是否正确
        var fundNumber = $(_pageId + "#fundNumber").val();
        if ($.trim(fundNumber).length <= 0) {
            $.alert("请输入委托数量 ");
            return false;
        } else if (fundNumber == "0") {
            $.alert("委托数量不能为0");
            return false;
        } else if (!validata.isNumberFloat(fundNumber) || parseFloat(fundNumber) < 0) {
            $.alert("请正确输入委托数量 ");
            return false;
        }
        var orderAmount = +fundDataList.report_unit * +fundNumber;
        var tipStrArray = [];
        tipStrArray.push(["赎回代码 ", fundDataList.stock_code]);
        tipStrArray.push(["基金名称", fundDataList.stock_name]);
        tipStrArray.push(["委托数量 ", fundNumber + "篮" + "(" + orderAmount + "股)"]);
        var tipStr = "<div >";
        tipStr += common.generatePrompt(tipStrArray);
        tipStr += "</div>";

        common.iConfirm("赎回确认", tipStr, function success() {
            var param = {
                "entrust_way": global.entrust_way,
                "branch_no": userInfo.branch_no,
                "fund_account": userInfo.fund_account,
                "cust_code": userInfo.cust_code,
                "session_id": userInfo.session_id,
                "password": userInfo.password,
                "stock_code": fundDataList.stock_code,
                "exchange_type": fundDataList.exchange_type,
                "stock_account": fundDataList.stock_account,
                "entrust_amount": orderAmount,
                "entrust_price": fundDataList.price,
            };
            // 如果是深圳 跨市ETF 增加 channel_type 参数
            if(commonHq.getHqMarket(fundDataList.exchange_type) === "SZ" && fundDataList.etfcode_type === "3"){
                param.channel_type = fundDataList.channel_type;
            }
            service_fundETF.etfRedeem(param, function (data) {
                $.hidePreloader();
                getBuyCallBack(data, param);
            }, {
                "isLastReq": false, "isShowWait": false,
                "timeOutFunc": function () {
                    $.hidePreloader();
                }, "errorFunc": function () {
                    $.hidePreloader();
                }
            });
            $.showPreloaders("请等待...");
        }, function fail() {
        });
    }

    //申购回调
    function getBuyCallBack(data, param) {
        if (data.error_no == 0) {
            var results = data.results;
            if (results) {
                $.alert("委托已经提交，委托编号：" + results[0].entrust_no);
                clearBuyMsg();
                $(_pageId + "#fundCode").quzhi("");
            }
        } else {
            $.alert(data.error_info);
        }
    }

    /**
     * 持仓查询（赎回列表查询）
     * 调用两个接口 股份查询，资金查询
     */
    function etfHoldPositionsQuery() {
        $(_pageId + ".cmpscode").html("").hide().css({ "height": "0rem" });
        var entrust_way = global.entrust_way; // 委托方式  在configuration配置
        var branch_no = userInfo.branch_no;	//分支机构
        var fund_account = userInfo.fund_account;	//资产账户
        var cust_code = userInfo.cust_code;	//客户代码
        var session_id = "";
        var fund_code = "";
        var param = {
            "entrust_way": entrust_way,
            "branch_no": branch_no,
            "fund_account": fund_account,
            "cust_code": cust_code,
            "session_id": session_id,
            "fund_code": fund_code,
            "query_flag": "0"//场内开放式基金
        };
        service_fundETF.etfHoldPositionsQuery(param, queryFundDataCallback);
    }

    //持仓查询回调方法
    function queryFundDataCallback(data) {
        if (data) {
            if (data.error_no == 0) {
                var results = data.results;
                if (results && results.length > 0) {
                    $(_pageId + " #fundCode").setPlaceholder("请输入赎回ETF代码");
                    listData = {};
                    var listDiv = "";
                    for (var i = 0; i < results.length; i++) {
                        if ($.isValue(results[i].stock_name_long)) results[i].stock_name = results[i].stock_name_long;
                        listData[results[i].stock_code + ""] = results[i];
                        listDiv += "<p stock_code='" + results[i].stock_code + "' exchange_type='" + results[i].exchange_type + "' stock_account='" + results[i].stock_account + "'><span>" + results[i].stock_code + "</span>" + results[i].stock_name + "</p>";
                    }
                    $(_pageId + " .cmpscode").html(listDiv);
                    if ($(_pageId + " .cmpscode p").length >= 4) {
                        $(_pageId + ".cmpscode").css({ "height": "1.8rem", "overflow": "scroll" });
                    } else {
                        $(_pageId + ".cmpscode").css({ "height": (($(_pageId + " .cmpscode p").length) * 0.45) + "rem" });
                    }
                    //列表选择事件
                    $.bindEvent($(_pageId + " .cmpscode p"), function (e) {
                        if (keyboard) {
                            keyboard.closeKeyPanel();
                        }
                        var stockCode = $(this).attr("stock_code");
                        var exchangeType = $(this).attr("exchange_type");
                        var stockAccount = $(this).attr("stock_account");
                        getFundList(stockCode, exchangeType, stockAccount);
                        e.stopPropagation();
                    });
                } else {
                    listData = {};
                    $(_pageId + " #fundCode").setPlaceholder("暂无可赎回基金");
                }
            } else {
                $.alert(data.error_info);
            }
        }
    }

    /*
     * 清除页面信息
     */
    function clearBuyMsg() {
        fundDataList = {};
        $(_pageId + "#fundName").quzhi("");//基金名称
        $(_pageId + "#fundNav").quzhi("");//基金净值
        $(_pageId + "#fundUnit").quzhi("");//申购单位
        $(_pageId + "#maxNumber").quzhi("");//可申购数
        $(_pageId + "#fundNumber").quzhi("");//申购份额
        $(_pageId + "#maxNumber2").quzhi("");//可赎回数蓝数
        $(_pageId + '.applyvote a').addClass('btn-disable');
        etfLineChart.clearData();
    }

    /**
     * 销毁
     */
    function destroy() {
        $.clearRequest();
        $(_pageId + "#fundCode").quzhi("");
        if (keyboard) {
            keyboard.keyDestroy();
        }
        clearBuyMsg();
        $(_pageId + " #fundCode").setPlaceholder("请输入赎回ETF代码");
        $(_pageId + ".cmpscode").html("").hide().css({ "height": "0rem" });//赎回下拉列表
    }


    var base = {
        "init": init,
        "load": load,
        "bindPageEvent": bindPageEvent,
        "destroy": destroy
    };
    module.exports = base;
});
