define('trade/scripts/hq/chart/hqCommon.js',function(require, exports, module) {
	var gconfig = $.config;
	var global = gconfig.global;
	var service = require("chartservice_hq");
	var project = require("project");
	// 新规债券上海市场二级类型
	var secondTypeArrBySH = project.constants.secondTypeArrBySH;
	// 新规债券深圳市场二级类型
	var secondTypeArrBySZ = project.constants.secondTypeArrBySZ;
    // 二级分类中的债券类型
    var bondTypeSecond = project.constants.bondTypeSecond;

	function firstLoadFunc() { // 行情模块首次加载启动的逻辑
//		setDefaultZxg(); // 设置默认的自选股
////		isSyncZxgFun(); // 是否同步自选股
//		initHQTimer(); // 行情定时器
	}

	/**
	 * 设置默认的自选股
	 * isFirstLoad只有在第一次启动时才会从空设置为true，之后启动就不会进if语句重新设置自选股数据
	 * localZxgList保存本地自选股数据 格式为："股票市场:股票代码|股票市场:股票代码|股票市场:股票代码..."
	 * */
	function setDefaultZxg() {
		var isFirstLoad = nativePluginServiceFunction(2, 2, "isFirstLoad", null); // 第一次取不到此值
		if(isFirstLoad != "true") { 
			nativePluginServiceFunction(1, 2, "isFirstLoad", "true"); // 第一次赋值为true
			nativePluginServiceFunction(1, 2, "localZxgList", global.defaultZxg, true); // 将设置的默认自选股存入本地自选股列表中
		}
	}

	/**
	 * 存取数据到session或local
	 * type 存或者取 1表示存，2表示取
	 * dire session或local 1表示session，2表示local
	 * key 存值或取值时的key
	 * value 存值时的value 取值时传null
	 * flag 是否需要多模块共享 false时可不传 false也表示取至cookie多模块取
	 * options 存cookie 
	 * */
	function nativePluginServiceFunction(type, dire, key, value, flag, options) {
		if(type == 1 && dire == 1) { // 存至session
			$.setSessionStorage(key, value, flag);
		} else if(type == 1 && dire == 2) { // 存至local
			$.setLocalStorage(key, value, flag);
		} else if(type == 2 && dire == 1) { // 取至session
			return $.getStorage(key, flag, options);
		} else if(type == 2 && dire == 2) { // 取至local
			return $.getStorage(key, flag, options);
		}
	}

	/**
	 * 判断交易是否登录来存取自选股数据
	 * type 存或者取 1表示存，2表示取
	 * value 存值时的value 取值时传null
	 * callBack 查询自选股时接口异步请求的回调
	 * */
	function isTradeLogin(type, value, callBack) {
		var clientid = nativePluginServiceFunction(2, 1, "clientid", null, true, {"shareCookie": true}); // 获取交易模块登录成功后保存的客户号
		if(clientid && type == 2) { // 取数据库的自选股
			queryZxgStore(clientid, function callback(bankZxgList) {
				callBack(bankZxgList);
			}); // 查询数据库自选股
		} else if(clientid && type == 1) { // 存自选股数据至数据库
			updateZxgStore(clientid, value); // 修改并保存数据库的自选股
		} else if(!clientid && type == 2) { // 取本地自选股
			callBack(nativePluginServiceFunction(2, 2, "localZxgList", null, true));
		} else if(!clientid && type == 1) { // 存本地自选股
			nativePluginServiceFunction(1, 2, "localZxgList", value, true);
		}
	}

	/**
	 * 行情定时器 实时判断是否需要发请求，减少非交易时间请求接口耗损的流量
	 * @param funcno = 29999
	 * @param version = 1 固定
	 * callback 回调函数
	 * obj[0] = 股票数量 Number
	 * obj[1] = 行情日期（转码机初始化日期） string
	 * obj[2] = 沪深行情源时间 string
	 * obj[3] = 行情服务器时间 string
	 * obj[4] = 港股通行情源时间 string
	 * */
	function initHQTimer() {
		var param = {};
		service.getHqState(param, getHqStateCallBack); // 获取转码机、行情服务器时间和日期
		var hqHeartTime = !isNaN(Number(global.hqHeartTime)) ? Number(global.hqHeartTime) : 30;
		//将标识暴露到window全局下，用于从行情切换至交易、开户等模块时清除该定时器，也可不清除
		window.hqCommonInterval = setInterval(function() {
			service.getHqState(param, getHqStateCallBack);
		}, hqHeartTime * 1000);
	}

	function getHqStateCallBack(data) {
		data = resultsVoFunc(data);
		if (data) {
			if(data.errorNo == 0) {
				if(data.results.length > 0) {
					var obj = data.results[0]; // 取行情服务器状态信息
					var hvDate = isDataFunc(obj[1], 1); // 行情日期（转码机初始化日期）
					var serverDate = isDataFunc(obj[3], 1); // 行情服务器机器日期
					var hqServerTime = Number(isDataFunc(obj[3], 2)); //行情服务器机器时间
					window.hvDate = Number(hvDate); // 保存用于K线图上最后一条数据填充的日期
					if(hvDate != serverDate) { // 周六、周日、节假日等 转码机将返回当前时间(行情服务器机器日期)之前最近的一个交易日期
						nativePluginServiceFunction(1, 1, "isTrade", "false"); // 非个股交易时间
						nativePluginServiceFunction(1, 1, "isHKTrade", "false"); // 非港股交易时间
					}else {
						isTradeFunc(hqServerTime); // 交易时间的判定
					}
				}else { // 取客户端时间
					isTradeFunc();
				}
			} else {
//				layerUtils.dialog(0, data.errorInfo);
				isTradeFunc();
			}
		}else {
			isTradeFunc();
		}
	}

	/**
	 * 判断值的类型并返回需要部分
	 * str 值
	 * type 类型 1：日期，2：时间
	 * */
	function isDataFunc(str, type) {
		var data = "";
		if(str && typeof str == "string") { // 判断是否为字符串
			if(type == 1) { // 需要日期
				data = str.length >= 8 ? str.substring(0,8) : "";
			} else if(type == 2) { // 需要时间
				data = str.length >= 12 ? str.substring(8,12) : "";
			}
		}
		return data;
	}
	
	function formatFunc(date, fmt)   // ie浏览器date.format方法报错
	{ //author: meizz   yyyy-MM-dd HH:mm:ss
	  var o = {   
	    "M+" : date.getMonth()+1,                 //月份   
	    "d+" : date.getDate(),                    //日   
	    "H+" : date.getHours(),                   //小时   
	    "m+" : date.getMinutes(),                 //分   
	    "s+" : date.getSeconds(),                 //秒   
	    "q+" : Math.floor((date.getMonth()+3)/3), //季度   
	    "S"  : date.getMilliseconds()             //毫秒   
	  };   
	  if(/(y+)/.test(fmt))   
	    fmt=fmt.replace(RegExp.$1, (date.getFullYear()+"").substr(4 - RegExp.$1.length));   
	  for(var k in o)   
	    if(new RegExp("("+ k +")").test(fmt))   
	  fmt = fmt.replace(RegExp.$1, (RegExp.$1.length==1) ? (o[k]) : (("00"+ o[k]).substr((""+ o[k]).length)));   
	  return fmt;   
	}

	function isTradeFunc(time) { // 判断是否在交易时间
		if(!time) {
			window.hvDate = formatFunc(new Date(), "yyyyMMdd");
			var time = formatFunc(new Date(), "HHmm");
			time = Number(parseFloat(time));
		}

		//判断行情服务器时间是否在个股交易时间
		if(time < global.hqFlushTime.startTime || (time > global.hqFlushTime.noonShutTime && time < global.hqFlushTime.noonStartTime) || time > global.hqFlushTime.shutTime) {
			nativePluginServiceFunction(1, 1, "isTrade", "false"); // 非个股交易时间
		}else {
			nativePluginServiceFunction(1, 1, "isTrade", "true"); // 非个股交易时间
		}

		//判断行情服务器时间是否在港股交易时间
		if(time < global.hqHKFlushTime.startTime || (time > global.hqHKFlushTime.noonShutTime && time < global.hqHKFlushTime.noonStartTime) || time > global.hqHKFlushTime.shutTime) {
			nativePluginServiceFunction(1, 1, "isHKTrade", "false"); // 港股交易时间
		}else {
			nativePluginServiceFunction(1, 1, "isHKTrade", "true"); // 港股交易时间
		}
	}

	/**
	 *  根据返回的数据填充列表
	 * @param {Object} id:0-自选股/热门行业，1-领涨股，2-领跌股，3-基金，4-债券，5-资金流入，6-资金流出，7-换手率，8-港股通，9-沪股通，10-AH股，11-认购，12-认沽
	 * @param {Object} stockList 列表数据(0-涨幅，1-现价，2-涨跌,3-类型，4-名称，5-市场，6-代码，7-总市值)
	 * @param {Object} titleName 自选股标头名称(涨跌幅，涨跌额，总市值)
	 * @return 返回值
	 * */
	function addListData(id, stockList, titleName) {
		//获得的数据正常，往下走
		var stockArray = {left:[],right:[]};
		var localZxgList = nativePluginServiceFunction(2, 2, "localZxgList", null, true);
		for(var i = 0, len = stockList.length; i < len; i++) {
			var stock = stockList[i]; // 获取某只股票数据
			if(stock && stock.length<=0)continue;
			var point = typePoint(stock.stockType); // 精确位数
			var zde = stock.up.toFixed(point); // 涨跌额
			var hsl = (stock.hsl * 100).toFixed(2) + "%"; // 换手率
			var syl = stock.pgr ? stock.pgr.toFixed(point) : "--"; // 市盈率
			var mrj = stock.buy ? stock.buy.toFixed(point) : "--"; // 买入价
			var mcj = stock.sell ? stock.sell.toFixed(point) : "--"; // 卖出价
			var jk = stock.open.toFixed(point); // 今开
			var zs = stock.yesterday.toFixed(point); // 昨收
			var zg = stock.high.toFixed(point); // 最高
			var zdi = stock.low.toFixed(point); // 今最低
			var zf = (stock.flux * 100).toFixed(2) + "%"; // 振幅
			var dd2Text = (stock.uppercent * 100).toFixed(2) + "%"; // 涨跌幅
			var dd1Text = stock.now.toFixed(point); // 现价
			var dd0Code = stock.stockCode; // 股票代码
			var dd0Market = stock.market; // 股票市场 
			var dd0Name = stock.stockName; // 股票名称
			var isSuspend = stock.isSuspend; // 是否停牌

			var curStyle = judgeColorValue(2, stock.now - stock.yesterday);
			if(zde){
				curStyle = judgeColorValue(2, zde);
			}
			dd0Name = (judgeStrGetLenthFun(dd0Name) >= 14 && global.nameMecismType == "1") ? (dd0Name.substring(0, 6) + "...") : dd0Name; // 列表列表股票名称字体过长时用跑马灯形式显示
			var amount = judgeColorValue(3, stock.amount);
			var nameStyle = (localZxgList && localZxgList.indexOf(dd0Market + ":" + dd0Code) > -1) ? "blue1" : "";
			var rMarkText = "";
			if(":98:99:".indexOf(":" + stock.stockType + ":") > -1) { // 港股通
				rMarkText = "<span>H</span>";
			} else if(stock.rMark) { // 融标的股票
				rMarkText = "<span>R</span>";
			}
			
			if((id == 5 || id == 6) && isNaN(dd2Text)) { // 资金流入、流出汉字单位增加样式
				var num = dd2Text.substring(0, dd2Text.length - 1);
				var unit = dd2Text.substr(dd2Text.length - 1, 1);
				if(judgeStrGetLenthFun(num) > 6) {
					num = Number(num).toFixed(1); // 在iPhone6微信上访问如8888.88万时会换行
				}
				dd2Text = num + "<em style=\"font-size:0.14rem;font-weight: bold;display: inline-block;vertical-align: middle;margin-top: -0.04rem;\">" + unit + "</em>";
			}
			var leftHtml = "<tr class=\"pad_top\"><td class=\"text_cen\">"+(i+1)+"</td><td class=\"text_left\">"+dd0Code+"</td>"+
			"<td class=\"text_left " + nameStyle + "\"><em></em>"+dd0Name+"</td></tr>";
			var rightHtml = "<tr class=\"pad_top\"><td class=" + curStyle + ">" + rMarkText +(isSuspend == 1 ? "--" : dd2Text)+"</td><td class=" + curStyle + ">"+(isSuspend == 1 ? "--" : dd1Text)+"</td>"+
			"<td class=" + curStyle + ">"+(isSuspend == 1 ? "--" : zde)+"</td><td class=\"blue\">"+(isSuspend == 1 ? "--" : amount)+"</td><td>"+(isSuspend == 1 ? "--" : hsl)+"</td>"+
			"<td>"+(isSuspend == 1 ? "--" : syl)+"</td><td class=" + judgeColorValue(2, stock.buy - stock.yesterday) + ">"+(isSuspend == 1 ? "--" : mrj)+"</td><td class=" + judgeColorValue(2, stock.sell - stock.yesterday) + ">"+(isSuspend == 1 ? "--" : mcj)+"</td><td class=" + judgeColorValue(2, stock.open - stock.yesterday) + ">"+(isSuspend == 1 ? "--" : jk)+"</td>"+
			"<td>"+zs+"</td><td class=" + judgeColorValue(2, stock.high - stock.yesterday) + ">"+(isSuspend == 1 ? "--" : zg)+"</td><td class=" + judgeColorValue(2, stock.low - stock.yesterday) + ">"+(isSuspend == 1 ? "--" : zdi)+"</td><td>"+(isSuspend == 1 ? "--" : zf)+"</td>" +
					"<td>"+(isSuspend == 1 || !stock.volume ? "--" : judgeColorValue(3, stock.volume))+"</td>" +
					"<td class=" + judgeColorValue(2, stock.min5change) + ">"+(isSuspend == 1 ? "--" : (stock.min5change * 100).toFixed(2))+"</td>" +
					"<td>"+(isSuspend == 1 || !stock.volrate ? "--" : stock.volrate.toFixed(point))+"</td>" +
					"<td class=" + judgeColorValue(2, stock.average - stock.yesterday) + ">"+(isSuspend == 1 || !stock.average ? "--" : stock.average.toFixed(point))+"</td>" +
					"<td class=\"green\">"+(isSuspend == 1 ? "--" : (stock.inside > 10000 ? judgeColorValue(3, stock.inside) : (stock.inside || "--")))+"</td>" +
					"<td class=\"read\">"+(isSuspend == 1 ? "--" : (stock.outside > 10000 ? judgeColorValue(3, stock.outside) : (stock.outside || "--")))+"</td>" +
					"<td>"+(isSuspend == 1 || !stock.thedeal ? "--" : judgeColorValue(3, stock.thedeal))+"</td>" +
					"<td>"+(isSuspend == 1 || !stock.ltsz ? "--" : judgeColorValue(3, stock.ltsz))+"</td>" +
					"<td>"+(isSuspend == 1 || !stock.zsz ? "--" : judgeColorValue(3, stock.zsz))+"</td>" +
					"</tr>";
			stockArray.left.push(leftHtml);
			stockArray.right.push(rightHtml);
			
//			var stockHtml = "<tr class=\"pad_top\"><td class=\"text_cen\">"+(i+1)+"</td><td class=\"text_left\">"+dd0Code+"</td>"+
//						"<td class=\"text_left " + nameStyle + "\">"+dd0Name+"</td><td class=" + curStyle + ">" + rMarkText +(isSuspend == 1 ? "--" : dd2Text)+"</td><td class=" + curStyle + ">"+(isSuspend == 1 ? "--" : dd1Text)+"</td>"+
//						"<td class=" + curStyle + ">"+(isSuspend == 1 ? "--" : zde)+"</td><td class=\"blue\">"+(isSuspend == 1 ? "--" : amount)+"</td><td>"+(isSuspend == 1 ? "--" : hsl)+"</td>"+
//						"<td>"+(isSuspend == 1 ? "--" : syl)+"</td><td class=" + judgeColorValue(2, stock.buy - stock.yesterday) + ">"+(isSuspend == 1 ? "--" : mrj)+"</td><td class=" + judgeColorValue(2, stock.sell - stock.yesterday) + ">"+(isSuspend == 1 ? "--" : mcj)+"</td><td class=" + judgeColorValue(2, stock.open - stock.yesterday) + ">"+(isSuspend == 1 ? "--" : jk)+"</td>"+
//						"<td>"+zs+"</td><td class=" + judgeColorValue(2, stock.high - stock.yesterday) + ">"+(isSuspend == 1 ? "--" : zg)+"</td><td class=" + judgeColorValue(2, stock.low - stock.yesterday) + ">"+(isSuspend == 1 ? "--" : zdi)+"</td><td>"+(isSuspend == 1 ? "--" : zf)+"</td><td>"+(isSuspend == 1 ? "--" : zf)+"</td><td>"+(isSuspend == 1 ? "--" : zf)+"</td><td>"+(isSuspend == 1 ? "--" : zf)+"</td></tr>";
//			stockArray.push(stockHtml);
		}
		return stockArray;	
	}
	
	function addFundListData(id, stockList, titleName) {
		//获得的数据正常，往下走
		var stockArray = {left:[],right:[]};
		var localZxgList = nativePluginServiceFunction(2, 2, "localZxgList", null, true);
		for(var i = 0, len = stockList.length; i < len; i++) {
			var stock = stockList[i]; // 获取某只股票数据
			if(stock && stock.length<=0)continue;
			var point = typePoint(stock.stockType); // 精确位数
			var zde = stock.up.toFixed(point); // 涨跌额
			var hsl = (stock.hsl * 100).toFixed(2) + "%"; // 换手率
			var dd2Text = (stock.uppercent * 100).toFixed(2) + "%"; // 涨跌幅
			var dd1Text = stock.now.toFixed(point); // 现价
			var dd0Code = stock.stockCode; // 股票代码
			var dd0Market = stock.market; // 股票市场 
			var dd0Name = stock.stockName; // 股票名称
			var isSuspend = stock.isSuspend; // 是否停牌

			var curStyle = judgeColorValue(2, stock.now - stock.yesterday);
			dd0Name = (judgeStrGetLenthFun(dd0Name) >= 12 && global.nameMecismType == "1") ? (dd0Name.substring(0, 4) + "...") : dd0Name; // 列表列表股票名称字体过长时用跑马灯形式显示
			var amount = judgeColorValue(3, stock.amount);
			var nameStyle = (localZxgList && localZxgList.indexOf(dd0Market + ":" + dd0Code) > -1) ? "blue1" : "";
			var rMarkText = "";
			if(":98:99:".indexOf(":" + stock.stockType + ":") > -1) { // 港股通
				rMarkText = "<span>H</span>";
			} else if(stock.rMark) { // 融标的股票
				rMarkText = "<span>R</span>";
			}
			
			if((id == 5 || id == 6) && isNaN(dd2Text)) { // 资金流入、流出汉字单位增加样式
				var num = dd2Text.substring(0, dd2Text.length - 1);
				var unit = dd2Text.substr(dd2Text.length - 1, 1);
				if(judgeStrGetLenthFun(num) > 6) {
					num = Number(num).toFixed(1); // 在iPhone6微信上访问如8888.88万时会换行
				}
				dd2Text = num + "<em style=\"font-size:0.14rem;font-weight: bold;display: inline-block;vertical-align: middle;margin-top: -0.04rem;\">" + unit + "</em>";
			}
			var leftHtml = "<tr class=\"pad_top\"><td class=\"text_cen\">"+(i+1)+"</td><td class=\"text_left\">"+dd0Code+"</td>"+
			"<td class=\"text_left " + nameStyle + "\">"+dd0Name+"</td></tr>";
			var rightHtml = "<tr class=\"pad_top\"><td class=" + curStyle + ">" + rMarkText +(isSuspend == 1 ? "--" : dd2Text)+"</td><td class=" + curStyle + ">"+(isSuspend == 1 ? "--" : dd1Text)+"</td>"+
						"<td>"+(isSuspend == 1 ? "--" : hsl)+"</td><td class=" + judgeColorValue(2, stock.day_jlr) + ">"+common.judgeColorValue(3, stock.day_jlr)+"</td><td class=" + judgeColorValue(2, stock.day_cdd) + ">"+common.judgeColorValue(3, stock.day_cdd)+"</td>"+
						"<td class=" + judgeColorValue(2, stock.day_dd) + ">"+common.judgeColorValue(3, stock.day_dd)+"</td><td class=" + judgeColorValue(2, stock.day_zd) + ">"+common.judgeColorValue(3, stock.day_zd)+"</td><td class=" + judgeColorValue(2, stock.day_xd) + ">"+common.judgeColorValue(3, stock.day_xd)+"</td><td class=" + judgeColorValue(2, stock.min_jlr) + ">"+common.judgeColorValue(3, stock.min_jlr)+"</td>"+
						"<td class=" + judgeColorValue(2, stock.min_cdd) + ">"+common.judgeColorValue(3, stock.min_cdd)+"</td><td class=" + judgeColorValue(2, stock.min_dd) + ">"+common.judgeColorValue(3, stock.min_dd)+"</td><td class=" + judgeColorValue(2, stock.min_zd) + ">"+common.judgeColorValue(3, stock.min_zd)+"</td><td class=" + judgeColorValue(2, stock.min_xd) + ">"+common.judgeColorValue(3, stock.min_xd)+"</td></tr>";
			stockArray.left.push(leftHtml);
			stockArray.right.push(rightHtml);
			
//			var stockHtml = "<tr class=\"pad_top\"><td class=\"text_cen\">"+(i+1)+"</td><td class=\"text_left\">"+dd0Code+"</td>"+
//						"<td class=\"text_left " + nameStyle + "\">"+dd0Name+"</td><td class=" + curStyle + ">" + rMarkText +(isSuspend == 1 ? "--" : dd2Text)+"</td><td class=" + curStyle + ">"+(isSuspend == 1 ? "--" : dd1Text)+"</td>"+
//						"<td>"+(isSuspend == 1 ? "--" : hsl)+"</td><td class=" + judgeColorValue(2, stock.day_jlr) + ">"+common.judgeColorValue(3, stock.day_jlr)+"</td><td class=" + judgeColorValue(2, stock.day_cdd) + ">"+common.judgeColorValue(3, stock.day_cdd)+"</td>"+
//						"<td class=" + judgeColorValue(2, stock.day_dd) + ">"+common.judgeColorValue(3, stock.day_dd)+"</td><td class=" + judgeColorValue(2, stock.day_zd) + ">"+common.judgeColorValue(3, stock.day_zd)+"</td><td class=" + judgeColorValue(2, stock.day_xd) + ">"+common.judgeColorValue(3, stock.day_xd)+"</td><td class=" + judgeColorValue(2, stock.min_jlr) + ">"+common.judgeColorValue(3, stock.min_jlr)+"</td>"+
//						"<td class=" + judgeColorValue(2, stock.min_cdd) + ">"+common.judgeColorValue(3, stock.min_cdd)+"</td><td class=" + judgeColorValue(2, stock.min_dd) + ">"+common.judgeColorValue(3, stock.min_dd)+"</td><td class=" + judgeColorValue(2, stock.min_zd) + ">"+common.judgeColorValue(3, stock.min_zd)+"</td><td class=" + judgeColorValue(2, stock.min_xd) + ">"+common.judgeColorValue(3, stock.min_xd)+"</td></tr>";
//			stockArray.push(stockHtml);
		}
		return stockArray;	
	}

	/**
	 * @param jsonObj 列表数据
	 * @param sort 排序字段
	 * @param order 排序方式
	 * */
	function hqListCompare(jsonObj, sort, order) {
		if(jsonObj) {
			var getValFromJson = function(jsonObj, idx) {
				var targetKey;
				for(var key in jsonObj) {
					if(idx == key) {
						targetKey = key;
						break;
					}
				}
				return jsonObj[targetKey];
			};

			jsonObj =  jsonObj.sort(function compare(a,b) {
				var itemA = getValFromJson(a,sort);
				var itemB = getValFromJson(b,sort);
				if(order == 0) { // 降序
					return parseFloat(itemA) < parseFloat(itemB) ? 1 : -1;
				} else { // 升序
					return parseFloat(itemA) > parseFloat(itemB) ? 1 : -1;
				}
			});
		}	
		return jsonObj;
	}

	/**
	 * 将对象进行深度克隆
	 * 保证新对象(复制的原对象)的改变不会影响原对象的变化
	 * @param obj 原对象
	 * @return 新对象
	 * */
	function clone(obj) {
		var o;
		if(obj) {
			if(obj.constructor == Object) { 
				o = new obj.constructor();
			} else {
				o = new obj.constructor(obj.valueOf());
			}
			for(var key in obj) {
				if(typeof obj[key] =="object" && obj[key] != null) {
					o[key] = clone(obj[key]);
				} else {
					o[key] = obj[key];
				}
			}
		}
		return o; 
	}

	/**
	 * 股票价格小数点后几位数确认，根据某只股票类型判断
	 * @param {*} stype 股票类型
	 * @param {*} secondStockType 二级市场类型
	 * @returns 
	 */
	function typePoint(stype,secondStockType) {
		var point = 2;
		var threeList = ":3:4:5:6:10:11:12:13:16:19:20:21:22:23:24:27:30:98:99:100:101:102:103:104:105:106:"; // 保留三位小数的股票类型
		var fourList = ":3:11:"; // 保留四位小数的股票类型
		if(threeList.indexOf(":" + stype + ":") > -1 || secondTypeArrBySH.indexOf(secondStockType) > -1 || bondTypeSecond.indexOf(secondStockType) > -1) point = 3;
		if(fourList.indexOf(":" + stype + ":") > -1 || secondTypeArrBySZ.indexOf(secondStockType) > -1) point = 4;
		return point;
	}

	Array.prototype.remove = function(index){
		this.splice(index, 1)
	}

	/**
	 * 在自选股基本数据和查询数据中移除一支股票对应的数据
	 * @param index 自选股查询数据的下标
	 * @param zxgResults 自选股查询数据
	 * 当两个参数都不传时表示删除所有
	 * */
	function removeZxg(index, zxgResults) {
		if(!index && !zxgResults) { // 全部删除
			nativePluginServiceFunction(1, 2, "zxgResults", "");
			isTradeLogin(1, "");
		} else {
			var stockIndex = zxgResults[index].market + ":" + zxgResults[index].stockCode;
			zxgResults.remove(index);
//			zxgResults.splice(index, 1);
			nativePluginServiceFunction(1, 2, "zxgResults", JSON.stringify(zxgResults));
			/*isTradeLogin(2, null, function callback(zxgList) {
				var zxgArray = $.grep(zxgList.split("|"), function(item) { // 删除指定自选股
					return stockIndex != item;
				});
				zxgList = zxgArray.join("|"); // 拼接
				isTradeLogin(1, zxgList);
			});*/
			// 这里自选股没有去判断是否登录，而是直接取的本地自选股，是因为在登录成功时批量删除会有异步的问题
			var zxgList = nativePluginServiceFunction(2, 2, "localZxgList", null, true); // 获取本地自选股
			var zxgArray = $.grep(zxgList.split("|"), function(item) { // 删除指定自选股
				return stockIndex != item;
			});
			zxgList = zxgArray.join("|"); // 拼接
			isTradeLogin(1, zxgList);
		}
	}

	/**
	 * 判断是否排序获取最新的自选股数据对象列表
	 * @param isRank boolean 是否需要排序
	 * @param sort string 排序key值
	 * @param order number 0或1对应降序或升序
	 * @return 排序后的自选股查询数据
	 * */
	function isRankFunc(isRank, sort, order) { 
		var zxgResults = nativePluginServiceFunction(2, 2, "zxgResults", null);
		if(!isRank) { // 不需要排序，还原最原始的查询数据，与zxgList对应
			sort = "id";
			order = 1;
		}
		if(zxgResults) {
			try{
				zxgResults = JSON.parse(zxgResults);
			}catch(e){
				$.setSessionStorage("historySearchResults", "");
				return "";
				console.log(e.message);
			}
			var getValFromJson = function(zxgResults, idx) {
				var targetKey;
				for(var key in zxgResults) {
					if(idx == key) {
						targetKey = key;
						break;
					}
				}
				return zxgResults[targetKey];
			};

			zxgResults = zxgResults.sort(function compare(a, b) {
				var itemA = getValFromJson(a, sort);
				var itemB = getValFromJson(b, sort);
				if(order == 0) { // 降序
					return parseFloat(itemA) < parseFloat(itemB) ? 1 : -1;
				} else { // 升序
					return parseFloat(itemA) > parseFloat(itemB) ? 1 : -1;
				}
			});
		}	
		return zxgResults;
	}

	function refreshFunc(_pageId) { // 去掉刷新的动作
//		var _pageId = "#" + $.getCurrentPageObj().pageCode.replace("/", "_") + " "; // 获取当前页面的pageId
//		var _prePageCode = $.getStorage("_prePageCode").replace("/", "_"); // 获取要跳页面的pageId
		setTimeout(function() {
			$(_pageId + ".rotate_a").removeClass("request");
		}, 800);
	}

	/**
	 * 统一封装固定参数
	 * 对固定参数进行下标式向json格式的转换
	 * id 标识
	 * newStock 封装的变量
	 * stock为股票的一条记录
	 * 特殊参数请在对应地方做对应添加
	 * */
	function unifyPackParam(id, newStock, stock) {
		var jsonStock = newStock;
		jsonStock.id = id; // 下标，根据排序id可以获得最原始的数据
		jsonStock.uppercent = stock[0]; // 涨跌幅
		jsonStock.now = stock[1]; // 现价
		jsonStock.up = stock[2]; // 涨跌
		jsonStock.stockType = stock[3]; // 股票类型
		jsonStock.stockName = stock[4]; // 股票名称
		jsonStock.market = stock[5]; // 股票市场
		jsonStock.stockCode = stock[6]; // 股票代码
		return jsonStock;
	}

	/**
	 * 根据val的正负判断色值和加减号
	 * type 类型 1表示加正负号 2表示获取颜色值 3表示格式化数值
	 * val 值
	 * */
	function judgeColorValue(type, val) {
		if(type == 2) {
			if(global.colorRule == 1) { // 红涨绿跌
				return (Number(val) > 0) ? "read" : ((Number(val) < 0) ? "green" : "read1");
			} else if(global.colorRule == 2) { // 绿涨红跌
				return (Number(val) < 0) ? "read" : ((Number(val) > 0) ? "green" : "read1");
			} else {
				return "";
			}
		} else if(type == 1) {
			return (Number(val) > 0) ? ("+" + val) : val;
		} else if(type == 3) { // 资金流入、流出和总市值的格式化
			if(val && Number(val).toFixed(0).length > 12) {
				return (Number(val) * 0.000000000001).toFixed(0) + "万亿";
			} else if(val && Number(val).toFixed(0).length > 8) {
				return (Number(val) * 0.00000001).toFixed(2) + "亿";
			} else if(val && Number(val).toFixed(0).length > 4) {
				return (Number(val) * 0.0001).toFixed(2) + "万";
			} else {
				return val ? val.toFixed(2) : val;
			}
		}
	}
	
	/**
	 * 将报表时间转换为指定标题
	 * endDate 报表时间 格式为yyyy-MM-dd hh:mm:ss.x
	 * */
	function dateTranTitle(endDate) {
		var year = endDate.substring(0, 4); // 获取年份
		var month = Number(endDate.substring(5, 7)); // 获取月份
		var titleText = "";
		switch(month) {
		case 3 :
			titleText = "一季报";
			break;
		case 6 :
			titleText = "中报";
			break;
		case 9 :
			titleText = "三季报";
			break;
		case 12 :
			titleText = "年报";
			break;
		default :
			break;
		}
		return year + titleText;
	}
	
	/**
	 * 五档页面数据填充
	 * @param _pageId 页面标识
	 * @param stock 五档数据
	 * @param point 数据精度
	 * */
	function fiveHtmlAll(_pageId, stock, point) { 
		var prec = stock[26]; // 昨收
		function colorCss(value) { // 判断五档颜色
			if(value > prec) return "read1";
			else if(value && value < prec) return "green"; // 当值为0时
			else return "";
		}
		$(_pageId + "#sell5 td:eq(1)").html(stock[6] ? stock[6].toFixed(point) : "--").removeClass().addClass(colorCss(stock[6]) + " text_cen1");
		$(_pageId + "#sell4 td:eq(1)").html(stock[7] ? stock[7].toFixed(point) : "--").removeClass().addClass(colorCss(stock[7]) + " text_cen1");
		$(_pageId + "#sell3 td:eq(1)").html(stock[8] ? stock[8].toFixed(point) : "--").removeClass().addClass(colorCss(stock[8]) + " text_cen1");
		$(_pageId + "#sell2 td:eq(1)").html(stock[9] ? stock[9].toFixed(point) : "--").removeClass().addClass(colorCss(stock[9]) + " text_cen1");
		$(_pageId + "#sell1 td:eq(1)").html(stock[10] ? stock[10].toFixed(point) : "--").removeClass().addClass(colorCss(stock[10]) + " text_cen1");
		$(_pageId + "#sell5 td:eq(2)").html(stock[11] > 10000 ? judgeColorValue(3, stock[11]) : (stock[11] || "--"));
		$(_pageId + "#sell4 td:eq(2)").html(stock[12] > 10000 ? judgeColorValue(3, stock[12]) : (stock[12] || "--"));
		$(_pageId + "#sell3 td:eq(2)").html(stock[13] > 10000 ? judgeColorValue(3, stock[13]) : (stock[13] || "--"));
		$(_pageId + "#sell2 td:eq(2)").html(stock[14] > 10000 ? judgeColorValue(3, stock[14]) : (stock[14] || "--"));
		$(_pageId + "#sell1 td:eq(2)").html(stock[15] > 10000 ? judgeColorValue(3, stock[15]) : (stock[15] || "--"));	
		$(_pageId + "#buy1 td:eq(1)").html(stock[16] ? stock[16].toFixed(point) : "--").removeClass().addClass(colorCss(stock[16]) + " text_cen1");
		$(_pageId + "#buy2 td:eq(1)").html(stock[17] ? stock[17].toFixed(point) : "--").removeClass().addClass(colorCss(stock[17]) + " text_cen1");
		$(_pageId + "#buy3 td:eq(1)").html(stock[18] ? stock[18].toFixed(point) : "--").removeClass().addClass(colorCss(stock[18]) + " text_cen1");
		$(_pageId + "#buy4 td:eq(1)").html(stock[19] ? stock[19].toFixed(point) : "--").removeClass().addClass(colorCss(stock[19]) + " text_cen1");
		$(_pageId + "#buy5 td:eq(1)").html(stock[20] ? stock[20].toFixed(point) : "--").removeClass().addClass(colorCss(stock[20]) + " text_cen1");
		$(_pageId + "#buy1 td:eq(2)").html(stock[21] > 10000 ? judgeColorValue(3, stock[21]) : (stock[21] || "--"));	
		$(_pageId + "#buy2 td:eq(2)").html(stock[22] > 10000 ? judgeColorValue(3, stock[22]) : (stock[22] || "--"));
		$(_pageId + "#buy3 td:eq(2)").html(stock[23] > 10000 ? judgeColorValue(3, stock[23]) : (stock[23] || "--"));
		$(_pageId + "#buy4 td:eq(2)").html(stock[24] > 10000 ? judgeColorValue(3, stock[24]) : (stock[24] || "--"));
		$(_pageId + "#buy5 td:eq(2)").html(stock[25] > 10000 ? judgeColorValue(3, stock[25]) : (stock[25] || "--"));
	}
	
	/**
	 * 明细页面数据填充
	 * @param _pageId 页面标识
	 * @param results 明细结果集
	 * @param point 数据精度
	 * */
	function bargainHtmlAll(_pageId, results, point) {
		var bargainArray = [];
		for (var i = 0; i < results.length; i++) {
			var stock = results[i];
			var date = stock[0]; // 分钟数
			var price = stock[1].toFixed(point); // 成交价
			var volume = stock[2] > 10000 ? common.judgeColorValue(3, stock[2]) : stock[2]; // 成交量
			var flag = stock[3]; // 标志 0是买 1是卖
			var h = Math.floor(date / 60); // 时
			if(h < 10) h = "0" + h;
			var m = Number(date % 60); // 分
			if(m < 10) m = "0" + m;
			date = h + ":" + m;
			if(flag == 0) {
				var bz = "买盘";//B
				var mmColor = "read1";
			} else {
				var bz = "卖盘";//S
				var mmColor = "green";
			}
//			var bargainText = "<li class=\"clearfix\">" +
//			"<span>" + date + "</span><span class=" + mmColor + ">" + price + "</span>" +
//			"<span>" + volume + "</span>" +
//			"</li>"; 
			var bargainText = "<tr><td class=\"pad_left\">" + date + "</td><td class=\"text_cen1\">" + price + "</td>"+
			"<td class=\"text_right\">" +volume + "</td><td class='text_right pad_right " +mmColor+"'>"+bz+"</td></tr>";
			bargainArray.push(bargainText);
		}
		$(_pageId + "#mx table:eq(1)").html(bargainArray.join(""));
	}

	/**
	 * 判断字符串字符长度
	 * 汉子2个字符
	 * */
	function judgeStrGetLenthFun(str) {
		var realLength = 0, len = str.length, charCode = -1;
	    for (var i = 0; i < len; i++) {
	        charCode = str.charCodeAt(i);
	        if (charCode >= 0 && charCode <= 128) realLength += 1;
	        else realLength += 2;
	    }
	    return realLength;
	}
	
	/**
	 * 判断当前是否交易时间
	 * time 日期   2016-07-28 11:09:53
	 * stockType 股票类型
	 * type 1返回分钟
	 * */
	function checkTradeTime(time, stockType, type){
		var oDate = new Date(time.replace(/-/g,"/"));
		var oTime = Number(time.substring(11).replace(":","").substr(0,4))||0;
		if(type == 1 && oDate){
			return oDate.getHours() + ":" + (oDate.getMinutes() < 10 ? "0" + oDate.getMinutes():oDate.getMinutes())
		}
		if("67".indexOf(oDate.getDay())>-1){
			return "非交易日 " + time;
		}else{
			if(stockType == "99") {
				if((oTime >= 900 && oTime < 1200)||(oTime>=1300 && oTime<1600)){
					return "交易中 " + time;
				}else if(oTime>=1200 && oTime<1300){
					return "午间休市 " + time;
				}else{
					return "已收盘 " + time;
				}
				return "";
			}else{
				if(oTime > 900 && time < 915) {
					return "未开盘 " + time;
				}else if((oTime >= 915 && oTime < 1130)||(oTime>=1300 && oTime<1500)){
					return "交易中 " + time;
				}else if(oTime>=1130 && oTime<1300){
					return "午间休市 " + time;
				}else{
					return "已收盘 " + time;
				}
				return "";
			}
		}
	}
	
	function numberConvertDate(type, value) { // 数字型转换成时间或日期格式
		if(type == 1) { // 数字型转换日期格式
			var value = value + "";
			return value.length == 8 ? value.substring(4, 6) + "-" + value.substring(6, 8) : "";
		} else if(type == 2) { // 数字型转换成时间
			var h = Math.floor(value / 60); // 时
			if(h < 10) {h = "0" + h;}
			var m = Number(value % 60); // 分
			if(m < 10) {m = "0" + m;}
			return h + ":" + m;
		}
		return "";
	}

	function resultsVoFunc(_data) { // 出参结构转换
		var data = {};
		data.errorNo = _data.getErrorNo();
		data.errorInfo = _data.getErrorInfo();
		data.results = _data.getResults("results");
		return data;
	}
	
	function indexOfFunc(str, array, isEq) {
		var isReturn = false;
		if(array.length > 0) {
			for (var i = 0; i < array.length; i++) {
				if((!isEq && (str + "").indexOf(array[i]) > -1) || (isEq && str == array[i])) {
					isReturn = true;
					break;
				}
			}
		}
		return isReturn;
	}

	var common = {
			"firstLoadFunc" : firstLoadFunc,
			"nativePluginServiceFunction" : nativePluginServiceFunction,
			"isTradeLogin" : isTradeLogin,
//			"isSyncZxgFun" : isSyncZxgFun,
			"typePoint" : typePoint,
			"addListData" : addListData,
			"addFundListData" : addFundListData,
			"clone" : clone,
			"isRankFunc" : isRankFunc,
			"removeZxg" : removeZxg,
			"refreshFunc" : refreshFunc,
			"unifyPackParam" : unifyPackParam,
			"judgeColorValue" : judgeColorValue,
			"dateTranTitle" : dateTranTitle,
			"fiveHtmlAll" : fiveHtmlAll,
			"bargainHtmlAll" : bargainHtmlAll,
			"judgeStrGetLenthFun" : judgeStrGetLenthFun,
			"checkTradeTime" : checkTradeTime,
			"numberConvertDate" : numberConvertDate,
			"resultsVoFunc" : resultsVoFunc,
			"indexOfFunc" : indexOfFunc
	};
	//暴露对外的接口
	module.exports = common;
});
