/**
 * 
 */
define("trade/scripts/hq/chart/service_hq.js", function(require, exports, module) {
	var service = require("service");
	var gconfig = $.config;
	var global = gconfig.global;

	function service_hq() { //对应的接口方法需要在这里暴露出来
		this.service = new $.service;
	};
	service_hq.prototype.destroy = function() {
		this.service.destroy();
	};
	module.exports = new service_hq();
	/********************************公共代码部分********************************/
	service_hq.prototype.commonInvoke = service.commonInvokeHq;
	/********************************应用接口开始********************************/
	/********************************业务范围--股票********************************/

	/**
	 *  根据股票代码，拼音简称，中文名称查询股票（可用做码表查询）(新的接口 推荐使用)
	 * @param {Object}  type		类型组合，每字节表示1种类型，用:分隔，参见数据字典 个股分类字段（默认沪深A股）	
	 * @param {Object}  q		查询关键字（股票代码，拼音简称，中文名称）
	 * @param {Object}  count		返回的记录条数，传-1表示不限长度
	 * @param {Object}  field		获取股票的属性字段ID，使用:分隔。默认为出参类型如：22:23:24:28:21
	 * @param {Object}  is_start		1：按以q开头查找 0：按存在q查找。默认为1	
	 * @param {Object}  marketType		搜索市场类型  可选值：1，2，3，4,5,6,7		"1：HS  2：HK  3：HK+SK+HS 4：HS+HK+SK 5.FUND 6.HS+HK+FUND(没有沪港通就是HS+FUND) 7.SK(深港通) "
	 * */
	service_hq.prototype.searchStockList = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcno"] = "21007";
		paraMap["version"] = "1";
		paraMap["type"] = param.type;
		paraMap["q"] = param.q;
		paraMap["count"] = param.count;
		paraMap["is_start"] = param.is_start;
		paraMap["marketType"] = param.marketType;

		var reqParamVo = this.service.reqParamVo;
		reqParamVo.setUrl(global.HqUrl);
		this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};


	/**
	 *  获取股票现价
	 * @param {Object} stockStr 市场代码:股票代码
	 * @param {Object} callback	回调方法
	 * */
	service_hq.prototype.getStockNowPrice = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcno"] = "26000";
		paraMap["version"] = 1;
		paraMap["stock_list"] = param.stock_list;
		paraMap["field"] = param.field || "24:22:2:3:1:6:19:18:8:9:10:11:32:31:27:13:12:45:46:56:148";
		var reqParamVo = this.service.reqParamVo;
		reqParamVo.setUrl(global.HqUrl);
		this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 *  获取行情五档
	 * @param {Object} stockStr 市场代码:股票代码
	 * @param {Object} callback	回调方法
	 * */
	service_hq.prototype.getStockFiveStep = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcno"] = "20003";
		paraMap["version"] = 1;
		paraMap["stock_list"] = param.stock_list;
		var reqParamVo = this.service.reqParamVo;
		reqParamVo.setUrl(global.HqUrl);
		this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 *  成交明细（定量）
	 * @param {Object} stockStr 市场代码:股票代码
	 * @param {Object} callback	回调方法
	 * */
	service_hq.prototype.transactionDetails = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcno"] = "20006";
		paraMap["version"] = 1;
		paraMap["stock_code"] = param.stock_code;
		paraMap["market"] = param.market;
		paraMap["count"] = 11;
		var reqParamVo = this.service.reqParamVo;
		reqParamVo.setUrl(global.HqUrl);
		this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 *  根据股票代码，拼音简称，中文名称查询股票（可用做码表查询）
	 * @param {Object} stockStr 市场代码:股票代码
	 * @param {Object} callback	回调方法
	 * */
	service_hq.prototype.getStockList = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcno"] = "20007";
		paraMap["version"] = 1;
		if (param.type) {
			paraMap["type"] = param.type;
		} else if (global.stockType && global.stockType instanceof Array && global.stockType.length != 0) {
			paraMap["type"] = global.stockType.join(":");
		} else {
			paraMap["type"] = "0:1:2:3:4:5:6:8:9:10:11:12:13:14:16:17:18:19:20:21:22:23:24:25:26:27:30:64:65:66";
		}
		paraMap["q"] = param.q;
		paraMap["count"] = "10";
		paraMap["field"] = "24:22:21:23:2:12:45:46:48";
		paraMap["is_start"] = "0";
		var reqParamVo = this.service.reqParamVo;
		reqParamVo.setUrl(global.HqUrl);
		this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 *  获取个股行情
	 * @param {Object} stockStr 股票代码或者拼音
	 * @param {Object} callback	回调方法
	 * */
	service_hq.prototype.getStockInfo = function(param, callback, ctrlParam) {
		//填充机构代码
		var paraMap = {};
		paraMap["funcno"] = "20010";
		paraMap["version"] = 1;
		paraMap["type"] = "0:1:2:3:4:5:6:8:9:10:11:12:13:14:16:17:18:19:20:21:22:23:24:25:26:27:30:64:65:66";
		paraMap["code_list"] = param.code_list;
		paraMap["field"] = "24:22:21:23:2:12:45:46:48";
		var reqParamVo = this.service.reqParamVo;
		reqParamVo.setUrl(global.HqUrl);
		this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 *  获取行情服务器状态与时间
	 * @param {Object} stockStr 市场代码:股票代码
	 * @param {Object} callback	回调方法
	 * */
	service_hq.prototype.getHqState = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcno"] = "29999";
		paraMap["version"] = 1;
		var reqParamVo = this.service.reqParamVo;
		reqParamVo.setUrl(global.HqUrl);
		this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 行情多日分时图行情
	 * 行情
	 * @param {Object} market  标的股票的市场
	 * @param {Object} stock_code  标的股票的代码
	 * @param {Object} start  起始索引
	 * @param {Object} callback	回调方法
	 * */
	service_hq.prototype.getStackHqFiveLine = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcno"] = "30029";
		paraMap["version"] = "1";
		paraMap["market"] = param.market;
		paraMap["stock_code"] = param.stock_code;
		paraMap["start"] = param.start;
		paraMap["dayitems"] = param.dayitems;

		var reqParamVo = this.service.reqParamVo;
		reqParamVo.setUrl(global.HqUrl);
		this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	/**
	 * 多只股票以及板块多日分时（出参为分时所属的field）
	 * 行情
	 * @param {Object} dayitem		取分时类型：1.一日分时， 5.五日分时(非全部点)   2:五日分时(五日的全部分时点)
	 * @param start		起点索引（从0开始）
	 * @param field		"请求的分时field。具体参见数据字典，分时数据属性说明（注：与20000使用的field属性不同）"
	 * @param stock_list		股票列表，以SH:000001|SZ:000001分隔
	 * @param {Object} callback	回调方法
	 * */
	service_hq.prototype.getHqMinLine2 = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcno"] = "30089";
		paraMap["version"] = "1";
		paraMap["dayitem"] = "7";
		paraMap["stock_list"] = param.stock_list;
		paraMap["start"] = param.start;
		paraMap["field"] = param.field;

		var reqParamVo = this.service.reqParamVo;
		reqParamVo.setUrl(global.HqUrl);
		this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	/**
	 * 行情叠加K线图K线数据查询
	 * 行情
	 * @param {Object} market  标的股票的市场
	 * @param {Object} stock_code  标的股票的代码
	 * @param {Object} start  起始索引
	 * @param {Object} callback	回调方法
	 * */
	service_hq.prototype.getStackHqKMinLine = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcno"] = "20009"; //20044、20009、20030
		paraMap["version"] = "1";
		paraMap["market"] = param.market;
		paraMap["stock_code"] = param.stock_code;
		paraMap["type"] = param.type;
		paraMap["Lastcount"] = param.Lastcount;
		paraMap["count"] = param.count;

		var reqParamVo = this.service.reqParamVo;
		reqParamVo.setUrl(global.HqUrl);
		this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 行情分钟K线数据查询
	 * 行情
	 * @param {Object} market  标的股票的市场
	 * @param {Object} stock_code  标的股票的代码
	 * @param {Object} start  起始索引
	 * @param {Object} callback	回调方法
	 * */
	service_hq.prototype.getHqNKMinLine = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcno"] = "20012";
		paraMap["version"] = "1";
		paraMap["market"] = param.market;
		paraMap["stock_code"] = param.stock_code;
		paraMap["type"] = param.type;
		paraMap["Lastcount"] = param.Lastcount;
		paraMap["count"] = param.count;

		var reqParamVo = this.service.reqParamVo;
		reqParamVo.setUrl(global.HqUrl);
		this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 行情叠加复权K线图K线数据查询
	 * 行情
	 * @param {Object} market  标的股票的市场
	 * @param {Object} stock_code  标的股票的代码
	 * @param {Object} start  起始索引
	 * @param {Object} FQType  复权类型 1-前复权 2-后复权
	 * @param {Object} callback	回调方法
	 * */
	service_hq.prototype.getStackHqFQKMinline = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcno"] = "20019";
		paraMap["version"] = "1";
		paraMap["stock_code"] = param.stock_code;
		paraMap["market"] = param.market;
		paraMap["FQType"] = param.FQType;
		paraMap["type"] = param.type;
		paraMap["count"] = param.count;
		paraMap["Lastcount"] = param.Lastcount;

		var reqParamVo = this.service.reqParamVo;
		reqParamVo.setUrl(global.HqUrl);
		this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 功能:获取指定证券代码的标准行情(1000003) 入参: callBackFunc: 回调函数 exchange_type：交易市场类别(Y)
	 * stock_code：证券代码(Y)
	 */
	service_hq.prototype.queryStandardMarket = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcno"] = "1000003";
		paraMap["market"] = param.market;
		paraMap["stock_code"] = param.stock_code;
		paraMap["count"] = param.count;

		var reqParamVo = this.service.reqParamVo;
		reqParamVo.setUrl(global.HqUrl);
		this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 *  获取期权信息 (可用于查询五档)
	 * @param {Object} market		标的市场
	 * @param {Object} SecurityID		期权编码   例如：10000843（11000001）
	 * @param {Object} callback	回调方法
	 * */
	service_hq.prototype.getOptionInfo = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcno"] = "6204";
		paraMap["version"] = 1;
		paraMap["SecurityID"] = param.SecurityID;
		paraMap["market"] = param.market;
		paraMap["field"] = param.field || "1:2:3:4:5:6:9:10:11:12:13:14:15:16:17:18:19:21:22:23:24:25:33:34:37:44:45:46:43:26:27:28:29:30:31:40:51:56:61:66:71:72:73:74:75:76:77:78:39:38";
		var reqParamVo = this.service.reqParamVo;
		reqParamVo.setUrl(global.optionHqUrl);
		this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 查询合约多日分时数据
	 * 期权
	 * @param {Object} market		标的市场
	 * @param {Object} SecurityID		期权编码   例如：10000843（11000001）
	 * @param {Object} start 
	 * @param {Object} daytype  1:一日分时  5：五日分时
	 * @param {Object} callback	回调方法
	 * */
	service_hq.prototype.getOptionDaysKMinLine = function(param, callback, ctrlParam) {
		var paraMap = {};
		paraMap["funcno"] = "6210";
		paraMap["version"] = 1;
		paraMap["market"] = param.market;
		paraMap["SecurityID"] = param.SecurityID;
		paraMap["start"] = param.start;
		paraMap["daytype"] = param.daytype;

		var reqParamVo = this.service.reqParamVo;
		reqParamVo.setUrl(global.HqUrl);
		this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	/***应用接口......................................................结束*/

});
