/**
 * 网络投票service层调用接口
 */
define('trade/service/scripts/trade/service_added.js',function(require, exports, module) {
	var service = require("service");
	var gconfig = $.config;
	var global = gconfig.global;
    
	/********************************公共代码部分********************************/
    service_added.prototype.commonInvoke = service.commonInvoke;

	service_added.prototype.destroy = function(){
		this.service.destroy();
	};
	function service_added(){ //对应的接口方法需要在这里暴露出来
		this.service = new $.service;
	};
	module.exports = new service_added();
	
	/********************************应用接口开始********************************/
	/********************************业务范围--网络投票等功能********************************/
	
	/**
	 * 股东大会信息查询
	 * @param {Object} entrust_way				委托方式
	 * @param {Object} branch_no				分支机构
	 * @param {Object} fund_account				资金账号
	 * @param {Object} cust_code				客户编号	
	 * @param {Object} password					交易密码
	 * @param {Object} op_station				操作站点	
	 * @param {Object} sessionid				会话号
	 * @param {Object} exchange_type			市场
	 * @param {Object} company_code				公司代码
	 * @param {Object} vote_code				产品代码
	 * */
	service_added.prototype.queryStockMeetingInfo = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "301530";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["password"] = param.password;
		paraMap["sessionid"] = param.sessionid;
		paraMap["exchange_type"] = param.exchange_type;
		paraMap["company_code"] = param.company_code;
		paraMap["vote_code"] = param.vote_code;
		 // 添加 op_station 到接口请求参数中
		var reqParamVo = this.service.reqParamVo;
 		reqParamVo.setUrl( global.serverPathTrade);
 		this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 投票议案信息查询
	 * @param {Object} entrust_way				委托方式
	 * @param {Object} branch_no				分支机构
	 * @param {Object} fund_account				资金账号
	 * @param {Object} cust_code				客户编号	
	 * @param {Object} password					交易密码
	 * @param {Object} op_station				操作站点	
	 * @param {Object} sessionid				会话号
	 * @param {Object} meeting_seq				股东大会编码
	 * @param {Object} v_id						议案编号
	 * @param {Object} vote_code				产品代码
	 * */
	service_added.prototype.queryVoteBillInfo = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "301531";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["password"] = param.password;
		paraMap["sessionid"] = param.sessionid;
		paraMap["meeting_seq"] = param.meeting_seq;
		paraMap["stock_code"] = param.stock_code;
		paraMap["v_id"] = param.v_id;
		paraMap["vote_code"] = param.vote_code;
		 // 添加 op_station 到接口请求参数中
		var reqParamVo = this.service.reqParamVo;
 		reqParamVo.setUrl( global.serverPathTrade);
 		this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	
	
	
	/**
	 * 上交所网络投票
	 * @param {Object} entrust_way				委托方式
	 * @param {Object} branch_no				分支机构
	 * @param {Object} fund_account				资金账号
	 * @param {Object} cust_code				客户编号	
	 * @param {Object} password					交易密码	
	 * @param {Object} op_station				操作站点	
	 * @param {Object} exchange_type			市场	
	 * @param {Object} stock_account			证券代码	
	 * @param {Object} stock_code				股东代码
	 * @param {Object} sessionid				会话号
	 * @param {Object} meeting_seq				股东大会编码
	 * @param {Object} v_id						议案编号
	 * @param {Object} vote_number				投票数量
	 * @param {Object} vote_result				投票意见
	 * @param {Object} order_group				委托批号
	 * */
	service_added.prototype.queryVote = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "301533";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["password"] = param.password;
		paraMap["exchange_type"] = param.exchange_type;
		paraMap["stock_account"] = param.stock_account;
		paraMap["stock_code"] = param.stock_code;
		paraMap["sessionid"] = param.sessionid;
		paraMap["meeting_seq"] = param.meeting_seq;
		paraMap["v_id"] = param.v_id;
		paraMap["vote_number"] = param.vote_number;
		paraMap["vote_result"] = param.vote_result;
		paraMap["order_group"] = param.order_group;
		 // 添加 op_station 到接口请求参数中
		var reqParamVo = this.service.reqParamVo;
 		reqParamVo.setUrl( global.serverPathTrade);
 		this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/**
	 * 网络投票委托查询
	 * @param {Object} entrust_way				委托方式
	 * @param {Object} branch_no				分支机构
	 * @param {Object} fund_account				资金账号
	 * @param {Object} cust_code				客户编号
	 * @param {Object} password					交易密码
	 * @param {Object} op_station				操作站点
	 * @param {Object} exchange_type			市场
	 * @param {Object} stock_account			证券代码
	 *
	 * */
	service_added.prototype.queryVoteHistory = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "301534";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["password"] = param.password;
		paraMap["exchange_type"] = param.exchange_type;
		paraMap["stock_account"] = param.stock_account;
		paraMap["stock_code"] = param.stock_code;
		paraMap["sessionid"] = param.sessionid;
		paraMap["meeting_seq"] = param.meeting_seq;
		paraMap["v_id"] = param.v_id;
		paraMap["begin_date"] = param.begin_date;
		paraMap["end_date"] = param.end_date;
		var reqParamVo = this.service.reqParamVo;
		reqParamVo.setUrl( global.serverPathTrade);
		this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 网络投票结果查询
	 * @param {Object} entrust_way				委托方式
	 * @param {Object} branch_no				分支机构
	 * @param {Object} fund_account				资金账号
	 * @param {Object} cust_code				客户编号
	 * @param {Object} password					交易密码
	 * @param {Object} op_station				操作站点
	 * @param {Object} exchange_type			市场
	 * @param {Object} stock_account			证券代码
	 *
	 * */
	service_added.prototype.resultQuery = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "301532";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["password"] = param.password;
		paraMap["begin_date"] = param.begin_date;
		paraMap["end_date"] = param.end_date;
		paraMap["search_type"] = param.search_type;
		var reqParamVo = this.service.reqParamVo;
		reqParamVo.setUrl( global.serverPathTrade);
		this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	/***应用接口......................................................结束*/

});
