/**
 * 股票期权service层调用接口
 * */
define('trade/service/scripts/trade/service_option.js',function(require,exports,module){
	var service = require("service");
	var gconfig = $.config;
	var global = gconfig.global;
	var serverConfig = global.serverConfig; // 柜台选择   1. 金证win  2. 恒生T2   3. 顶点 （可拓展）
	var global = gconfig.global;
	
	function service_option(){ //对应的接口方法需要在这里暴露出来
		this.service = new $.service;
	};
	
	module.exports = new service_option();
    
    /**
	 * 释放操作
	 */
	service_option.prototype.destroy = function(){
		this.service.destroy();
	};
	/********************************公共代码部分********************************/
    service_option.prototype.commonInvoke = service.commonInvoke;

	
	/********************************应用接口开始********************************/

	/***应用接口......................................................开始*/
    
    
    /**
 	 * 期权行情查询
 	 * @param {Object} exchange_type             交易类别
     * @param {Object} option_code               期权合约编码
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.queryOptionsMarket = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305000";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["exchange_type"] = param.exchange_type;
		 paraMap["option_code"] = param.option_code;
		 
		var reqParamVo = this.service.reqParamVo;
	  	reqParamVo.setUrl(global.serverPathTrade);
	  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
    
    
    /**
 	 * 期权代码信息查询（联动査询）
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} stock_code               股票代码
     * @param {Object} option_code              期权合约编码
     * @param {Object} option_type  			期权类别（见数据字典)
     * @param {Object} entrust_bs           	委托标志（见数据字典)
     * @param {Object} covered_flag				备兑标志（见数据字典）
     * @param {Object} entrust_oc           	开平仓方向（见数据字典)
     * @param {Object} exercise_price  			行权价格
     * @param {Object} exercise_month  			行权年月
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.optionCodeInformation = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305001";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["stock_code"] = param.stock_code;
		 paraMap["option_code"] = $.trim(param.option_code);
		 paraMap["entrust_prop_opt"] = param.entrust_prop_opt;
		 paraMap["option_type"] = param.option_type;
		 paraMap["covered_flag"] = param.covered_flag;
		 paraMap["entrust_bs"] = param.entrust_bs;
		 paraMap["entrust_oc"] = param.entrust_oc;
		 paraMap["exercise_price"] = $.trim(param.exercise_price);
		 paraMap["exercise_month"] = $.trim(param.exercise_month);
		 paraMap["entrust_price"] = param.entrust_price;
		 
		var reqParamVo = this.service.reqParamVo;
	  	reqParamVo.setUrl(global.serverPathTrade);
	  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
     
      /**
 	 * 期权持仓查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
 	 * @param {Object} password                 交易密码
     * @param {Object} session_id                会话号
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.underlyingSecurities = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305002";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 
		var reqParamVo = this.service.reqParamVo;
	  	reqParamVo.setUrl(global.serverPathTrade);
	  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    };
      
      /**
 	 * 期权持仓查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
 	 * @param {Object} password                 交易密码
     * @param {Object} session_id                会话号
     * @param {Object} exchange_type            交易市场类别（见数据字典)
     * @param {Object} option_account  			衍生品合约账户
     * @param {Object} opthold_type           	期权持仓类别（'0'-权利方 '1'-义务方 '2'-备兑方
     * @param {Object} option_code              期权合约编码
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.queryPosition = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305003";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["exchange_type"] = param.exchange_type;
		 paraMap["option_account"] = param.option_account;
		 paraMap["opthold_type"] = param.opthold_type;
		 paraMap["option_code"] = param.option_code;
		 
			var reqParamVo = this.service.reqParamVo;
		  	reqParamVo.setUrl(global.serverPathTrade);
		  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
      /**
 	 * 期权资产查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             衍生品资金账户
     * @param {Object} cust_code                客户编号
 	 * @param {Object} password                 交易密码
     * @param {Object} session_id                会话号
     * @param {Object} money_type            	币种类别（见数据字典)
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.queryAssets = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305004";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["money_type"] = param.money_type;
		 
			var reqParamVo = this.service.reqParamVo;
		  	reqParamVo.setUrl(global.serverPathTrade);
		  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
      /**
 	 * 期权委托
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
 	 * @param {Object} password                 交易密码
     * @param {Object} session_id                会话号
     * @param {Object} exchange_type            交易市场类别（见数据字典)
     * @param {Object} option_account           衍生品合约账户
     * @param {Object} option_code              期权合约编码
     * @param {Object} entrust_amount  			委托数量
     * @param {Object} entrust_price  			委托价格
     * @param {Object} entrust_bs           	委托标志（见数据字典)
     * @param {Object} entrust_oc           	开平仓方向
     * @param {Object} covered_flag  			备兑标志
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.placeAnOrder = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305005";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["exchange_type"] = param.exchange_type;
		 paraMap["entrust_prop_opt"] = param.entrust_prop_opt,
		 paraMap["option_type"] = param.option_type;
		 paraMap["stock_account"] = param.stock_account,
		 paraMap["option_account"] = param.option_account;
		 paraMap["option_code"] = param.option_code;
		 paraMap["entrust_amount"] = param.entrust_amount;
		 paraMap["entrust_price"] = param.entrust_price;
		 paraMap["entrust_bs"] = param.entrust_bs;
		 paraMap["entrust_oc"] = param.entrust_oc;
		paraMap["separate_flag"] = param.separate_flag; 
		 paraMap["covered_flag"] = param.covered_flag;
		 
			var reqParamVo = this.service.reqParamVo;
		  	reqParamVo.setUrl(global.serverPathTrade);
		  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
      /**
 	 * 期权撤单
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
 	 * @param {Object} password                 交易密码
     * @param {Object} session_id                会话号
     * @param {Object} entrust_no            	委托编号
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.cancellation = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305006";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["exchange_type"] = param.exchange_type;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["entrust_no"] = param.entrust_no;
		 
			var reqParamVo = this.service.reqParamVo;
		  	reqParamVo.setUrl(global.serverPathTrade);
		  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
    /**
 	 * 期权当日委托查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
 	 * @param {Object} password                 交易密码
     * @param {Object} session_id                会话号
     * @param {Object} exchange_type            交易市场类别（见数据字典)
     * @param {Object} stock_code               股票代码
     * @param {Object} option_code              期权合约编码
     * @param {Object} entrust_bs           	委托标志（见数据字典)
     * @param {Object} option_account  			衍生品合约账户
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.queryDayOrder = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305007";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["exchange_type"] = param.exchange_type;
		 paraMap["stock_code"] = param.stock_code;
		 paraMap["option_code"] = param.option_code;
		 paraMap["entrust_bs"] = param.entrust_bs;
		 paraMap["option_account"] = param.option_account;
		 
			var reqParamVo = this.service.reqParamVo;
		  	reqParamVo.setUrl(global.serverPathTrade);
		  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
     /**
 	 * 期权历史委托查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
 	 * @param {Object} password                 交易密码
     * @param {Object} session_id                会话号
     * @param {Object} exchange_type            交易市场类别（见数据字典)
     * @param {Object} stock_code               股票代码
     * @param {Object} option_code              期权合约编码
     * @param {Object} entrust_bs           	委托标志（见数据字典)
     * @param {Object} option_account  			衍生品合约账户
     * @param {Object} begin_time  				开始日期
     * @param {Object} end_time  				截止日期
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.queryHistoryOrder = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305008";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["exchange_type"] = param.exchange_type;
		 paraMap["stock_code"] = param.stock_code;
		 paraMap["option_code"] = param.option_code;
		 paraMap["entrust_bs"] = param.entrust_bs;
		 paraMap["option_account"] = param.option_account;
		 paraMap["begin_time"] = param.begin_time;
		 paraMap["end_time"] = param.end_time;
		 
			var reqParamVo = this.service.reqParamVo;
		  	reqParamVo.setUrl(global.serverPathTrade);
		  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
      /**
 	 * 期权当日成交查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
 	 * @param {Object} password                 交易密码
     * @param {Object} session_id                会话号
     * @param {Object} exchange_type            交易市场类别（见数据字典)
     * @param {Object} stock_code               股票代码
     * @param {Object} option_code              期权合约编码
     * @param {Object} entrust_bs           	委托标志（见数据字典)
     * @param {Object} option_account  			衍生品合约账户
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.queryDayDeal = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305009";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["exchange_type"] = param.exchange_type;
		 paraMap["stock_code"] = param.stock_code;
		 paraMap["option_code"] = param.option_code;
		 paraMap["entrust_bs"] = param.entrust_bs;
		 paraMap["option_account"] = param.option_account;
		 
			var reqParamVo = this.service.reqParamVo;
		  	reqParamVo.setUrl(global.serverPathTrade);
		  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
     /**
 	 * 期权历史成交查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
 	 * @param {Object} password                 交易密码
     * @param {Object} session_id                会话号
     * @param {Object} exchange_type            交易市场类别（见数据字典)
     * @param {Object} stock_code               股票代码
     * @param {Object} option_code              期权合约编码
     * @param {Object} entrust_bs           	委托标志（见数据字典)
     * @param {Object} option_account  			衍生品合约账户
     * @param {Object} begin_time  				开始日期
     * @param {Object} end_time  				截止日期
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.queryHistoryDeal = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305010";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["exchange_type"] = param.exchange_type;
		 paraMap["stock_code"] = param.stock_code;
		 paraMap["option_code"] = param.option_code;
		 paraMap["entrust_bs"] = param.entrust_bs;
		 paraMap["option_account"] = param.option_account;
		 paraMap["begin_time"] = param.begin_time;
		 paraMap["end_time"] = param.end_time;
		 
			var reqParamVo = this.service.reqParamVo;
		  	reqParamVo.setUrl(global.serverPathTrade);
		  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
     /**
 	 * 期权当日行权指派查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
 	 * @param {Object} password                 交易密码
     * @param {Object} session_id                会话号
     * @param {Object} exchange_type            交易市场类别（见数据字典)
     * @param {Object} opthold_type             期权持仓类别（'0'-权利方 '1'-义务方 '2'-备兑方）
     * @param {Object} option_code              期权合约编码
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.queryDayAssign = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305011";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["exchange_type"] = param.exchange_type;
		 paraMap["opthold_type"] = param.opthold_type;
		 paraMap["option_code"] = param.option_code;
		 
			var reqParamVo = this.service.reqParamVo;
		  	reqParamVo.setUrl(global.serverPathTrade);
		  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
      /**
 	 * 期权历史行权指派查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
 	 * @param {Object} password                 交易密码
     * @param {Object} session_id                会话号
     * @param {Object} exchange_type            交易市场类别（见数据字典)
     * @param {Object} opthold_type             期权持仓类别（'0'-权利方 '1'-义务方 '2'-备兑方）
     * @param {Object} option_code              期权合约编码
     * @param {Object} begin_time  				开始日期
     * @param {Object} end_time  				截止日期
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.queryHistoryAssign = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305012";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["exchange_type"] = param.exchange_type;
		 paraMap["opthold_type"] = param.opthold_type;
		 paraMap["option_code"] = param.option_code;
		 paraMap["begin_time"] = param.begin_time;
		 paraMap["end_time"] = param.end_time;
		 
			var reqParamVo = this.service.reqParamVo;
		  	reqParamVo.setUrl(global.serverPathTrade);
		  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
      /**
 	 * 期权当日行权交割查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
 	 * @param {Object} password                 交易密码
     * @param {Object} session_id                会话号
     * @param {Object} stock_code            	证券代码
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.queryDayExerciseDelivery = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305013";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["stock_code"] = param.stock_code;
		 
			var reqParamVo = this.service.reqParamVo;
		  	reqParamVo.setUrl(global.serverPathTrade);
		  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
     /**
 	 * 期权历史行权交割查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
 	 * @param {Object} password                 交易密码
     * @param {Object} session_id                会话号
     * @param {Object} deliver_type            	交割标志　'0'-打未交割　'1'-全部（见数据字典)
     * @param {Object} exchange_type            交易市场类别（见数据字典)
     * @param {Object} option_account           衍生品合约账户
     * @param {Object} option_code              期权合约编码
     * @param {Object} money_type            	币种类别
     * @param {Object} begin_time  				开始日期
     * @param {Object} end_time  				截止日期
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.queryHistoryExerciseDelivery = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305014";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["deliver_type"] = param.deliver_type;
		 paraMap["exchange_type"] = param.exchange_type;
		 paraMap["option_account"] = param.option_account;
		 paraMap["option_code"] = param.option_code;
		 paraMap["money_type"] = param.money_type;
		 paraMap["begin_time"] = param.begin_time;
		 paraMap["end_time"] = param.end_time;
		 
			var reqParamVo = this.service.reqParamVo;
		  	reqParamVo.setUrl(global.serverPathTrade);
		  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
      /**
 	 * 期权行权指派欠资欠券查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
 	 * @param {Object} password                 交易密码
     * @param {Object} session_id                会话号
     * @param {Object} fund_account_opt         衍生品资金账户
     * @param {Object} stock_code           	 证券代码
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.queryPostageDueLessVoucher = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305015";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["fund_account_opt"] = param.fund_account_opt;
		 paraMap["stock_code"] = param.stock_code;
		 
			var reqParamVo = this.service.reqParamVo;
		  	reqParamVo.setUrl(global.serverPathTrade);
		  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
     /**
 	 * 期权历史交割信息查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
 	 * @param {Object} password                 交易密码
     * @param {Object} session_id                会话号
     * @param {Object} deliver_type            	交割标志　'0'-打未交割　'1'-全部（见数据字典)
     * @param {Object} exchange_type            交易市场类别（见数据字典)
     * @param {Object} option_account           衍生品合约账户
     * @param {Object} option_code              期权合约编码
     * @param {Object} money_type            	币种类别
     * @param {Object} begin_time  				开始日期
     * @param {Object} end_time  				截止日期
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.queryHistoryDelivery = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305016";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["deliver_type"] = param.deliver_type;
		 paraMap["exchange_type"] = param.exchange_type;
		 paraMap["option_account"] = param.option_account;
		 paraMap["option_code"] = param.option_code;
		 paraMap["money_type"] = param.money_type;
		 paraMap["begin_time"] = param.begin_time;
		 paraMap["end_time"] = param.end_time;
		 
			var reqParamVo = this.service.reqParamVo;
		  	reqParamVo.setUrl(global.serverPathTrade);
		  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
     /**
 	 * 期权历史对账单查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
 	 * @param {Object} password                 交易密码
     * @param {Object} session_id                会话号
     * @param {Object} money_type            	币种类别
     * @param {Object} begin_time  				开始日期
     * @param {Object} end_time  				截止日期
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.queryHistoryAccountStatement = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305017";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["money_type"] = param.money_type;
		 paraMap["begin_time"] = param.begin_time;
		 paraMap["end_time"] = param.end_time;
		 
			var reqParamVo = this.service.reqParamVo;
		  	reqParamVo.setUrl(global.serverPathTrade);
		  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
      /**
 	 * 客户备兑证券不足查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
 	 * @param {Object} password                 交易密码
     * @param {Object} session_id                会话号
     * @param {Object} stock_code            	证券代码
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.queryEnoughSecurities = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305018";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["stock_code"] = param.stock_code;
		 
			var reqParamVo = this.service.reqParamVo;
		  	reqParamVo.setUrl(global.serverPathTrade);
		  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
      /**
 	 * 备兑证券可划转数量获取
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
 	 * @param {Object} password                 交易密码
     * @param {Object} session_id                会话号
     * @param {Object} fund_account_opt         衍生品资金账户
     * @param {Object} option_account           衍生品合约账户
     * @param {Object} stock_account            证券账号
     * @param {Object} seat_no              	席位编号
     * @param {Object} exchange_type            交易类别
     * @param {Object} stock_code  				标的证券代码
     * @param {Object} lock_direction  			锁定方向（'1'-锁定 '2'-解锁）
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.querySecuritiesTransferred = function(param,callback,ctrlParam)
	 {
		 var paraMap = {}; 
		 paraMap["funcNo"] = "305019";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["fund_account_opt"] = param.fund_account_opt;
		 paraMap["fund_account_comm"] = param.fund_account_comm;
		 paraMap["option_account"] = param.option_account;
		 paraMap["stock_account"] = param.stock_account;
		 paraMap["seat_no"] = param.seat_no;
		 paraMap["exchange_type"] = param.exchange_type;
		 paraMap["stock_code"] = param.stock_code;
		 paraMap["lock_direction"] = param.lock_direction;
		 
			var reqParamVo = this.service.reqParamVo;
		  	reqParamVo.setUrl(global.serverPathTrade);
		  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
     /**
 	 * 备兑证券划转（冻结和解冻）
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
 	 * @param {Object} password                 交易密码
     * @param {Object} session_id                会话号
     * @param {Object} fund_account_opt         衍生品资金账户
     * @param {Object} option_account           衍生品合约账户
     * @param {Object} stock_account            证券账号
     * @param {Object} seat_no              	席位编号
     * @param {Object} exchange_type            交易类别
     * @param {Object} stock_code  				标的证券代码
     * @param {Object} lock_direction  			锁定方向（'1'-锁定 '2'-解锁）
     * @param {Object} entrust_amount			划转数量
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.AgainstSecuritiesTransfer = function(param,callback,ctrlParam)
	 {
		 var paraMap = {}; 
		 paraMap["funcNo"] = "305020";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["fund_account_comm"] = param.fund_account_comm;
		 paraMap["fund_account_opt"] = param.fund_account_opt;
		 paraMap["option_account"] = param.option_account;
		 paraMap["stock_account"] = param.stock_account;
		 paraMap["seat_no"] = param.seat_no;
		 paraMap["exchange_type"] = param.exchange_type;
		 paraMap["stock_code"] = param.stock_code;
		 paraMap["lock_direction"] = param.lock_direction;
		 paraMap["entrust_amount"] = param.entrust_amount;
		 
			var reqParamVo = this.service.reqParamVo;
		  	reqParamVo.setUrl(global.serverPathTrade);
		  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
      /**
 	 * 股票期权可撤单査询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
 	 * @param {Object} password                 交易密码
     * @param {Object} session_id                会话号
     * @param {Object} exchange_type            交易市场类别（见数据字典)
     * @param {Object} stock_code               股票代码
     * @param {Object} option_code              期权合约编码
     * @param {Object} entrust_bs           	委托标志（见数据字典)
     * @param {Object} option_account  			衍生品合约账户
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.queryOrderCancellation = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305021";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["exchange_type"] = param.exchange_type;
		 paraMap["stock_code"] = param.stock_code;
		 paraMap["option_code"] = param.option_code;
		 paraMap["entrust_bs"] = param.entrust_bs;
		 paraMap["option_account"] = param.option_account;
		 
			var reqParamVo = this.service.reqParamVo;
		  	reqParamVo.setUrl(global.serverPathTrade);
		  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
      /**
 	 * 股票期权合约查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
     * @param {Object} session_id                会话号
     * @param {Object} stock_code            	标的证券代码
     * @param {Object} option_code                 期权合约编码
     * @param {Object} option_type                期权类别（见数据字典)
     * @param {Object} exercise_month           行权年月
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.queryOptionContrac = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305022";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["stock_code"] = param.stock_code;
		 paraMap["option_code"] = param.option_code;
		 paraMap["option_type"] = param.option_type;
		 paraMap["exercise_month"] = param.exercise_month;
		 
		var reqParamVo = this.service.reqParamVo;
	  	reqParamVo.setUrl(global.serverPathTrade);
	  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
       /**
 	 * 股票期权近期可行权查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
     * @param {Object} session_id                会话号
     * @param {Object} stock_code            	标的证券代码
     * @param {Object} option_code                 期权合约编码
     * @param {Object} option_type                期权类别（见数据字典)
     * @param {Object} exercise_month           行权年月
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.recentVesting = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305032";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["option_code"] = param.option_code;
		 
		var reqParamVo = this.service.reqParamVo;
	  	reqParamVo.setUrl(global.serverPathTrade);
	  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
        /**
 	 * 股票期权当日备兑锁定解锁
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
     * @param {Object} session_id                会话号
     * @param {Object} stock_code            	标的证券代码
     * @param {Object} option_code                 期权合约编码
     * @param {Object} option_type                期权类别（见数据字典)
     * @param {Object} exercise_month           行权年月
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.dayReleaseLockedUnlock = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305034";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 
		var reqParamVo = this.service.reqParamVo;
	  	reqParamVo.setUrl(global.serverPathTrade);
	  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
     
       /**
 	 * 股票期权合约查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
     * @param {Object} session_id                会话号
     * @param {Object} stock_code            	标的证券代码
     * @param {Object} option_code                 期权合约编码
     * @param {Object} option_type                期权类别（见数据字典)
     * @param {Object} exercise_month           行权年月
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.queryCommonPosition = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305037";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["stock_code"] = param.stock_code;
		 
		var reqParamVo = this.service.reqParamVo;
	  	reqParamVo.setUrl(global.serverPathTrade);
	  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
        /**
 	 * 股票期权合约查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
     * @param {Object} session_id                会话号
     * @param {Object} stock_code            	标的证券代码
     * @param {Object} option_code                 期权合约编码
     * @param {Object} option_type                期权类别（见数据字典)
     * @param {Object} exercise_month           行权年月
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.queryPostageDues = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305038";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["stock_code"] = param.stock_code;
		 
		var reqParamVo = this.service.reqParamVo;
	  	reqParamVo.setUrl(global.serverPathTrade);
	  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
         /**
 	 * 股票期权合约查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
     * @param {Object} session_id                会话号
     * @param {Object} stock_code            	标的证券代码
     * @param {Object} option_code                 期权合约编码
     * @param {Object} option_type                期权类别（见数据字典)
     * @param {Object} exercise_month           行权年月
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.queryOweCoupons = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305039";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["stock_code"] = param.stock_code;
		 
		var reqParamVo = this.service.reqParamVo;
	  	reqParamVo.setUrl(global.serverPathTrade);
	  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
     /**
 	 * 股票期权可锁定持仓查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
     * @param {Object} session_id                会话号
     * @param {Object} stock_code            	标的证券代码
     * @param {Object} option_code                 期权合约编码
     * @param {Object} option_type                期权类别（见数据字典)
     * @param {Object} exercise_month           行权年月
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.queryLockableHolding = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "305041";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 paraMap["stock_code"] = param.stock_code;
		 
		var reqParamVo = this.service.reqParamVo;
	  	reqParamVo.setUrl(global.serverPathTrade);
	  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
      
     /**
 	 * 期权账户信息查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
     * @param {Object} session_id                会话号
     * @param {Object} stock_code            	标的证券代码
     * @param {Object} option_code                 期权合约编码
     * @param {Object} option_type                期权类别（见数据字典)
     * @param {Object} exercise_month           行权年月
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.queryOptionAccount = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "3050031";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		 
		var reqParamVo = this.service.reqParamVo;
	  	reqParamVo.setUrl(global.serverPathTrade);
	  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
      };
      
     /**
 	 * 行权、指派的数量查询
 	 * @param {Object} entrust_way              委托方式
     * @param {Object} branch_no                分支机构
     * @param {Object} fund_account             资金账号
     * @param {Object} cust_code                客户编号
     * @param {Object} session_id               会话号
 	 * @param callback 回调函数
 	 */
	 service_option.prototype.rightAssignmentQuery = function(param,callback,ctrlParam)
	 {
		 var paraMap = {};
		 paraMap["funcNo"] = "3050321";
		 paraMap["entrust_way"] = param.entrust_way;
		 paraMap["branch_no"] = param.branch_no;
		 paraMap["fund_account"] = param.fund_account;
		 paraMap["cust_code"] = param.cust_code;
		 paraMap["password"] = param.password;
		 paraMap["session_id"] = param.session_id;
		var reqParamVo = this.service.reqParamVo;
	  	reqParamVo.setUrl(global.serverPathTrade);
	  	this.commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
     };
	/***应用接口......................................................结束*/
   

});